/* A recursive-descent parser generated by greg 0.4.3 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
struct _GREG;
#define YYRULECOUNT 233

/* PEG Markdown Highlight
 * Copyright 2011-2016 Ali Rantakari -- http://hasseg.org
 * Licensed under the GPL2+ and MIT licenses (see LICENSE for more info).
 * 
 * pmh_grammar.leg
 * 
 * This is a slightly adapted version of the PEG grammar from John MacFarlane's
 * peg-markdown compiler.
 */

/* PEG Markdown Highlight
 * Copyright 2011-2016 Ali Rantakari -- http://hasseg.org
 * Licensed under the GPL2+ and MIT licenses (see LICENSE for more info).
 * 
 * pmh_parser_head.c
 * 
 * Code to be inserted into the beginning of the parser code generated
 * from the PEG grammar.
 */

#include "pmh_parser.h"

#ifndef pmh_DEBUG_OUTPUT
#define pmh_DEBUG_OUTPUT 0
#endif

#if pmh_DEBUG_OUTPUT
#define pmh_IF(x)           if (x)
#define pmh_PRINTF(x, ...)  fprintf(stderr, x, ##__VA_ARGS__)
#define pmh_PUTCHAR(x)      putchar(x)
#else
#define pmh_IF(x)
#define pmh_PRINTF(x, ...)
#define pmh_PUTCHAR(x)
#endif



// Alias strdup to _strdup on MSVC:
#ifdef _MSC_VER
#define strdup _strdup
#endif


char *strdup_or_null(char *s)
{
    return (s == NULL) ? NULL : strdup(s);
}


// Internal language element occurrence structure, containing
// both public and private members:
struct pmh_RealElement
{
    // "Public" members:
    // (these must match what's defined in pmh_definitions.h)
    // -----------------------------------------------
    pmh_element_type type;
    unsigned long pos;
    unsigned long end;
    struct pmh_RealElement *next;
    char *label;
    char *address;
    
    // "Private" members for use by the parser itself:
    // -----------------------------------------------
    
    // next element in list of all elements:
    struct pmh_RealElement *all_elems_next;
    
    // offset to text (for elements of type pmh_EXTRA_TEXT, used when the
    // parser reads the value of 'text'):
    int text_offset;
    
    // text content (for elements of type pmh_EXTRA_TEXT):
    char *text;
    
    // children of element (for elements of type pmh_RAW_LIST)
    struct pmh_RealElement *children;
};
typedef struct pmh_RealElement pmh_realelement;




// Parser state data:
typedef struct
{
    /* The original, unmodified UTF-8 input: */
    char *original_input;
    
    /* The offsets of the bytes we have stripped from original_input: */
    unsigned long *strip_positions;
    size_t strip_positions_len;
    
    /* Buffer of characters to be parsed: */
    char *charbuf;
    
    /* Linked list of {start, end} offset pairs determining which parts */
    /* of charbuf to actually parse: */
    pmh_realelement *current_elem;
    pmh_realelement *elem_head;
    
    /* Current parsing offset within charbuf: */
    unsigned long offset;
    
    /* The extensions to use for parsing (bitfield */
    /* of enum pmh_extensions): */
    int extensions;
    
    /* Array of parsing result elements, indexed by type: */
    pmh_realelement **head_elems;
    
    /* Whether we are parsing only references: */
    bool parsing_only_references;
    
    /* List of reference elements: */
    pmh_realelement *references;
} parser_data;

static parser_data *mk_parser_data(char *original_input,
                                   unsigned long *strip_positions,
                                   size_t strip_positions_len,
                                   char *charbuf,
                                   pmh_realelement *parsing_elems,
                                   unsigned long offset,
                                   int extensions,
                                   pmh_realelement **head_elems,
                                   pmh_realelement *references)
{
    parser_data *p_data = (parser_data *)malloc(sizeof(parser_data));
    p_data->extensions = extensions;
    p_data->original_input = original_input;
    p_data->strip_positions = strip_positions;
    p_data->strip_positions_len = strip_positions_len;
    p_data->charbuf = charbuf;
    p_data->offset = offset;
    p_data->elem_head = p_data->current_elem = parsing_elems;
    p_data->references = references;
    p_data->parsing_only_references = false;
    if (head_elems != NULL)
        p_data->head_elems = head_elems;
    else {
        p_data->head_elems = (pmh_realelement **)
                             malloc(sizeof(pmh_realelement *) * pmh_NUM_TYPES);
        int i;
        for (i = 0; i < pmh_NUM_TYPES; i++)
            p_data->head_elems[i] = NULL;
    }
    return p_data;
}


// Forward declarations
static void parse_markdown(parser_data *p_data);
static void parse_references(parser_data *p_data);





static char **get_element_type_names()
{
    static char **elem_type_names = NULL;
    if (elem_type_names == NULL)
    {
        elem_type_names = (char **)malloc(sizeof(char*) * pmh_NUM_LANG_TYPES);
        int i;
        for (i = 0; i < pmh_NUM_LANG_TYPES; i++)
            elem_type_names[i] = NULL;
        elem_type_names[pmh_LINK] = "LINK";
        elem_type_names[pmh_AUTO_LINK_URL] = "AUTO_LINK_URL";
        elem_type_names[pmh_AUTO_LINK_EMAIL] = "AUTO_LINK_EMAIL";
        elem_type_names[pmh_IMAGE] = "IMAGE";
        elem_type_names[pmh_CODE] = "CODE";
        elem_type_names[pmh_HTML] = "HTML";
        elem_type_names[pmh_HTML_ENTITY] = "HTML_ENTITY";
        elem_type_names[pmh_EMPH] = "EMPH";
        elem_type_names[pmh_STRONG] = "STRONG";
        elem_type_names[pmh_LIST_BULLET] = "LIST_BULLET";
        elem_type_names[pmh_LIST_ENUMERATOR] = "LIST_ENUMERATOR";
        elem_type_names[pmh_COMMENT] = "COMMENT";
        elem_type_names[pmh_H1] = "H1";
        elem_type_names[pmh_H2] = "H2";
        elem_type_names[pmh_H3] = "H3";
        elem_type_names[pmh_H4] = "H4";
        elem_type_names[pmh_H5] = "H5";
        elem_type_names[pmh_H6] = "H6";
        elem_type_names[pmh_BLOCKQUOTE] = "BLOCKQUOTE";
        elem_type_names[pmh_VERBATIM] = "VERBATIM";
        elem_type_names[pmh_HTMLBLOCK] = "HTMLBLOCK";
        elem_type_names[pmh_HRULE] = "HRULE";
        elem_type_names[pmh_REFERENCE] = "REFERENCE";
        elem_type_names[pmh_NOTE] = "NOTE";
        elem_type_names[pmh_STRIKE] = "STRIKE";
    }
    return elem_type_names;
}

pmh_element_type pmh_element_type_from_name(char *name)
{
    char **elem_type_names = get_element_type_names();
    
    int i;
    for (i = 0; i < pmh_NUM_LANG_TYPES; i++)
    {
        char *i_name = elem_type_names[i];
        if (i_name == NULL)
            continue;
        if (strcmp(i_name, name) == 0)
            return i;
    }
    
    return pmh_NO_TYPE;
}

char *pmh_element_name_from_type(pmh_element_type type)
{
    char **elem_type_names = get_element_type_names();
    char* ret = elem_type_names[type];
    if (ret == NULL)
        return "unknown type";
    return ret;
}




/*
Remove pmh_RAW elements with zero length; return pointer
to new head.
*/
static pmh_realelement *remove_zero_length_raw_spans(pmh_realelement *elem)
{
    pmh_realelement *head = elem;
    pmh_realelement *parent = NULL;
    pmh_realelement *c = head;
    while (c != NULL)
    {
        if (c->type == pmh_RAW && c->pos >= c->end)
        {
            if (parent != NULL)
                parent->next = c->next;
            else
                head = c->next;
            parent = c;
            c = c->next;
            continue;
        }
        parent = c;
        c = c->next;
    }
    return head;
}

#if pmh_DEBUG_OUTPUT
/*
Print null-terminated string s.t. some characters are
represented by their corresponding espace sequences
*/
static void print_str_literal_escapes(char *str)
{
    char *c = str;
    pmh_PRINTF("'");
    while (*c != '\0')
    {
        if (*c == '\n')         pmh_PRINTF("\\n");
        else if (*c == '\t')    pmh_PRINTF("\\t");
        else putchar(*c);
        c++;
    }
    pmh_PRINTF("'");
}
#endif

#if pmh_DEBUG_OUTPUT
/*
Print elements in a linked list of
pmh_RAW, pmh_SEPARATOR, pmh_EXTRA_TEXT elements
*/
static void print_raw_spans_inline(pmh_realelement *elem)
{
    pmh_realelement *cur = elem;
    while (cur != NULL)
    {
        if (cur->type == pmh_SEPARATOR)
            pmh_PRINTF("<pmh_SEP %ld> ", cur->pos);
        else if (cur->type == pmh_EXTRA_TEXT) {
            pmh_PRINTF("{pmh_ETEXT ");
            print_str_literal_escapes(cur->text);
            pmh_PRINTF("}");
        }
        else
            pmh_PRINTF("(%ld-%ld) ", cur->pos, cur->end);
        cur = cur->next;
    }
}
#endif

/*
Perform postprocessing parsing runs for pmh_RAW_LIST elements in `elem`,
iteratively until no such elements exist.
*/
static void process_raw_blocks(parser_data *p_data)
{
    pmh_PRINTF("--------process_raw_blocks---------\n");
    while (p_data->head_elems[pmh_RAW_LIST] != NULL)
    {
        pmh_PRINTF("new iteration.\n");
        pmh_realelement *cursor = p_data->head_elems[pmh_RAW_LIST];
        p_data->head_elems[pmh_RAW_LIST] = NULL;
        while (cursor != NULL)
        {
            pmh_realelement *span_list = (pmh_realelement*)cursor->children;
            
            span_list = remove_zero_length_raw_spans(span_list);
            
            #if pmh_DEBUG_OUTPUT
            pmh_PRINTF("  process: ");
            print_raw_spans_inline(span_list);
            pmh_PRINTF("\n");
            #endif
            
            while (span_list != NULL)
            {
                pmh_PRINTF("next: span_list: %ld-%ld\n",
                           span_list->pos, span_list->end);
                
                // Skip separators in the beginning, as well as
                // separators after another separator:
                if (span_list->type == pmh_SEPARATOR) {
                    span_list = span_list->next;
                    continue;
                }
                
                // Store list of spans until next separator in subspan_list:
                pmh_realelement *subspan_list = span_list;
                pmh_realelement *previous = NULL;
                while (span_list != NULL && span_list->type != pmh_SEPARATOR) {
                    previous = span_list;
                    span_list = span_list->next;
                }
                if (span_list != NULL && span_list->type == pmh_SEPARATOR) {
                    span_list = span_list->next;
                    previous->next = NULL;
                }
                
                #if pmh_DEBUG_OUTPUT
                pmh_PRINTF("    subspan process: ");
                print_raw_spans_inline(subspan_list);
                pmh_PRINTF("\n");
                #endif
                
                // Process subspan_list:
                parser_data *raw_p_data = mk_parser_data(
                    p_data->original_input,
                    p_data->strip_positions,
                    p_data->strip_positions_len,
                    p_data->charbuf,
                    subspan_list,
                    subspan_list->pos,
                    p_data->extensions,
                    p_data->head_elems,
                    p_data->references
                );
                parse_markdown(raw_p_data);
                free(raw_p_data);
                
                pmh_PRINTF("parse over\n");
            }
            
            cursor = cursor->next;
        }
    }
}


#if pmh_DEBUG_OUTPUT
static void print_raw_blocks(char *text, pmh_realelement *elem[])
{
    pmh_PRINTF("--------print_raw_blocks---------\n");
    pmh_PRINTF("block:\n");
    pmh_realelement *cursor = elem[pmh_RAW_LIST];
    while (cursor != NULL)
    {
        print_raw_spans_inline(cursor->children);
        cursor = cursor->next;
    }
}
#endif




/* Free all elements created while parsing */
void pmh_free_elements(pmh_element **elems)
{
    pmh_realelement *cursor = (pmh_realelement*)elems[pmh_ALL];
    while (cursor != NULL) {
        pmh_realelement *tofree = cursor;
        cursor = cursor->all_elems_next;
        if (tofree->text != NULL)
            free(tofree->text);
        if (tofree->label != NULL)
            free(tofree->label);
        if (tofree->address != NULL)
            free(tofree->address);
        free(tofree);
    }
    elems[pmh_ALL] = NULL;
    
    free(elems);
}






#define IS_CONTINUATION_BYTE(x) ((x & 0xC0) == 0x80)
#define HAS_UTF8_BOM(x)         ( ((*x & 0xFF) == 0xEF)\
                                  && ((*(x+1) & 0xFF) == 0xBB)\
                                  && ((*(x+2) & 0xFF) == 0xBF) )
#define ADD_STRIP_POS(x) \
    /* reallocate more space for the array, if needed: */ \
    if (strip_positions_size <= strip_positions_pos) { \
        size_t new_size = strip_positions_size * 2; \
        unsigned long *new_arr = (unsigned long *) \
                                 calloc(new_size, \
                                        sizeof(unsigned long)); \
        memcpy(new_arr, strip_positions, \
               (sizeof(unsigned long) * strip_positions_size)); \
        strip_positions_size = new_size; \
        free(strip_positions); \
        strip_positions = new_arr; \
    } \
    strip_positions[strip_positions_pos] = x; \
    strip_positions_pos++;

/*
Copy `str` to `out`, while doing the following:
  - remove UTF-8 continuation bytes
  - remove possible UTF-8 BOM (byte order mark)
  - append two newlines to the end (like peg-markdown does)
  - keep track of which bytes we have stripped (in strip_positions)
*/
static int strcpy_preformat(char *str, char **out,
                            unsigned long **out_strip_positions,
                            size_t *out_strip_positions_len)
{
    size_t strip_positions_size = 1024;
    size_t strip_positions_pos = 0;
    unsigned long *strip_positions = (unsigned long *)
                                     calloc(strip_positions_size,
                                            sizeof(unsigned long));
    
    
    // +2 in the following is due to the "\n\n" suffix:
    char *new_str = (char *)malloc(sizeof(char) * strlen(str) + 1 + 2);
    char *c = str;
    int i = 0;
    
    if (HAS_UTF8_BOM(c)) {
        c += 3;
        ADD_STRIP_POS(0);
        ADD_STRIP_POS(1);
        ADD_STRIP_POS(2);
    }
    
    while (*c != '\0')
    {
        if (!IS_CONTINUATION_BYTE(*c)) {
            *(new_str+i) = *c, i++;
        } else {
            ADD_STRIP_POS((int)(c-str));
        }
        c++;
    }
    
    *(new_str+(i++)) = '\n';
    *(new_str+(i++)) = '\n';
    *(new_str+i) = '\0';
    
    *out = new_str;
    *out_strip_positions = strip_positions;
    *out_strip_positions_len = strip_positions_pos;
    return i;
}



void pmh_markdown_to_elements(char *text, int extensions,
                              pmh_element **out_result[])
{
    char *text_copy = NULL;
    unsigned long *strip_positions = NULL;
    size_t strip_positions_len = 0;
    int text_copy_len = strcpy_preformat(text, &text_copy, &strip_positions,
                                         &strip_positions_len);
    
    pmh_realelement *parsing_elem = (pmh_realelement *)
                                    malloc(sizeof(pmh_realelement));
    parsing_elem->type = pmh_RAW;
    parsing_elem->pos = 0;
    parsing_elem->end = text_copy_len;
    parsing_elem->next = NULL;
    
    parser_data *p_data = mk_parser_data(
        text,
        strip_positions,
        strip_positions_len,
        text_copy,
        parsing_elem,
        0,
        extensions,
        NULL,
        NULL
    );
    pmh_realelement **result = p_data->head_elems;
    
    if (*text_copy != '\0')
    {
        // Get reference definitions into p_data->references
        parse_references(p_data);
        
        // Reset parser state to beginning of input
        p_data->offset = 0;
        p_data->current_elem = p_data->elem_head;
        
        // Parse whole document
        parse_markdown(p_data);
        
        #if pmh_DEBUG_OUTPUT
        print_raw_blocks(text_copy, result);
        #endif
        
        process_raw_blocks(p_data);
    }
    
    free(strip_positions);
    free(p_data);
    free(parsing_elem);
    free(text_copy);
    
    *out_result = (pmh_element**)result;
}



/*
Mergesort linked list of elements (using comparison function `compare`),
return new head. (Adapted slightly from Simon Tatham's algorithm.)
*/
static pmh_element *ll_mergesort(pmh_element *list,
                                 int (*compare)(const pmh_element*,
                                                const pmh_element*))
{
    if (!list)
        return NULL;
    
    pmh_element *out_head = list;
    
    /* Merge widths of doubling size until done */
    int merge_width = 1;
    while (1)
    {
        pmh_element *l, *r; /* left & right segment pointers */
        pmh_element *tail = NULL; /* tail of sorted section */
        
        l = out_head;
        out_head = NULL;
        
        int merge_count = 0;
        
        while (l)
        {
            merge_count++;
            
            /* Position r, determine lsize & rsize */
            r = l;
            int lsize = 0;
            int i;
            for (i = 0; i < merge_width; i++) {
                lsize++;
                r = r->next;
                if (!r)
                    break;
            }
            int rsize = merge_width;
            
            /* Merge l & r */
            while (lsize > 0 || (rsize > 0 && r))
            {
                bool get_from_left = false;
                if (lsize == 0)             get_from_left = false;
                else if (rsize == 0 || !r)  get_from_left = true;
                else if (compare(l,r) <= 0) get_from_left = true;
                
                pmh_element *e;
                if (get_from_left) {
                    e = l; l = l->next; lsize--;
                } else {
                    e = r; r = r->next; rsize--;
                }
                
                /* add the next pmh_element to the merged list */
                if (tail)
                    tail->next = e;
                else
                    out_head = e;
                tail = e;
            }
            
            l = r;
        }
        tail->next = NULL;
        
        if (merge_count <= 1)
            return out_head;
        
        merge_width *= 2;
    }
}

static int elem_compare_by_pos(const pmh_element *a, const pmh_element *b)
{
    return a->pos - b->pos;
}

void pmh_sort_elements_by_pos(pmh_element *element_lists[])
{
    int i;
    for (i = 0; i < pmh_NUM_LANG_TYPES; i++)
        element_lists[i] = ll_mergesort(element_lists[i], &elem_compare_by_pos);
}








/* return true if extension is selected */
static bool extension(parser_data *p_data, int ext)
{
    return ((p_data->extensions & ext) != 0);
}

/* return reference pmh_realelement for a given label */
static pmh_realelement *get_reference(parser_data *p_data, char *label)
{
    if (!label)
        return NULL;
    
    pmh_realelement *cursor = p_data->references;
    while (cursor != NULL)
    {
        if (cursor->label && strcmp(label, cursor->label) == 0)
            return cursor;
        cursor = cursor->next;
    }
    return NULL;
}


/* cons an element/list onto a list, returning pointer to new head */
static pmh_realelement *cons(pmh_realelement *elem, pmh_realelement *list)
{
    assert(elem != NULL);
    
    pmh_realelement *cur = elem;
    while (cur->next != NULL) {
        cur = cur->next;
    }
    cur->next = list;
    
    return elem;
}


/* reverse a list, returning pointer to new list */
static pmh_realelement *reverse(pmh_realelement *list)
{
    pmh_realelement *new_head = NULL;
    pmh_realelement *next = NULL;
    while (list != NULL) {
        next = list->next;
        list->next = new_head;
        new_head = list;
        list = next;
    }
    return new_head;
}



/* construct pmh_realelement */
static pmh_realelement *mk_element(parser_data *p_data, pmh_element_type type,
                                   long pos, long end)
{
    pmh_realelement *result = (pmh_realelement *)malloc(sizeof(pmh_realelement));
    memset(result, 0, sizeof(*result));
    result->type = type;
    result->pos = pos;
    result->end = end;
    
    pmh_realelement *old_all_elements_head = p_data->head_elems[pmh_ALL];
    p_data->head_elems[pmh_ALL] = result;
    result->all_elems_next = old_all_elements_head;
    
    //pmh_PRINTF("  mk_element: %s [%ld - %ld]\n", pmh_element_name_from_type(type), pos, end);
    
    return result;
}

static pmh_realelement *copy_element(parser_data *p_data, pmh_realelement *elem)
{
    pmh_realelement *result = mk_element(p_data, elem->type, elem->pos, elem->end);
    result->label = strdup_or_null(elem->label);
    result->text = strdup_or_null(elem->text);
    result->address = strdup_or_null(elem->address);
    return result;
}

/* construct pmh_EXTRA_TEXT pmh_realelement */
static pmh_realelement *mk_etext(parser_data *p_data, char *string)
{
    pmh_realelement *result;
    assert(string != NULL);
    result = mk_element(p_data, pmh_EXTRA_TEXT, 0,0);
    result->text = strdup_or_null(string);
    return result;
}


/*
Given an element where the offsets {pos, end} represent
locations in the *parsed text* (defined by the linked list of pmh_RAW and
pmh_EXTRA_TEXT elements in p_data->current_elem), fix these offsets to represent
corresponding offsets in the parse buffer (p_data->charbuf). Also split
the given pmh_realelement into multiple parts if its offsets span multiple
p_data->current_elem elements. Return the (list of) elements with real offsets.
*/
static pmh_realelement *fix_offsets(parser_data *p_data, pmh_realelement *elem)
{
    if (elem->type == pmh_EXTRA_TEXT)
        return mk_etext(p_data, elem->text);
    
    pmh_realelement *new_head = copy_element(p_data, elem);
    
    pmh_realelement *tail = new_head;
    pmh_realelement *prev = NULL;
    
    bool found_start = false;
    bool found_end = false;
    bool tail_needs_pos = false;
    unsigned long previous_end = 0;
    unsigned long c = 0;
    
    pmh_realelement *cursor = p_data->elem_head;
    while (cursor != NULL)
    {
        int thislen = (cursor->type == pmh_EXTRA_TEXT)
                        ? strlen(cursor->text)
                        : cursor->end - cursor->pos;
        
        if (tail_needs_pos && cursor->type != pmh_EXTRA_TEXT) {
            tail->pos = cursor->pos;
            tail_needs_pos = false;
        }
        
        unsigned int this_pos = cursor->pos;
        
        if (!found_start && (c <= elem->pos && elem->pos <= c+thislen)) {
            tail->pos = (cursor->type == pmh_EXTRA_TEXT)
                        ? previous_end
                        : cursor->pos + (elem->pos - c);
            this_pos = tail->pos;
            found_start = true;
        }
        
        if (!found_end && (c <= elem->end && elem->end <= c+thislen)) {
            tail->end = (cursor->type == pmh_EXTRA_TEXT)
                        ? previous_end
                        : cursor->pos + (elem->end - c);
            found_end = true;
        }
        
        if (found_start && found_end)
            break;
        
        if (cursor->type != pmh_EXTRA_TEXT)
            previous_end = cursor->end;
        
        if (found_start) {
            pmh_realelement *new_elem = copy_element(p_data, tail);
            new_elem->pos = this_pos;
            new_elem->end = cursor->end;
            new_elem->next = tail;
            if (prev != NULL)
                prev->next = new_elem;
            if (new_head == tail)
                new_head = new_elem;
            prev = new_elem;
            tail_needs_pos = true;
        }
        
        c += thislen;
        cursor = cursor->next;
    }
    
    return new_head;
}



/* Add an element to p_data->head_elems. */
static void add(parser_data *p_data, pmh_realelement *elem)
{
    if (elem->type != pmh_RAW_LIST)
    {
        pmh_PRINTF("  add: %s [%ld - %ld]\n",
                   pmh_element_name_from_type(elem->type), elem->pos, elem->end);
        elem = fix_offsets(p_data, elem);
        pmh_PRINTF("     > %s [%ld - %ld]\n",
                   pmh_element_name_from_type(elem->type), elem->pos, elem->end);
    }
    else
    {
        pmh_PRINTF("  add: pmh_RAW_LIST ");
        pmh_realelement *cursor = elem->children;
        pmh_realelement *previous = NULL;
        while (cursor != NULL)
        {
            pmh_realelement *next = cursor->next;
            pmh_PRINTF("(%ld-%ld)>", cursor->pos, cursor->end);
            pmh_realelement *new_cursor = fix_offsets(p_data, cursor);
            if (previous != NULL)
                previous->next = new_cursor;
            else
                elem->children = new_cursor;
            pmh_PRINTF("(%ld-%ld)", new_cursor->pos, new_cursor->end);
            while (new_cursor->next != NULL) {
                new_cursor = new_cursor->next;
                pmh_PRINTF("(%ld-%ld)", new_cursor->pos, new_cursor->end);
            }
            pmh_PRINTF(" ");
            if (next != NULL)
                new_cursor->next = next;
            previous = new_cursor;
            cursor = next;
        }
        pmh_PRINTF("\n");
    }
    
    if (p_data->head_elems[elem->type] == NULL)
        p_data->head_elems[elem->type] = elem;
    else
    {
        pmh_realelement *last = elem;
        while (last->next != NULL)
            last = last->next;
        last->next = p_data->head_elems[elem->type];
        p_data->head_elems[elem->type] = elem;
    }
}


// Given a range in the list of spans we use for parsing (pos, end), return
// a copy of the corresponding section in the original input, with all of
// the UTF-8 bytes intact:
static char *copy_input_span(parser_data *p_data,
                             unsigned long pos, unsigned long end)
{
    if (end <= pos)
        return NULL;
    
    char *ret = NULL;
    
    // Adjust (pos,end) to match actual indexes in charbuf:
    pmh_realelement *dummy = mk_element(p_data, pmh_NO_TYPE, pos, end);
    pmh_realelement *fixed_dummies = fix_offsets(p_data, dummy);
    pmh_realelement *cursor = fixed_dummies;
    while (cursor != NULL)
    {
        if (cursor->end <= cursor->pos)
        {
            cursor = cursor->next;
            continue;
        }
        
        // Adjust cursor's span to take bytes stripped from the original
        // input into account (i.e. match the corresponding span in
        // p_data->original_input):
        unsigned long adjusted_pos = cursor->pos;
        unsigned long adjusted_end = cursor->end;
        size_t i;
        for (i = 0; i < p_data->strip_positions_len; i++)
        {
            unsigned long strip_position = p_data->strip_positions[i];
            if (strip_position <= adjusted_pos)
                adjusted_pos++;
            if (strip_position <= adjusted_end)
                adjusted_end++;
            else
                break;
        }
        
        // Copy span from original input:
        size_t adjusted_len = adjusted_end - adjusted_pos;
        char *str = (char *)malloc(sizeof(char)*adjusted_len + 1);
        *str = '\0';
        strncat(str, (p_data->original_input + adjusted_pos), adjusted_len);
        
        if (ret == NULL)
            ret = str;
        else
        {
            // append str to ret:
            char *new_ret = (char *)malloc(sizeof(char)
                                           *(strlen(str) + strlen(ret)) + 1);
            *new_ret = '\0';
            strcat(new_ret, ret);
            strcat(new_ret, str);
            free(ret);
            free(str);
            ret = new_ret;
        }
        
        cursor = cursor->next;
    }
    
    return ret;
}





# define YYSTYPE pmh_realelement *
#ifdef __DEBUG__
# define YY_DEBUG 1
#endif

#define YY_INPUT(buf, result, max_size)\
        yy_input_func(buf, &result, max_size, (parser_data *)G->data)

static void yy_input_func(char *buf, int *result, int max_size,
                          parser_data *p_data)
{
    if (p_data->current_elem == NULL)
    {
        (*result) = 0;
        return;
    }
    
    if (p_data->current_elem->type == pmh_EXTRA_TEXT)
    {
        int yyc;
        bool moreToRead = (p_data->current_elem->text
                           && *(p_data->current_elem->text
                                + p_data->current_elem->text_offset) != '\0');
        if (moreToRead)
        {
            yyc = *(p_data->current_elem->text + p_data->current_elem->text_offset++);
            pmh_PRINTF("\e[47;30m"); pmh_PUTCHAR(yyc); pmh_PRINTF("\e[0m");
            pmh_IF(yyc == '\n') pmh_PRINTF("\e[47m \e[0m");
        }
        else
        {
            yyc = EOF;
            p_data->current_elem = p_data->current_elem->next;
            pmh_PRINTF("\e[41m \e[0m");
            if (p_data->current_elem != NULL)
                p_data->offset = p_data->current_elem->pos;
        }
        (*result) = (EOF == yyc) ? 0 : (*(buf) = yyc, 1);
        return;
    }
    
    *(buf) = *(p_data->charbuf + p_data->offset);
    (*result) = (*buf != '\0');
    p_data->offset++;
    
    pmh_PRINTF("\e[43;30m"); pmh_PUTCHAR(*buf); pmh_PRINTF("\e[0m");
    pmh_IF(*buf == '\n') pmh_PRINTF("\e[42m \e[0m");
    
    if (p_data->offset >= p_data->current_elem->end)
    {
        p_data->current_elem = p_data->current_elem->next;
        pmh_PRINTF("\e[41m \e[0m");
        if (p_data->current_elem != NULL)
            p_data->offset = p_data->current_elem->pos;
    }
}



#define elem(x)     mk_element((parser_data *)G->data, x, thunk->begin, thunk->end)
#define elem_s(x)   mk_element((parser_data *)G->data, x, s->pos, thunk->end)
#define mk_sep      mk_element((parser_data *)G->data, pmh_SEPARATOR, 0,0)
#define mk_notype   mk_element((parser_data *)G->data, pmh_NO_TYPE, 0,0)
#define etext(x)    mk_etext((parser_data *)G->data, x)
#define ADD(x)      add((parser_data *)G->data, x)
#define EXT(x)      extension((parser_data *)G->data, x)
#define REF_EXISTS(x) reference_exists((parser_data *)G->data, x)
#define GET_REF(x)  get_reference((parser_data *)G->data, x)
#define PARSING_REFERENCES ((parser_data *)G->data)->parsing_only_references
#define FREE_LABEL(l) { free(l->label); l->label = NULL; }
#define FREE_ADDRESS(l) { free(l->address); l->address = NULL; }

// This gives us the text matched with < > as it appears in the original input:
#define COPY_YYTEXT_ORIG() copy_input_span((parser_data *)G->data, thunk->begin, thunk->end)


#ifndef YY_ALLOC
#define YY_ALLOC(N, D) malloc(N)
#endif
#ifndef YY_CALLOC
#define YY_CALLOC(N, S, D) calloc(N, S)
#endif
#ifndef YY_REALLOC
#define YY_REALLOC(B, N, D) realloc(B, N)
#endif
#ifndef YY_FREE
#define YY_FREE free
#endif
#ifndef YY_LOCAL
#define YY_LOCAL(T)     static T
#endif
#ifndef YY_ACTION
#define YY_ACTION(T)    static T
#endif
#ifndef YY_RULE
#define YY_RULE(T)      static T
#endif
#ifndef YY_PARSE
#define YY_PARSE(T)     T
#endif
#ifndef YY_NAME
#define YY_NAME(N) yy##N
#endif
#ifndef YY_INPUT
#define YY_INPUT(buf, result, max_size)                 \
  {                                                     \
    int yyc= getchar();                                 \
    result= (EOF == yyc) ? 0 : (*(buf)= yyc, 1);        \
    yyprintf((stderr, "<%c>", yyc));                  \
  }
#endif
#ifndef YY_BEGIN
#define YY_BEGIN        ( G->begin= G->pos, 1)
#endif
#ifndef YY_END
#define YY_END          ( G->end= G->pos, 1)
#endif
#ifdef YY_DEBUG
# define yyprintf(args) fprintf args
#else
# define yyprintf(args)
#endif
#ifndef YYSTYPE
#define YYSTYPE int
#endif
#ifndef YY_XTYPE
#define YY_XTYPE void *
#endif
#ifndef YY_XVAR
#define YY_XVAR yyxvar
#endif

#ifndef YY_STACK_SIZE
#define YY_STACK_SIZE 128
#endif

#ifndef YY_BUFFER_START_SIZE
#define YY_BUFFER_START_SIZE 1024
#endif

#ifndef YY_PART
#define yydata G->data
#define yy G->ss

struct _yythunk; // forward declaration
typedef void (*yyaction)(struct _GREG *G, char *yytext, int yyleng, struct _yythunk *thunkpos, YY_XTYPE YY_XVAR);
typedef struct _yythunk { int begin, end;  yyaction  action;  struct _yythunk *next; } yythunk;

typedef struct _GREG {
  char *buf;
  int buflen;
  int   offset;
  int   pos;
  int   limit;
  char *text;
  int   textlen;
  int   begin;
  int   end;
  yythunk *thunks;
  int   thunkslen;
  int thunkpos;
  YYSTYPE ss;
  YYSTYPE *val;
  YYSTYPE *vals;
  int valslen;
  YY_XTYPE data;
} GREG;

YY_LOCAL(int) yyrefill(GREG *G)
{
  int yyn;
  while (G->buflen - G->pos < 512)
    {
      G->buflen *= 2;
      G->buf= (char *)YY_REALLOC(G->buf, G->buflen, G->data);
    }
  YY_INPUT((G->buf + G->pos), yyn, (G->buflen - G->pos));
  if (!yyn) return 0;
  G->limit += yyn;
  return 1;
}

YY_LOCAL(int) yymatchDot(GREG *G)
{
  if (G->pos >= G->limit && !yyrefill(G)) return 0;
  ++G->pos;
  return 1;
}

YY_LOCAL(int) yymatchChar(GREG *G, int c)
{
  if (G->pos >= G->limit && !yyrefill(G)) return 0;
  if ((unsigned char)G->buf[G->pos] == c)
    {
      ++G->pos;
      yyprintf((stderr, "  ok   yymatchChar(%c) @ %s\n", c, G->buf+G->pos));
      return 1;
    }
  yyprintf((stderr, "  fail yymatchChar(%c) @ %s\n", c, G->buf+G->pos));
  return 0;
}

YY_LOCAL(int) yymatchString(GREG *G, char *s)
{
  int yysav= G->pos;
  while (*s)
    {
      if (G->pos >= G->limit && !yyrefill(G)) return 0;
      if (G->buf[G->pos] != *s)
        {
          G->pos= yysav;
          return 0;
        }
      ++s;
      ++G->pos;
    }
  return 1;
}

YY_LOCAL(int) yymatchClass(GREG *G, unsigned char *bits)
{
  int c;
  if (G->pos >= G->limit && !yyrefill(G)) return 0;
  c= (unsigned char)G->buf[G->pos];
  if (bits[c >> 3] & (1 << (c & 7)))
    {
      ++G->pos;
      yyprintf((stderr, "  ok   yymatchClass @ %s\n", G->buf+G->pos));
      return 1;
    }
  yyprintf((stderr, "  fail yymatchClass @ %s\n", G->buf+G->pos));
  return 0;
}

YY_LOCAL(void) yyDo(GREG *G, yyaction action, int begin, int end)
{
  while (G->thunkpos >= G->thunkslen)
    {
      G->thunkslen *= 2;
      G->thunks= (yythunk *)YY_REALLOC(G->thunks, sizeof(yythunk) * G->thunkslen, G->data);
    }
  G->thunks[G->thunkpos].begin=  begin;
  G->thunks[G->thunkpos].end=    end;
  G->thunks[G->thunkpos].action= action;
  ++G->thunkpos;
}

YY_LOCAL(int) yyText(GREG *G, int begin, int end)
{
  int yyleng= end - begin;
  if (yyleng <= 0)
    yyleng= 0;
  else
    {
      while (G->textlen < (yyleng + 1))
        {
          G->textlen *= 2;
          G->text= (char *)YY_REALLOC(G->text, G->textlen, G->data);
        }
      memcpy(G->text, G->buf + begin, yyleng);
    }
  G->text[yyleng]= '\0';
  return yyleng;
}

YY_LOCAL(void) yyDone(GREG *G)
{
  int pos;
  for (pos= 0; pos < G->thunkpos; ++pos)
    {
      yythunk *thunk= &G->thunks[pos];
      int yyleng= thunk->end ? yyText(G, thunk->begin, thunk->end) : thunk->begin;
      yyprintf((stderr, "DO [%d] %p %s\n", pos, thunk->action, G->text));
      thunk->action(G, G->text, yyleng, thunk, G->data);
    }
  G->thunkpos= 0;
}

YY_LOCAL(void) yyCommit(GREG *G)
{
  if ((G->limit -= G->pos))
    {
      memmove(G->buf, G->buf + G->pos, G->limit);
    }
  G->offset += G->pos;
  G->begin -= G->pos;
  G->end -= G->pos;
  G->pos= G->thunkpos= 0;
}

YY_LOCAL(int) yyAccept(GREG *G, int tp0)
{
  if (tp0)
    {
      fprintf(stderr, "accept denied at %d\n", tp0);
      return 0;
    }
  else
    {
      yyDone(G);
      yyCommit(G);
    }
  return 1;
}

YY_LOCAL(void) yyPush(GREG *G, char *text, int count, yythunk *thunk, YY_XTYPE YY_XVAR) { G->val += count; }
YY_LOCAL(void) yyPop(GREG *G, char *text, int count, yythunk *thunk, YY_XTYPE YY_XVAR)  { G->val -= count; }
YY_LOCAL(void) yySet(GREG *G, char *text, int count, yythunk *thunk, YY_XTYPE YY_XVAR)  { G->val[count]= G->ss; }

#endif /* YY_PART */

#define YYACCEPT        yyAccept(G, yythunkpos0)

YY_RULE(int) yy_RawNoteBlock(GREG *G); /* 233 */
YY_RULE(int) yy_RawNoteReference(GREG *G); /* 232 */
YY_RULE(int) yy_ExtendedSpecialChar(GREG *G); /* 231 */
YY_RULE(int) yy_AlphanumericAscii(GREG *G); /* 230 */
YY_RULE(int) yy_Quoted(GREG *G); /* 229 */
YY_RULE(int) yy_HtmlTag(GREG *G); /* 228 */
YY_RULE(int) yy_Ticks5(GREG *G); /* 227 */
YY_RULE(int) yy_Ticks4(GREG *G); /* 226 */
YY_RULE(int) yy_Ticks3(GREG *G); /* 225 */
YY_RULE(int) yy_Ticks2(GREG *G); /* 224 */
YY_RULE(int) yy_Ticks1(GREG *G); /* 223 */
YY_RULE(int) yy_SkipBlock(GREG *G); /* 222 */
YY_RULE(int) yy_References(GREG *G); /* 221 */
YY_RULE(int) yy_EmptyTitle(GREG *G); /* 220 */
YY_RULE(int) yy_RefTitleParens(GREG *G); /* 219 */
YY_RULE(int) yy_RefTitleDouble(GREG *G); /* 218 */
YY_RULE(int) yy_RefTitleSingle(GREG *G); /* 217 */
YY_RULE(int) yy_RefTitle(GREG *G); /* 216 */
YY_RULE(int) yy_RefSrc(GREG *G); /* 215 */
YY_RULE(int) yy_AutoLinkEmail(GREG *G); /* 214 */
YY_RULE(int) yy_AutoLinkUrl(GREG *G); /* 213 */
YY_RULE(int) yy_ImageSizeHeight(GREG *G); /* 212 */
YY_RULE(int) yy_ImageSizeWidth(GREG *G); /* 211 */
YY_RULE(int) yy_ImageSizeComplete(GREG *G); /* 210 */
YY_RULE(int) yy_TitleDoubleExt(GREG *G); /* 209 */
YY_RULE(int) yy_TitleSingleExt(GREG *G); /* 208 */
YY_RULE(int) yy_TitleDouble(GREG *G); /* 207 */
YY_RULE(int) yy_TitleSingle(GREG *G); /* 206 */
YY_RULE(int) yy_Nonspacechar(GREG *G); /* 205 */
YY_RULE(int) yy_SourceContents(GREG *G); /* 204 */
YY_RULE(int) yy_ImageSize(GREG *G); /* 203 */
YY_RULE(int) yy_TitleExt(GREG *G); /* 202 */
YY_RULE(int) yy_Title(GREG *G); /* 201 */
YY_RULE(int) yy_Source(GREG *G); /* 200 */
YY_RULE(int) yy_Label(GREG *G); /* 199 */
YY_RULE(int) yy_ReferenceLinkSingle(GREG *G); /* 198 */
YY_RULE(int) yy_ReferenceLinkDouble(GREG *G); /* 197 */
YY_RULE(int) yy_AutoLink(GREG *G); /* 196 */
YY_RULE(int) yy_ReferenceLink(GREG *G); /* 195 */
YY_RULE(int) yy_ExplicitLinkSize(GREG *G); /* 194 */
YY_RULE(int) yy_ExplicitLink(GREG *G); /* 193 */
YY_RULE(int) yy_StrongUl(GREG *G); /* 192 */
YY_RULE(int) yy_StrongStar(GREG *G); /* 191 */
YY_RULE(int) yy_Whitespace(GREG *G); /* 190 */
YY_RULE(int) yy_EmphUl(GREG *G); /* 189 */
YY_RULE(int) yy_EmphStar(GREG *G); /* 188 */
YY_RULE(int) yy_StarLine(GREG *G); /* 187 */
YY_RULE(int) yy_UlLine(GREG *G); /* 186 */
YY_RULE(int) yy_SpecialChar(GREG *G); /* 185 */
YY_RULE(int) yy_Eof(GREG *G); /* 184 */
YY_RULE(int) yy_NormalEndline(GREG *G); /* 183 */
YY_RULE(int) yy_TerminalEndline(GREG *G); /* 182 */
YY_RULE(int) yy_LineBreak(GREG *G); /* 181 */
YY_RULE(int) yy_CharEntity(GREG *G); /* 180 */
YY_RULE(int) yy_DecEntity(GREG *G); /* 179 */
YY_RULE(int) yy_HexEntity(GREG *G); /* 178 */
YY_RULE(int) yy_Alphanumeric(GREG *G); /* 177 */
YY_RULE(int) yy_NormalChar(GREG *G); /* 176 */
YY_RULE(int) yy_Symbol(GREG *G); /* 175 */
YY_RULE(int) yy_EscapedChar(GREG *G); /* 174 */
YY_RULE(int) yy_Entity(GREG *G); /* 173 */
YY_RULE(int) yy_RawHtml(GREG *G); /* 172 */
YY_RULE(int) yy_Code(GREG *G); /* 171 */
YY_RULE(int) yy_InlineNote(GREG *G); /* 170 */
YY_RULE(int) yy_NoteReference(GREG *G); /* 169 */
YY_RULE(int) yy_Link(GREG *G); /* 168 */
YY_RULE(int) yy_Image(GREG *G); /* 167 */
YY_RULE(int) yy_Strike(GREG *G); /* 166 */
YY_RULE(int) yy_Emph(GREG *G); /* 165 */
YY_RULE(int) yy_Strong(GREG *G); /* 164 */
YY_RULE(int) yy_UlOrStarLine(GREG *G); /* 163 */
YY_RULE(int) yy_Str(GREG *G); /* 162 */
YY_RULE(int) yy_InStyleTags(GREG *G); /* 161 */
YY_RULE(int) yy_StyleClose(GREG *G); /* 160 */
YY_RULE(int) yy_StyleOpen(GREG *G); /* 159 */
YY_RULE(int) yy_HtmlBlockType(GREG *G); /* 158 */
YY_RULE(int) yy_HtmlBlockSelfClosing(GREG *G); /* 157 */
YY_RULE(int) yy_HtmlComment(GREG *G); /* 156 */
YY_RULE(int) yy_HtmlBlockInTags(GREG *G); /* 155 */
YY_RULE(int) yy_HtmlBlockHead(GREG *G); /* 154 */
YY_RULE(int) yy_HtmlBlockCloseHead(GREG *G); /* 153 */
YY_RULE(int) yy_HtmlBlockOpenHead(GREG *G); /* 152 */
YY_RULE(int) yy_HtmlBlockScript(GREG *G); /* 151 */
YY_RULE(int) yy_HtmlBlockCloseScript(GREG *G); /* 150 */
YY_RULE(int) yy_HtmlBlockOpenScript(GREG *G); /* 149 */
YY_RULE(int) yy_HtmlBlockTr(GREG *G); /* 148 */
YY_RULE(int) yy_HtmlBlockCloseTr(GREG *G); /* 147 */
YY_RULE(int) yy_HtmlBlockOpenTr(GREG *G); /* 146 */
YY_RULE(int) yy_HtmlBlockThead(GREG *G); /* 145 */
YY_RULE(int) yy_HtmlBlockCloseThead(GREG *G); /* 144 */
YY_RULE(int) yy_HtmlBlockOpenThead(GREG *G); /* 143 */
YY_RULE(int) yy_HtmlBlockTh(GREG *G); /* 142 */
YY_RULE(int) yy_HtmlBlockCloseTh(GREG *G); /* 141 */
YY_RULE(int) yy_HtmlBlockOpenTh(GREG *G); /* 140 */
YY_RULE(int) yy_HtmlBlockTfoot(GREG *G); /* 139 */
YY_RULE(int) yy_HtmlBlockCloseTfoot(GREG *G); /* 138 */
YY_RULE(int) yy_HtmlBlockOpenTfoot(GREG *G); /* 137 */
YY_RULE(int) yy_HtmlBlockTd(GREG *G); /* 136 */
YY_RULE(int) yy_HtmlBlockCloseTd(GREG *G); /* 135 */
YY_RULE(int) yy_HtmlBlockOpenTd(GREG *G); /* 134 */
YY_RULE(int) yy_HtmlBlockTbody(GREG *G); /* 133 */
YY_RULE(int) yy_HtmlBlockCloseTbody(GREG *G); /* 132 */
YY_RULE(int) yy_HtmlBlockOpenTbody(GREG *G); /* 131 */
YY_RULE(int) yy_HtmlBlockLi(GREG *G); /* 130 */
YY_RULE(int) yy_HtmlBlockCloseLi(GREG *G); /* 129 */
YY_RULE(int) yy_HtmlBlockOpenLi(GREG *G); /* 128 */
YY_RULE(int) yy_HtmlBlockFrameset(GREG *G); /* 127 */
YY_RULE(int) yy_HtmlBlockCloseFrameset(GREG *G); /* 126 */
YY_RULE(int) yy_HtmlBlockOpenFrameset(GREG *G); /* 125 */
YY_RULE(int) yy_HtmlBlockDt(GREG *G); /* 124 */
YY_RULE(int) yy_HtmlBlockCloseDt(GREG *G); /* 123 */
YY_RULE(int) yy_HtmlBlockOpenDt(GREG *G); /* 122 */
YY_RULE(int) yy_HtmlBlockDd(GREG *G); /* 121 */
YY_RULE(int) yy_HtmlBlockCloseDd(GREG *G); /* 120 */
YY_RULE(int) yy_HtmlBlockOpenDd(GREG *G); /* 119 */
YY_RULE(int) yy_HtmlBlockUl(GREG *G); /* 118 */
YY_RULE(int) yy_HtmlBlockCloseUl(GREG *G); /* 117 */
YY_RULE(int) yy_HtmlBlockOpenUl(GREG *G); /* 116 */
YY_RULE(int) yy_HtmlBlockTable(GREG *G); /* 115 */
YY_RULE(int) yy_HtmlBlockCloseTable(GREG *G); /* 114 */
YY_RULE(int) yy_HtmlBlockOpenTable(GREG *G); /* 113 */
YY_RULE(int) yy_HtmlBlockPre(GREG *G); /* 112 */
YY_RULE(int) yy_HtmlBlockClosePre(GREG *G); /* 111 */
YY_RULE(int) yy_HtmlBlockOpenPre(GREG *G); /* 110 */
YY_RULE(int) yy_HtmlBlockP(GREG *G); /* 109 */
YY_RULE(int) yy_HtmlBlockCloseP(GREG *G); /* 108 */
YY_RULE(int) yy_HtmlBlockOpenP(GREG *G); /* 107 */
YY_RULE(int) yy_HtmlBlockOl(GREG *G); /* 106 */
YY_RULE(int) yy_HtmlBlockCloseOl(GREG *G); /* 105 */
YY_RULE(int) yy_HtmlBlockOpenOl(GREG *G); /* 104 */
YY_RULE(int) yy_HtmlBlockNoscript(GREG *G); /* 103 */
YY_RULE(int) yy_HtmlBlockCloseNoscript(GREG *G); /* 102 */
YY_RULE(int) yy_HtmlBlockOpenNoscript(GREG *G); /* 101 */
YY_RULE(int) yy_HtmlBlockNoframes(GREG *G); /* 100 */
YY_RULE(int) yy_HtmlBlockCloseNoframes(GREG *G); /* 99 */
YY_RULE(int) yy_HtmlBlockOpenNoframes(GREG *G); /* 98 */
YY_RULE(int) yy_HtmlBlockMenu(GREG *G); /* 97 */
YY_RULE(int) yy_HtmlBlockCloseMenu(GREG *G); /* 96 */
YY_RULE(int) yy_HtmlBlockOpenMenu(GREG *G); /* 95 */
YY_RULE(int) yy_HtmlBlockH6(GREG *G); /* 94 */
YY_RULE(int) yy_HtmlBlockCloseH6(GREG *G); /* 93 */
YY_RULE(int) yy_HtmlBlockOpenH6(GREG *G); /* 92 */
YY_RULE(int) yy_HtmlBlockH5(GREG *G); /* 91 */
YY_RULE(int) yy_HtmlBlockCloseH5(GREG *G); /* 90 */
YY_RULE(int) yy_HtmlBlockOpenH5(GREG *G); /* 89 */
YY_RULE(int) yy_HtmlBlockH4(GREG *G); /* 88 */
YY_RULE(int) yy_HtmlBlockCloseH4(GREG *G); /* 87 */
YY_RULE(int) yy_HtmlBlockOpenH4(GREG *G); /* 86 */
YY_RULE(int) yy_HtmlBlockH3(GREG *G); /* 85 */
YY_RULE(int) yy_HtmlBlockCloseH3(GREG *G); /* 84 */
YY_RULE(int) yy_HtmlBlockOpenH3(GREG *G); /* 83 */
YY_RULE(int) yy_HtmlBlockH2(GREG *G); /* 82 */
YY_RULE(int) yy_HtmlBlockCloseH2(GREG *G); /* 81 */
YY_RULE(int) yy_HtmlBlockOpenH2(GREG *G); /* 80 */
YY_RULE(int) yy_HtmlBlockH1(GREG *G); /* 79 */
YY_RULE(int) yy_HtmlBlockCloseH1(GREG *G); /* 78 */
YY_RULE(int) yy_HtmlBlockOpenH1(GREG *G); /* 77 */
YY_RULE(int) yy_HtmlBlockForm(GREG *G); /* 76 */
YY_RULE(int) yy_HtmlBlockCloseForm(GREG *G); /* 75 */
YY_RULE(int) yy_HtmlBlockOpenForm(GREG *G); /* 74 */
YY_RULE(int) yy_HtmlBlockFieldset(GREG *G); /* 73 */
YY_RULE(int) yy_HtmlBlockCloseFieldset(GREG *G); /* 72 */
YY_RULE(int) yy_HtmlBlockOpenFieldset(GREG *G); /* 71 */
YY_RULE(int) yy_HtmlBlockDl(GREG *G); /* 70 */
YY_RULE(int) yy_HtmlBlockCloseDl(GREG *G); /* 69 */
YY_RULE(int) yy_HtmlBlockOpenDl(GREG *G); /* 68 */
YY_RULE(int) yy_HtmlBlockDiv(GREG *G); /* 67 */
YY_RULE(int) yy_HtmlBlockCloseDiv(GREG *G); /* 66 */
YY_RULE(int) yy_HtmlBlockOpenDiv(GREG *G); /* 65 */
YY_RULE(int) yy_HtmlBlockDir(GREG *G); /* 64 */
YY_RULE(int) yy_HtmlBlockCloseDir(GREG *G); /* 63 */
YY_RULE(int) yy_HtmlBlockOpenDir(GREG *G); /* 62 */
YY_RULE(int) yy_HtmlBlockCenter(GREG *G); /* 61 */
YY_RULE(int) yy_HtmlBlockCloseCenter(GREG *G); /* 60 */
YY_RULE(int) yy_HtmlBlockOpenCenter(GREG *G); /* 59 */
YY_RULE(int) yy_HtmlBlockBlockquote(GREG *G); /* 58 */
YY_RULE(int) yy_HtmlBlockCloseBlockquote(GREG *G); /* 57 */
YY_RULE(int) yy_HtmlBlockOpenBlockquote(GREG *G); /* 56 */
YY_RULE(int) yy_HtmlBlockAddress(GREG *G); /* 55 */
YY_RULE(int) yy_HtmlBlockCloseAddress(GREG *G); /* 54 */
YY_RULE(int) yy_HtmlAttribute(GREG *G); /* 53 */
YY_RULE(int) yy_Spnl(GREG *G); /* 52 */
YY_RULE(int) yy_HtmlBlockOpenAddress(GREG *G); /* 51 */
YY_RULE(int) yy_OptionallyIndentedLine(GREG *G); /* 50 */
YY_RULE(int) yy_Indent(GREG *G); /* 49 */
YY_RULE(int) yy_ListBlockLine(GREG *G); /* 48 */
YY_RULE(int) yy_ListContinuationBlock(GREG *G); /* 47 */
YY_RULE(int) yy_ListBlock(GREG *G); /* 46 */
YY_RULE(int) yy_ListItem(GREG *G); /* 45 */
YY_RULE(int) yy_Enumerator(GREG *G); /* 44 */
YY_RULE(int) yy_ListItemTight(GREG *G); /* 43 */
YY_RULE(int) yy_ListLoose(GREG *G); /* 42 */
YY_RULE(int) yy_ListTight(GREG *G); /* 41 */
YY_RULE(int) yy_Spacechar(GREG *G); /* 40 */
YY_RULE(int) yy_Bullet(GREG *G); /* 39 */
YY_RULE(int) yy_VerbatimChunk(GREG *G); /* 38 */
YY_RULE(int) yy_IndentedLine(GREG *G); /* 37 */
YY_RULE(int) yy_NonblankIndentedLine(GREG *G); /* 36 */
YY_RULE(int) yy_Line(GREG *G); /* 35 */
YY_RULE(int) yy_StartList(GREG *G); /* 34 */
YY_RULE(int) yy_BlockQuoteRaw(GREG *G); /* 33 */
YY_RULE(int) yy_Endline(GREG *G); /* 32 */
YY_RULE(int) yy_RawLine(GREG *G); /* 31 */
YY_RULE(int) yy_SetextBottom2(GREG *G); /* 30 */
YY_RULE(int) yy_SetextBottom1(GREG *G); /* 29 */
YY_RULE(int) yy_SetextHeading2(GREG *G); /* 28 */
YY_RULE(int) yy_SetextHeading1(GREG *G); /* 27 */
YY_RULE(int) yy_SetextHeading(GREG *G); /* 26 */
YY_RULE(int) yy_Space(GREG *G); /* 25 */
YY_RULE(int) yy_AtxHeading(GREG *G); /* 24 */
YY_RULE(int) yy_AtxStart(GREG *G); /* 23 */
YY_RULE(int) yy_Inline(GREG *G); /* 22 */
YY_RULE(int) yy_Sp(GREG *G); /* 21 */
YY_RULE(int) yy_Newline(GREG *G); /* 20 */
YY_RULE(int) yy_AtxInline(GREG *G); /* 19 */
YY_RULE(int) yy_Inlines(GREG *G); /* 18 */
YY_RULE(int) yy_NonindentSpace(GREG *G); /* 17 */
YY_RULE(int) yy_Plain(GREG *G); /* 16 */
YY_RULE(int) yy_Para(GREG *G); /* 15 */
YY_RULE(int) yy_StyleBlock(GREG *G); /* 14 */
YY_RULE(int) yy_HtmlBlock(GREG *G); /* 13 */
YY_RULE(int) yy_BulletList(GREG *G); /* 12 */
YY_RULE(int) yy_OrderedList(GREG *G); /* 11 */
YY_RULE(int) yy_Heading(GREG *G); /* 10 */
YY_RULE(int) yy_HorizontalRule(GREG *G); /* 9 */
YY_RULE(int) yy_Reference(GREG *G); /* 8 */
YY_RULE(int) yy_Note(GREG *G); /* 7 */
YY_RULE(int) yy_Verbatim(GREG *G); /* 6 */
YY_RULE(int) yy_BlockQuote(GREG *G); /* 5 */
YY_RULE(int) yy_BlankLine(GREG *G); /* 4 */
YY_RULE(int) yy_LocMarker(GREG *G); /* 3 */
YY_RULE(int) yy_Block(GREG *G); /* 2 */
YY_RULE(int) yy_Doc(GREG *G); /* 1 */

YY_ACTION(void) yy_1_RawLine(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_RawLine\n"));
   yy = elem(pmh_RAW); ;
}
YY_ACTION(void) yy_1_Line(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Line\n"));
   yy = mk_element((parser_data *)G->data, pmh_RAW, yy->pos, yy->end); ;
}
YY_ACTION(void) yy_1_StartList(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_StartList\n"));
   yy = NULL; ;
}
YY_ACTION(void) yy_1_HtmlComment(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_HtmlComment\n"));
   ADD(elem_s(pmh_COMMENT)); ;
#undef s
}
YY_ACTION(void) yy_1_RawHtml(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_RawHtml\n"));
   ADD(elem_s(pmh_HTML)); ;
#undef s
}
YY_ACTION(void) yy_1_Code(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_Code\n"));
   ADD(elem_s(pmh_CODE)); ;
#undef s
}
YY_ACTION(void) yy_1_Ticks5(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Ticks5\n"));
   yy = elem(pmh_NO_TYPE); ;
}
YY_ACTION(void) yy_1_Ticks4(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Ticks4\n"));
   yy = elem(pmh_NO_TYPE); ;
}
YY_ACTION(void) yy_1_Ticks3(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Ticks3\n"));
   yy = elem(pmh_NO_TYPE); ;
}
YY_ACTION(void) yy_1_Ticks2(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Ticks2\n"));
   yy = elem(pmh_NO_TYPE); ;
}
YY_ACTION(void) yy_1_Ticks1(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Ticks1\n"));
   yy = elem(pmh_NO_TYPE); ;
}
YY_ACTION(void) yy_1_RefSrc(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_RefSrc\n"));
   yy = mk_notype; yy->address = COPY_YYTEXT_ORIG(); ;
}
YY_ACTION(void) yy_2_Label(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_2_Label\n"));
  
            s->pos = s->pos;
            s->end = thunk->end;
            yy = s;
        ;
#undef s
}
YY_ACTION(void) yy_1_Label(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_Label\n"));
   s->label = COPY_YYTEXT_ORIG(); ;
#undef s
}
YY_ACTION(void) yy_1_Reference(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define r G->val[-1]
#define l G->val[-2]
#define s G->val[-3]
  yyprintf((stderr, "do yy_1_Reference\n"));
  
                pmh_realelement *el = elem_s(pmh_REFERENCE);
                el->label = strdup_or_null(l->label);
                el->address = strdup_or_null(r->address);
                ADD(el);
                FREE_LABEL(l);
                FREE_ADDRESS(r);
              ;
#undef r
#undef l
#undef s
}
YY_ACTION(void) yy_3_AutoLinkEmail(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_3_AutoLinkEmail\n"));
  
                s->end = thunk->end;
                ADD(s);
               ;
#undef s
}
YY_ACTION(void) yy_2_AutoLinkEmail(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_2_AutoLinkEmail\n"));
   s->address = COPY_YYTEXT_ORIG(); ;
#undef s
}
YY_ACTION(void) yy_1_AutoLinkEmail(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_AutoLinkEmail\n"));
   s->type = pmh_AUTO_LINK_EMAIL; ;
#undef s
}
YY_ACTION(void) yy_3_AutoLinkUrl(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_3_AutoLinkUrl\n"));
  
                s->end = thunk->end;
                ADD(s);
               ;
#undef s
}
YY_ACTION(void) yy_2_AutoLinkUrl(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_2_AutoLinkUrl\n"));
   s->address = COPY_YYTEXT_ORIG(); ;
#undef s
}
YY_ACTION(void) yy_1_AutoLinkUrl(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_AutoLinkUrl\n"));
   s->type = pmh_AUTO_LINK_URL; ;
#undef s
}
YY_ACTION(void) yy_3_Source(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_3_Source\n"));
   yy->address = COPY_YYTEXT_ORIG(); ;
}
YY_ACTION(void) yy_2_Source(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_2_Source\n"));
   yy->address = COPY_YYTEXT_ORIG(); ;
}
YY_ACTION(void) yy_1_Source(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Source\n"));
   yy = mk_notype; ;
}
YY_ACTION(void) yy_1_ExplicitLinkSize(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define l G->val[-1]
#define s G->val[-2]
  yyprintf((stderr, "do yy_1_ExplicitLinkSize\n"));
  
                        yy = elem_s(pmh_LINK);
                        if (l->address != NULL)
                            yy->address = strdup_or_null(l->address);
                        FREE_LABEL(s);
                        FREE_ADDRESS(l);
                    ;
#undef l
#undef s
}
YY_ACTION(void) yy_1_ExplicitLink(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define l G->val[-1]
#define s G->val[-2]
  yyprintf((stderr, "do yy_1_ExplicitLink\n"));
  
                    yy = elem_s(pmh_LINK);
                    if (l->address != NULL)
                        yy->address = strdup_or_null(l->address);
                    FREE_LABEL(s);
                    FREE_ADDRESS(l);
                ;
#undef l
#undef s
}
YY_ACTION(void) yy_1_ReferenceLinkSingle(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_ReferenceLinkSingle\n"));
  
                        	pmh_realelement *reference = GET_REF(s->label);
                            if (reference) {
                                yy = elem_s(pmh_LINK);
                                yy->label = strdup_or_null(s->label);
                                yy->address = strdup_or_null(reference->address);
                            } else
                                yy = NULL;
                            FREE_LABEL(s);
                        ;
#undef s
}
YY_ACTION(void) yy_1_ReferenceLinkDouble(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define l G->val[-1]
#define s G->val[-2]
  yyprintf((stderr, "do yy_1_ReferenceLinkDouble\n"));
  
                        	pmh_realelement *reference = GET_REF(l->label);
                            if (reference) {
                                yy = elem_s(pmh_LINK);
                                yy->label = strdup_or_null(l->label);
                                yy->address = strdup_or_null(reference->address);
                            } else
                                yy = NULL;
                            FREE_LABEL(s);
                            FREE_LABEL(l);
                        ;
#undef l
#undef s
}
YY_ACTION(void) yy_1_Link(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Link\n"));
   if (yy) ADD(yy); ;
}
YY_ACTION(void) yy_1_Image(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Image\n"));
  
            if (yy != NULL) {
                yy->type = pmh_IMAGE;
                yy->pos -= 1;
                ADD(yy);
            }
        ;
}
YY_ACTION(void) yy_1_Strike(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_Strike\n"));
   ADD(elem_s(pmh_STRIKE)); ;
#undef s
}
YY_ACTION(void) yy_1_StrongUl(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_StrongUl\n"));
   ADD(elem_s(pmh_STRONG)); ;
#undef s
}
YY_ACTION(void) yy_1_StrongStar(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_StrongStar\n"));
   ADD(elem_s(pmh_STRONG)); ;
#undef s
}
YY_ACTION(void) yy_1_EmphUl(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_EmphUl\n"));
   ADD(elem_s(pmh_EMPH)); ;
#undef s
}
YY_ACTION(void) yy_1_EmphStar(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_EmphStar\n"));
   ADD(elem_s(pmh_EMPH)); ;
#undef s
}
YY_ACTION(void) yy_1_Entity(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_Entity\n"));
   ADD(elem_s(pmh_HTML_ENTITY)); ;
#undef s
}
YY_ACTION(void) yy_1_StyleBlock(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_StyleBlock\n"));
   ADD(elem_s(pmh_HTMLBLOCK)); ;
#undef s
}
YY_ACTION(void) yy_1_HtmlBlock(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_HtmlBlock\n"));
   ADD(elem_s(pmh_HTMLBLOCK)); ;
#undef s
}
YY_ACTION(void) yy_1_HtmlBlockH6(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_HtmlBlockH6\n"));
   ADD(elem_s(pmh_H6)); ;
#undef s
}
YY_ACTION(void) yy_1_HtmlBlockH5(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_HtmlBlockH5\n"));
   ADD(elem_s(pmh_H5)); ;
#undef s
}
YY_ACTION(void) yy_1_HtmlBlockH4(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_HtmlBlockH4\n"));
   ADD(elem_s(pmh_H4)); ;
#undef s
}
YY_ACTION(void) yy_1_HtmlBlockH3(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_HtmlBlockH3\n"));
   ADD(elem_s(pmh_H3)); ;
#undef s
}
YY_ACTION(void) yy_1_HtmlBlockH2(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_HtmlBlockH2\n"));
   ADD(elem_s(pmh_H2)); ;
#undef s
}
YY_ACTION(void) yy_1_HtmlBlockH1(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_HtmlBlockH1\n"));
   ADD(elem_s(pmh_H1)); ;
#undef s
}
YY_ACTION(void) yy_1_Enumerator(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Enumerator\n"));
   ADD(elem(pmh_LIST_ENUMERATOR)); ;
}
YY_ACTION(void) yy_3_ListContinuationBlock(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_3_ListContinuationBlock\n"));
   yy = a; ;
#undef a
}
YY_ACTION(void) yy_2_ListContinuationBlock(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_2_ListContinuationBlock\n"));
   a = cons(yy, a); ;
#undef a
}
YY_ACTION(void) yy_1_ListContinuationBlock(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_1_ListContinuationBlock\n"));
   if (*yytext == '\0') /* if strlen(yytext) == 0 */
                                a = cons(elem(pmh_SEPARATOR), a);
                            else
                                a = cons(elem(pmh_RAW), a);
                          ;
#undef a
}
YY_ACTION(void) yy_3_ListBlock(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_3_ListBlock\n"));
   yy = a; ;
#undef a
}
YY_ACTION(void) yy_2_ListBlock(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_2_ListBlock\n"));
   a = cons(elem(pmh_RAW), a); ;
#undef a
}
YY_ACTION(void) yy_1_ListBlock(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_1_ListBlock\n"));
   a = cons(yy, a); ;
#undef a
}
YY_ACTION(void) yy_3_ListItemTight(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_3_ListItemTight\n"));
   yy = a; ;
#undef a
}
YY_ACTION(void) yy_2_ListItemTight(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_2_ListItemTight\n"));
   a = cons(yy, a); ;
#undef a
}
YY_ACTION(void) yy_1_ListItemTight(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_1_ListItemTight\n"));
   a = cons(yy, a); ;
#undef a
}
YY_ACTION(void) yy_3_ListItem(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_3_ListItem\n"));
   yy = a; ;
#undef a
}
YY_ACTION(void) yy_2_ListItem(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_2_ListItem\n"));
   a = cons(yy, a); ;
#undef a
}
YY_ACTION(void) yy_1_ListItem(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_1_ListItem\n"));
   a = cons(yy, a); ;
#undef a
}
YY_ACTION(void) yy_2_ListLoose(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define b G->val[-1]
#define a G->val[-2]
  yyprintf((stderr, "do yy_2_ListLoose\n"));
   pmh_realelement *cur = a;
              while (cur != NULL) {
                  pmh_realelement *rawlist = mk_element((parser_data *)G->data, pmh_RAW_LIST, 0,0);
                  rawlist->children = reverse(cur->children);
                  ADD(rawlist);
                  cur = cur->next;
              }
            ;
#undef b
#undef a
}
YY_ACTION(void) yy_1_ListLoose(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define b G->val[-1]
#define a G->val[-2]
  yyprintf((stderr, "do yy_1_ListLoose\n"));
   b = cons(etext("\n\n"), b); /* In loose list, \n\n added to end of each element */
                pmh_realelement *el = mk_notype;
                el->children = b;
                a = cons(el, a);
              ;
#undef b
#undef a
}
YY_ACTION(void) yy_2_ListTight(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_2_ListTight\n"));
   pmh_realelement *cur = a;
              while (cur != NULL) {
                  pmh_realelement *rawlist = mk_element((parser_data *)G->data, pmh_RAW_LIST, 0,0);
                  rawlist->children = reverse(cur->children);
                  ADD(rawlist);
                  cur = cur->next;
              }
            ;
#undef a
}
YY_ACTION(void) yy_1_ListTight(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_1_ListTight\n"));
   pmh_realelement *el = mk_notype;
                el->children = yy;
                a = cons(el, a);
              ;
#undef a
}
YY_ACTION(void) yy_1_Bullet(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Bullet\n"));
   ADD(elem(pmh_LIST_BULLET)); ;
}
YY_ACTION(void) yy_1_HorizontalRule(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_HorizontalRule\n"));
   ADD(elem(pmh_HRULE)); ;
}
YY_ACTION(void) yy_1_Verbatim(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_Verbatim\n"));
   ADD(elem_s(pmh_VERBATIM)); ;
#undef s
}
YY_ACTION(void) yy_5_BlockQuoteRaw(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_5_BlockQuoteRaw\n"));
   yy = a; ;
#undef a
}
YY_ACTION(void) yy_4_BlockQuoteRaw(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_4_BlockQuoteRaw\n"));
   a = cons(etext("\n"), a); ;
#undef a
}
YY_ACTION(void) yy_3_BlockQuoteRaw(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_3_BlockQuoteRaw\n"));
   a = cons(yy, a); ;
#undef a
}
YY_ACTION(void) yy_2_BlockQuoteRaw(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_2_BlockQuoteRaw\n"));
   a = cons(yy, a); ;
#undef a
}
YY_ACTION(void) yy_1_BlockQuoteRaw(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_1_BlockQuoteRaw\n"));
   ADD(elem(pmh_BLOCKQUOTE)); ;
#undef a
}
YY_ACTION(void) yy_1_BlockQuote(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_1_BlockQuote\n"));
   pmh_realelement *rawlist = mk_element((parser_data *)G->data, pmh_RAW_LIST, 0,0);
              rawlist->children = reverse(a);
              ADD(rawlist);
            ;
#undef a
}
YY_ACTION(void) yy_1_SetextHeading2(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_SetextHeading2\n"));
   ADD(elem_s(pmh_H2)); ;
#undef s
}
YY_ACTION(void) yy_1_SetextHeading1(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_SetextHeading1\n"));
   ADD(elem_s(pmh_H1)); ;
#undef s
}
YY_ACTION(void) yy_1_AtxHeading(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_AtxHeading\n"));
   ADD(elem_s(s->type)); ;
#undef s
}
YY_ACTION(void) yy_1_AtxStart(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_AtxStart\n"));
   yy = elem((pmh_element_type)(pmh_H1 + (strlen(yytext) - 1))); ;
}
YY_ACTION(void) yy_1_LocMarker(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_LocMarker\n"));
   yy = elem(pmh_NO_TYPE); ;
}

YY_RULE(int) yy_RawNoteBlock(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "RawNoteBlock"));
  {  int yypos4= G->pos, yythunkpos4= G->thunkpos;  if (!yy_BlankLine(G)) { goto l4; }  goto l1;
  l4:;	  G->pos= yypos4; G->thunkpos= yythunkpos4;
  }  if (!yy_OptionallyIndentedLine(G)) { goto l1; }
  l2:;	
  {  int yypos3= G->pos, yythunkpos3= G->thunkpos;
  {  int yypos5= G->pos, yythunkpos5= G->thunkpos;  if (!yy_BlankLine(G)) { goto l5; }  goto l3;
  l5:;	  G->pos= yypos5; G->thunkpos= yythunkpos5;
  }  if (!yy_OptionallyIndentedLine(G)) { goto l3; }  goto l2;
  l3:;	  G->pos= yypos3; G->thunkpos= yythunkpos3;
  }
  l6:;	
  {  int yypos7= G->pos, yythunkpos7= G->thunkpos;  if (!yy_BlankLine(G)) { goto l7; }  goto l6;
  l7:;	  G->pos= yypos7; G->thunkpos= yythunkpos7;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "RawNoteBlock", G->buf+G->pos));
  return 1;
  l1:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "RawNoteBlock", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_RawNoteReference(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "RawNoteReference"));  if (!yymatchString(G, "[^")) goto l8;
  {  int yypos11= G->pos, yythunkpos11= G->thunkpos;  if (!yy_Newline(G)) { goto l11; }  goto l8;
  l11:;	  G->pos= yypos11; G->thunkpos= yythunkpos11;
  }
  {  int yypos12= G->pos, yythunkpos12= G->thunkpos;  if (!yymatchChar(G, ']')) goto l12;  goto l8;
  l12:;	  G->pos= yypos12; G->thunkpos= yythunkpos12;
  }  if (!yymatchDot(G)) goto l8;
  l9:;	
  {  int yypos10= G->pos, yythunkpos10= G->thunkpos;
  {  int yypos13= G->pos, yythunkpos13= G->thunkpos;  if (!yy_Newline(G)) { goto l13; }  goto l10;
  l13:;	  G->pos= yypos13; G->thunkpos= yythunkpos13;
  }
  {  int yypos14= G->pos, yythunkpos14= G->thunkpos;  if (!yymatchChar(G, ']')) goto l14;  goto l10;
  l14:;	  G->pos= yypos14; G->thunkpos= yythunkpos14;
  }  if (!yymatchDot(G)) goto l10;  goto l9;
  l10:;	  G->pos= yypos10; G->thunkpos= yythunkpos10;
  }  if (!yymatchChar(G, ']')) goto l8;
  yyprintf((stderr, "  ok   %s @ %s\n", "RawNoteReference", G->buf+G->pos));
  return 1;
  l8:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "RawNoteReference", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ExtendedSpecialChar(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "ExtendedSpecialChar"));  yyText(G, G->begin, G->end);  if (!( EXT(pmh_EXT_NOTES) )) goto l15;  if (!yymatchChar(G, '^')) goto l15;
  yyprintf((stderr, "  ok   %s @ %s\n", "ExtendedSpecialChar", G->buf+G->pos));
  return 1;
  l15:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ExtendedSpecialChar", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_AlphanumericAscii(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "AlphanumericAscii"));  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\376\377\377\007\376\377\377\007\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l16;
  yyprintf((stderr, "  ok   %s @ %s\n", "AlphanumericAscii", G->buf+G->pos));
  return 1;
  l16:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "AlphanumericAscii", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Quoted(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Quoted"));
  {  int yypos18= G->pos, yythunkpos18= G->thunkpos;  if (!yymatchChar(G, '"')) goto l19;
  l20:;	
  {  int yypos21= G->pos, yythunkpos21= G->thunkpos;
  {  int yypos22= G->pos, yythunkpos22= G->thunkpos;  if (!yymatchChar(G, '"')) goto l22;  goto l21;
  l22:;	  G->pos= yypos22; G->thunkpos= yythunkpos22;
  }  if (!yymatchDot(G)) goto l21;  goto l20;
  l21:;	  G->pos= yypos21; G->thunkpos= yythunkpos21;
  }  if (!yymatchChar(G, '"')) goto l19;  goto l18;
  l19:;	  G->pos= yypos18; G->thunkpos= yythunkpos18;  if (!yymatchChar(G, '\'')) goto l17;
  l23:;	
  {  int yypos24= G->pos, yythunkpos24= G->thunkpos;
  {  int yypos25= G->pos, yythunkpos25= G->thunkpos;  if (!yymatchChar(G, '\'')) goto l25;  goto l24;
  l25:;	  G->pos= yypos25; G->thunkpos= yythunkpos25;
  }  if (!yymatchDot(G)) goto l24;  goto l23;
  l24:;	  G->pos= yypos24; G->thunkpos= yythunkpos24;
  }  if (!yymatchChar(G, '\'')) goto l17;
  }
  l18:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Quoted", G->buf+G->pos));
  return 1;
  l17:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Quoted", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlTag(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlTag"));  if (!yymatchChar(G, '<')) goto l26;  if (!yy_Spnl(G)) { goto l26; }
  {  int yypos27= G->pos, yythunkpos27= G->thunkpos;  if (!yymatchChar(G, '/')) goto l27;  goto l28;
  l27:;	  G->pos= yypos27; G->thunkpos= yythunkpos27;
  }
  l28:;	  if (!yy_AlphanumericAscii(G)) { goto l26; }
  l29:;	
  {  int yypos30= G->pos, yythunkpos30= G->thunkpos;  if (!yy_AlphanumericAscii(G)) { goto l30; }  goto l29;
  l30:;	  G->pos= yypos30; G->thunkpos= yythunkpos30;
  }  if (!yy_Spnl(G)) { goto l26; }
  l31:;	
  {  int yypos32= G->pos, yythunkpos32= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l32; }  goto l31;
  l32:;	  G->pos= yypos32; G->thunkpos= yythunkpos32;
  }
  {  int yypos33= G->pos, yythunkpos33= G->thunkpos;  if (!yymatchChar(G, '/')) goto l33;  goto l34;
  l33:;	  G->pos= yypos33; G->thunkpos= yythunkpos33;
  }
  l34:;	  if (!yy_Spnl(G)) { goto l26; }  if (!yymatchChar(G, '>')) goto l26;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlTag", G->buf+G->pos));
  return 1;
  l26:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlTag", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Ticks5(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Ticks5"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l35;  if (!yymatchString(G, "`````")) goto l35;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l35;
  {  int yypos36= G->pos, yythunkpos36= G->thunkpos;  if (!yymatchChar(G, '`')) goto l36;  goto l35;
  l36:;	  G->pos= yypos36; G->thunkpos= yythunkpos36;
  }  yyDo(G, yy_1_Ticks5, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Ticks5", G->buf+G->pos));
  return 1;
  l35:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Ticks5", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Ticks4(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Ticks4"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l37;  if (!yymatchString(G, "````")) goto l37;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l37;
  {  int yypos38= G->pos, yythunkpos38= G->thunkpos;  if (!yymatchChar(G, '`')) goto l38;  goto l37;
  l38:;	  G->pos= yypos38; G->thunkpos= yythunkpos38;
  }  yyDo(G, yy_1_Ticks4, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Ticks4", G->buf+G->pos));
  return 1;
  l37:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Ticks4", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Ticks3(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Ticks3"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l39;  if (!yymatchString(G, "```")) goto l39;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l39;
  {  int yypos40= G->pos, yythunkpos40= G->thunkpos;  if (!yymatchChar(G, '`')) goto l40;  goto l39;
  l40:;	  G->pos= yypos40; G->thunkpos= yythunkpos40;
  }  yyDo(G, yy_1_Ticks3, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Ticks3", G->buf+G->pos));
  return 1;
  l39:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Ticks3", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Ticks2(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Ticks2"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l41;  if (!yymatchString(G, "``")) goto l41;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l41;
  {  int yypos42= G->pos, yythunkpos42= G->thunkpos;  if (!yymatchChar(G, '`')) goto l42;  goto l41;
  l42:;	  G->pos= yypos42; G->thunkpos= yythunkpos42;
  }  yyDo(G, yy_1_Ticks2, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Ticks2", G->buf+G->pos));
  return 1;
  l41:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Ticks2", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Ticks1(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Ticks1"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l43;  if (!yymatchChar(G, '`')) goto l43;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l43;
  {  int yypos44= G->pos, yythunkpos44= G->thunkpos;  if (!yymatchChar(G, '`')) goto l44;  goto l43;
  l44:;	  G->pos= yypos44; G->thunkpos= yythunkpos44;
  }  yyDo(G, yy_1_Ticks1, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Ticks1", G->buf+G->pos));
  return 1;
  l43:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Ticks1", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_SkipBlock(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "SkipBlock"));
  {  int yypos46= G->pos, yythunkpos46= G->thunkpos;
  {  int yypos50= G->pos, yythunkpos50= G->thunkpos;  if (!yy_BlankLine(G)) { goto l50; }  goto l47;
  l50:;	  G->pos= yypos50; G->thunkpos= yythunkpos50;
  }  if (!yy_RawLine(G)) { goto l47; }
  l48:;	
  {  int yypos49= G->pos, yythunkpos49= G->thunkpos;
  {  int yypos51= G->pos, yythunkpos51= G->thunkpos;  if (!yy_BlankLine(G)) { goto l51; }  goto l49;
  l51:;	  G->pos= yypos51; G->thunkpos= yythunkpos51;
  }  if (!yy_RawLine(G)) { goto l49; }  goto l48;
  l49:;	  G->pos= yypos49; G->thunkpos= yythunkpos49;
  }
  l52:;	
  {  int yypos53= G->pos, yythunkpos53= G->thunkpos;  if (!yy_BlankLine(G)) { goto l53; }  goto l52;
  l53:;	  G->pos= yypos53; G->thunkpos= yythunkpos53;
  }  goto l46;
  l47:;	  G->pos= yypos46; G->thunkpos= yythunkpos46;  if (!yy_BlankLine(G)) { goto l45; }
  l54:;	
  {  int yypos55= G->pos, yythunkpos55= G->thunkpos;  if (!yy_BlankLine(G)) { goto l55; }  goto l54;
  l55:;	  G->pos= yypos55; G->thunkpos= yythunkpos55;
  }
  }
  l46:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "SkipBlock", G->buf+G->pos));
  return 1;
  l45:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "SkipBlock", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_References(GREG *G)
{
  yyprintf((stderr, "%s\n", "References"));
  l57:;	
  {  int yypos58= G->pos, yythunkpos58= G->thunkpos;
  {  int yypos59= G->pos, yythunkpos59= G->thunkpos;  if (!yy_Reference(G)) { goto l60; }  goto l59;
  l60:;	  G->pos= yypos59; G->thunkpos= yythunkpos59;  if (!yy_SkipBlock(G)) { goto l58; }
  }
  l59:;	  goto l57;
  l58:;	  G->pos= yypos58; G->thunkpos= yythunkpos58;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "References", G->buf+G->pos));
  return 1;
}
YY_RULE(int) yy_EmptyTitle(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "EmptyTitle"));  if (!yymatchString(G, "")) goto l61;
  yyprintf((stderr, "  ok   %s @ %s\n", "EmptyTitle", G->buf+G->pos));
  return 1;
  l61:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "EmptyTitle", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_RefTitleParens(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "RefTitleParens"));  if (!yy_Spnl(G)) { goto l62; }  if (!yymatchChar(G, '(')) goto l62;
  l63:;	
  {  int yypos64= G->pos, yythunkpos64= G->thunkpos;
  {  int yypos65= G->pos, yythunkpos65= G->thunkpos;
  {  int yypos66= G->pos, yythunkpos66= G->thunkpos;  if (!yymatchChar(G, ')')) goto l67;  if (!yy_Sp(G)) { goto l67; }  if (!yy_Newline(G)) { goto l67; }  goto l66;
  l67:;	  G->pos= yypos66; G->thunkpos= yythunkpos66;  if (!yy_Newline(G)) { goto l65; }
  }
  l66:;	  goto l64;
  l65:;	  G->pos= yypos65; G->thunkpos= yythunkpos65;
  }  if (!yymatchDot(G)) goto l64;  goto l63;
  l64:;	  G->pos= yypos64; G->thunkpos= yythunkpos64;
  }  if (!yymatchChar(G, ')')) goto l62;
  yyprintf((stderr, "  ok   %s @ %s\n", "RefTitleParens", G->buf+G->pos));
  return 1;
  l62:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "RefTitleParens", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_RefTitleDouble(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "RefTitleDouble"));  if (!yy_Spnl(G)) { goto l68; }  if (!yymatchChar(G, '"')) goto l68;
  l69:;	
  {  int yypos70= G->pos, yythunkpos70= G->thunkpos;
  {  int yypos71= G->pos, yythunkpos71= G->thunkpos;
  {  int yypos72= G->pos, yythunkpos72= G->thunkpos;  if (!yymatchChar(G, '"')) goto l73;  if (!yy_Sp(G)) { goto l73; }  if (!yy_Newline(G)) { goto l73; }  goto l72;
  l73:;	  G->pos= yypos72; G->thunkpos= yythunkpos72;  if (!yy_Newline(G)) { goto l71; }
  }
  l72:;	  goto l70;
  l71:;	  G->pos= yypos71; G->thunkpos= yythunkpos71;
  }  if (!yymatchDot(G)) goto l70;  goto l69;
  l70:;	  G->pos= yypos70; G->thunkpos= yythunkpos70;
  }  if (!yymatchChar(G, '"')) goto l68;
  yyprintf((stderr, "  ok   %s @ %s\n", "RefTitleDouble", G->buf+G->pos));
  return 1;
  l68:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "RefTitleDouble", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_RefTitleSingle(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "RefTitleSingle"));  if (!yy_Spnl(G)) { goto l74; }  if (!yymatchChar(G, '\'')) goto l74;
  l75:;	
  {  int yypos76= G->pos, yythunkpos76= G->thunkpos;
  {  int yypos77= G->pos, yythunkpos77= G->thunkpos;
  {  int yypos78= G->pos, yythunkpos78= G->thunkpos;  if (!yymatchChar(G, '\'')) goto l79;  if (!yy_Sp(G)) { goto l79; }  if (!yy_Newline(G)) { goto l79; }  goto l78;
  l79:;	  G->pos= yypos78; G->thunkpos= yythunkpos78;  if (!yy_Newline(G)) { goto l77; }
  }
  l78:;	  goto l76;
  l77:;	  G->pos= yypos77; G->thunkpos= yythunkpos77;
  }  if (!yymatchDot(G)) goto l76;  goto l75;
  l76:;	  G->pos= yypos76; G->thunkpos= yythunkpos76;
  }  if (!yymatchChar(G, '\'')) goto l74;
  yyprintf((stderr, "  ok   %s @ %s\n", "RefTitleSingle", G->buf+G->pos));
  return 1;
  l74:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "RefTitleSingle", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_RefTitle(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "RefTitle"));
  {  int yypos81= G->pos, yythunkpos81= G->thunkpos;  if (!yy_RefTitleSingle(G)) { goto l82; }  goto l81;
  l82:;	  G->pos= yypos81; G->thunkpos= yythunkpos81;  if (!yy_RefTitleDouble(G)) { goto l83; }  goto l81;
  l83:;	  G->pos= yypos81; G->thunkpos= yythunkpos81;  if (!yy_RefTitleParens(G)) { goto l84; }  goto l81;
  l84:;	  G->pos= yypos81; G->thunkpos= yythunkpos81;  if (!yy_EmptyTitle(G)) { goto l80; }
  }
  l81:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "RefTitle", G->buf+G->pos));
  return 1;
  l80:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "RefTitle", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_RefSrc(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "RefSrc"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l85;  if (!yy_Nonspacechar(G)) { goto l85; }
  l86:;	
  {  int yypos87= G->pos, yythunkpos87= G->thunkpos;  if (!yy_Nonspacechar(G)) { goto l87; }  goto l86;
  l87:;	  G->pos= yypos87; G->thunkpos= yythunkpos87;
  }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l85;  yyDo(G, yy_1_RefSrc, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "RefSrc", G->buf+G->pos));
  return 1;
  l85:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "RefSrc", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_AutoLinkEmail(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "AutoLinkEmail"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l88;  if (!yy_LocMarker(G)) { goto l88; }  yyDo(G, yySet, -1, 0);  yyDo(G, yy_1_AutoLinkEmail, G->begin, G->end);  if (!yymatchChar(G, '<')) goto l88;
  {  int yypos89= G->pos, yythunkpos89= G->thunkpos;  if (!yymatchString(G, "mailto:")) goto l89;  goto l90;
  l89:;	  G->pos= yypos89; G->thunkpos= yythunkpos89;
  }
  l90:;	  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l88;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\062\350\377\003\376\377\377\207\376\377\377\107\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l88;
  l91:;	
  {  int yypos92= G->pos, yythunkpos92= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\062\350\377\003\376\377\377\207\376\377\377\107\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l92;  goto l91;
  l92:;	  G->pos= yypos92; G->thunkpos= yythunkpos92;
  }  if (!yymatchChar(G, '@')) goto l88;
  {  int yypos95= G->pos, yythunkpos95= G->thunkpos;  if (!yy_Newline(G)) { goto l95; }  goto l88;
  l95:;	  G->pos= yypos95; G->thunkpos= yythunkpos95;
  }
  {  int yypos96= G->pos, yythunkpos96= G->thunkpos;  if (!yymatchChar(G, '>')) goto l96;  goto l88;
  l96:;	  G->pos= yypos96; G->thunkpos= yythunkpos96;
  }  if (!yymatchDot(G)) goto l88;
  l93:;	
  {  int yypos94= G->pos, yythunkpos94= G->thunkpos;
  {  int yypos97= G->pos, yythunkpos97= G->thunkpos;  if (!yy_Newline(G)) { goto l97; }  goto l94;
  l97:;	  G->pos= yypos97; G->thunkpos= yythunkpos97;
  }
  {  int yypos98= G->pos, yythunkpos98= G->thunkpos;  if (!yymatchChar(G, '>')) goto l98;  goto l94;
  l98:;	  G->pos= yypos98; G->thunkpos= yythunkpos98;
  }  if (!yymatchDot(G)) goto l94;  goto l93;
  l94:;	  G->pos= yypos94; G->thunkpos= yythunkpos94;
  }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l88;  yyDo(G, yy_2_AutoLinkEmail, G->begin, G->end);  if (!yymatchChar(G, '>')) goto l88;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l88;  yyDo(G, yy_3_AutoLinkEmail, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "AutoLinkEmail", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l88:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "AutoLinkEmail", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_AutoLinkUrl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "AutoLinkUrl"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l99;  if (!yy_LocMarker(G)) { goto l99; }  yyDo(G, yySet, -1, 0);  yyDo(G, yy_1_AutoLinkUrl, G->begin, G->end);  if (!yymatchChar(G, '<')) goto l99;  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l99;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\000\000\376\377\377\007\376\377\377\007\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l99;
  l100:;	
  {  int yypos101= G->pos, yythunkpos101= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\000\000\376\377\377\007\376\377\377\007\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l101;  goto l100;
  l101:;	  G->pos= yypos101; G->thunkpos= yythunkpos101;
  }  if (!yymatchString(G, "://")) goto l99;
  {  int yypos104= G->pos, yythunkpos104= G->thunkpos;  if (!yy_Newline(G)) { goto l104; }  goto l99;
  l104:;	  G->pos= yypos104; G->thunkpos= yythunkpos104;
  }
  {  int yypos105= G->pos, yythunkpos105= G->thunkpos;  if (!yymatchChar(G, '>')) goto l105;  goto l99;
  l105:;	  G->pos= yypos105; G->thunkpos= yythunkpos105;
  }  if (!yymatchDot(G)) goto l99;
  l102:;	
  {  int yypos103= G->pos, yythunkpos103= G->thunkpos;
  {  int yypos106= G->pos, yythunkpos106= G->thunkpos;  if (!yy_Newline(G)) { goto l106; }  goto l103;
  l106:;	  G->pos= yypos106; G->thunkpos= yythunkpos106;
  }
  {  int yypos107= G->pos, yythunkpos107= G->thunkpos;  if (!yymatchChar(G, '>')) goto l107;  goto l103;
  l107:;	  G->pos= yypos107; G->thunkpos= yythunkpos107;
  }  if (!yymatchDot(G)) goto l103;  goto l102;
  l103:;	  G->pos= yypos103; G->thunkpos= yythunkpos103;
  }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l99;  yyDo(G, yy_2_AutoLinkUrl, G->begin, G->end);  if (!yymatchChar(G, '>')) goto l99;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l99;  yyDo(G, yy_3_AutoLinkUrl, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "AutoLinkUrl", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l99:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "AutoLinkUrl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ImageSizeHeight(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "ImageSizeHeight"));  if (!yymatchString(G, "=x")) goto l108;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l108;
  l109:;	
  {  int yypos110= G->pos, yythunkpos110= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l110;  goto l109;
  l110:;	  G->pos= yypos110; G->thunkpos= yythunkpos110;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "ImageSizeHeight", G->buf+G->pos));
  return 1;
  l108:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ImageSizeHeight", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ImageSizeWidth(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "ImageSizeWidth"));  if (!yymatchChar(G, '=')) goto l111;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l111;
  l112:;	
  {  int yypos113= G->pos, yythunkpos113= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l113;  goto l112;
  l113:;	  G->pos= yypos113; G->thunkpos= yythunkpos113;
  }  if (!yymatchChar(G, 'x')) goto l111;
  yyprintf((stderr, "  ok   %s @ %s\n", "ImageSizeWidth", G->buf+G->pos));
  return 1;
  l111:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ImageSizeWidth", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ImageSizeComplete(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "ImageSizeComplete"));  if (!yymatchChar(G, '=')) goto l114;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l114;
  l115:;	
  {  int yypos116= G->pos, yythunkpos116= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l116;  goto l115;
  l116:;	  G->pos= yypos116; G->thunkpos= yythunkpos116;
  }  if (!yymatchChar(G, 'x')) goto l114;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l114;
  l117:;	
  {  int yypos118= G->pos, yythunkpos118= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l118;  goto l117;
  l118:;	  G->pos= yypos118; G->thunkpos= yythunkpos118;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "ImageSizeComplete", G->buf+G->pos));
  return 1;
  l114:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ImageSizeComplete", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_TitleDoubleExt(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "TitleDoubleExt"));  if (!yymatchChar(G, '"')) goto l119;
  l120:;	
  {  int yypos121= G->pos, yythunkpos121= G->thunkpos;
  {  int yypos122= G->pos, yythunkpos122= G->thunkpos;
  {  int yypos123= G->pos, yythunkpos123= G->thunkpos;  if (!yymatchChar(G, '"')) goto l124;  goto l123;
  l124:;	  G->pos= yypos123; G->thunkpos= yythunkpos123;  if (!yy_Newline(G)) { goto l122; }
  }
  l123:;	  goto l121;
  l122:;	  G->pos= yypos122; G->thunkpos= yythunkpos122;
  }  if (!yymatchDot(G)) goto l121;  goto l120;
  l121:;	  G->pos= yypos121; G->thunkpos= yythunkpos121;
  }  if (!yymatchChar(G, '"')) goto l119;
  yyprintf((stderr, "  ok   %s @ %s\n", "TitleDoubleExt", G->buf+G->pos));
  return 1;
  l119:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "TitleDoubleExt", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_TitleSingleExt(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "TitleSingleExt"));  if (!yymatchChar(G, '\'')) goto l125;
  l126:;	
  {  int yypos127= G->pos, yythunkpos127= G->thunkpos;
  {  int yypos128= G->pos, yythunkpos128= G->thunkpos;
  {  int yypos129= G->pos, yythunkpos129= G->thunkpos;  if (!yymatchChar(G, '\'')) goto l130;  goto l129;
  l130:;	  G->pos= yypos129; G->thunkpos= yythunkpos129;  if (!yy_Newline(G)) { goto l128; }
  }
  l129:;	  goto l127;
  l128:;	  G->pos= yypos128; G->thunkpos= yythunkpos128;
  }  if (!yymatchDot(G)) goto l127;  goto l126;
  l127:;	  G->pos= yypos127; G->thunkpos= yythunkpos127;
  }  if (!yymatchChar(G, '\'')) goto l125;
  yyprintf((stderr, "  ok   %s @ %s\n", "TitleSingleExt", G->buf+G->pos));
  return 1;
  l125:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "TitleSingleExt", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_TitleDouble(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "TitleDouble"));  if (!yymatchChar(G, '"')) goto l131;
  l132:;	
  {  int yypos133= G->pos, yythunkpos133= G->thunkpos;
  {  int yypos134= G->pos, yythunkpos134= G->thunkpos;  if (!yymatchChar(G, '"')) goto l134;  if (!yy_Sp(G)) { goto l134; }
  {  int yypos135= G->pos, yythunkpos135= G->thunkpos;  if (!yymatchChar(G, ')')) goto l136;  goto l135;
  l136:;	  G->pos= yypos135; G->thunkpos= yythunkpos135;  if (!yy_Newline(G)) { goto l134; }
  }
  l135:;	  goto l133;
  l134:;	  G->pos= yypos134; G->thunkpos= yythunkpos134;
  }  if (!yymatchDot(G)) goto l133;  goto l132;
  l133:;	  G->pos= yypos133; G->thunkpos= yythunkpos133;
  }  if (!yymatchChar(G, '"')) goto l131;
  yyprintf((stderr, "  ok   %s @ %s\n", "TitleDouble", G->buf+G->pos));
  return 1;
  l131:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "TitleDouble", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_TitleSingle(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "TitleSingle"));  if (!yymatchChar(G, '\'')) goto l137;
  l138:;	
  {  int yypos139= G->pos, yythunkpos139= G->thunkpos;
  {  int yypos140= G->pos, yythunkpos140= G->thunkpos;  if (!yymatchChar(G, '\'')) goto l140;  if (!yy_Sp(G)) { goto l140; }
  {  int yypos141= G->pos, yythunkpos141= G->thunkpos;  if (!yymatchChar(G, ')')) goto l142;  goto l141;
  l142:;	  G->pos= yypos141; G->thunkpos= yythunkpos141;  if (!yy_Newline(G)) { goto l140; }
  }
  l141:;	  goto l139;
  l140:;	  G->pos= yypos140; G->thunkpos= yythunkpos140;
  }  if (!yymatchDot(G)) goto l139;  goto l138;
  l139:;	  G->pos= yypos139; G->thunkpos= yythunkpos139;
  }  if (!yymatchChar(G, '\'')) goto l137;
  yyprintf((stderr, "  ok   %s @ %s\n", "TitleSingle", G->buf+G->pos));
  return 1;
  l137:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "TitleSingle", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Nonspacechar(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Nonspacechar"));
  {  int yypos144= G->pos, yythunkpos144= G->thunkpos;  if (!yy_Spacechar(G)) { goto l144; }  goto l143;
  l144:;	  G->pos= yypos144; G->thunkpos= yythunkpos144;
  }
  {  int yypos145= G->pos, yythunkpos145= G->thunkpos;  if (!yy_Newline(G)) { goto l145; }  goto l143;
  l145:;	  G->pos= yypos145; G->thunkpos= yythunkpos145;
  }  if (!yymatchDot(G)) goto l143;
  yyprintf((stderr, "  ok   %s @ %s\n", "Nonspacechar", G->buf+G->pos));
  return 1;
  l143:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Nonspacechar", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_SourceContents(GREG *G)
{
  yyprintf((stderr, "%s\n", "SourceContents"));
  l147:;	
  {  int yypos148= G->pos, yythunkpos148= G->thunkpos;
  {  int yypos149= G->pos, yythunkpos149= G->thunkpos;
  {  int yypos153= G->pos, yythunkpos153= G->thunkpos;  if (!yymatchChar(G, '(')) goto l153;  goto l150;
  l153:;	  G->pos= yypos153; G->thunkpos= yythunkpos153;
  }
  {  int yypos154= G->pos, yythunkpos154= G->thunkpos;  if (!yymatchChar(G, ')')) goto l154;  goto l150;
  l154:;	  G->pos= yypos154; G->thunkpos= yythunkpos154;
  }
  {  int yypos155= G->pos, yythunkpos155= G->thunkpos;  if (!yymatchChar(G, '>')) goto l155;  goto l150;
  l155:;	  G->pos= yypos155; G->thunkpos= yythunkpos155;
  }  if (!yy_Nonspacechar(G)) { goto l150; }
  l151:;	
  {  int yypos152= G->pos, yythunkpos152= G->thunkpos;
  {  int yypos156= G->pos, yythunkpos156= G->thunkpos;  if (!yymatchChar(G, '(')) goto l156;  goto l152;
  l156:;	  G->pos= yypos156; G->thunkpos= yythunkpos156;
  }
  {  int yypos157= G->pos, yythunkpos157= G->thunkpos;  if (!yymatchChar(G, ')')) goto l157;  goto l152;
  l157:;	  G->pos= yypos157; G->thunkpos= yythunkpos157;
  }
  {  int yypos158= G->pos, yythunkpos158= G->thunkpos;  if (!yymatchChar(G, '>')) goto l158;  goto l152;
  l158:;	  G->pos= yypos158; G->thunkpos= yythunkpos158;
  }  if (!yy_Nonspacechar(G)) { goto l152; }  goto l151;
  l152:;	  G->pos= yypos152; G->thunkpos= yythunkpos152;
  }  goto l149;
  l150:;	  G->pos= yypos149; G->thunkpos= yythunkpos149;  if (!yymatchChar(G, '(')) goto l148;  if (!yy_SourceContents(G)) { goto l148; }  if (!yymatchChar(G, ')')) goto l148;
  }
  l149:;	  goto l147;
  l148:;	  G->pos= yypos148; G->thunkpos= yythunkpos148;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "SourceContents", G->buf+G->pos));
  return 1;
}
YY_RULE(int) yy_ImageSize(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "ImageSize"));
  {  int yypos160= G->pos, yythunkpos160= G->thunkpos;  if (!yy_ImageSizeComplete(G)) { goto l161; }  goto l160;
  l161:;	  G->pos= yypos160; G->thunkpos= yythunkpos160;  if (!yy_ImageSizeWidth(G)) { goto l162; }  goto l160;
  l162:;	  G->pos= yypos160; G->thunkpos= yythunkpos160;  if (!yy_ImageSizeHeight(G)) { goto l163; }  goto l160;
  l163:;	  G->pos= yypos160; G->thunkpos= yythunkpos160;  if (!yymatchString(G, "")) goto l159;
  }
  l160:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "ImageSize", G->buf+G->pos));
  return 1;
  l159:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ImageSize", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_TitleExt(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "TitleExt"));
  {  int yypos165= G->pos, yythunkpos165= G->thunkpos;  if (!yy_TitleSingleExt(G)) { goto l166; }  goto l165;
  l166:;	  G->pos= yypos165; G->thunkpos= yythunkpos165;  if (!yy_TitleDoubleExt(G)) { goto l167; }  goto l165;
  l167:;	  G->pos= yypos165; G->thunkpos= yythunkpos165;  if (!yymatchString(G, "")) goto l164;
  }
  l165:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "TitleExt", G->buf+G->pos));
  return 1;
  l164:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "TitleExt", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Title(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Title"));
  {  int yypos169= G->pos, yythunkpos169= G->thunkpos;  if (!yy_TitleSingle(G)) { goto l170; }  goto l169;
  l170:;	  G->pos= yypos169; G->thunkpos= yythunkpos169;  if (!yy_TitleDouble(G)) { goto l171; }  goto l169;
  l171:;	  G->pos= yypos169; G->thunkpos= yythunkpos169;  if (!yymatchString(G, "")) goto l168;
  }
  l169:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Title", G->buf+G->pos));
  return 1;
  l168:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Title", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Source(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Source"));  yyDo(G, yy_1_Source, G->begin, G->end);
  {  int yypos173= G->pos, yythunkpos173= G->thunkpos;  if (!yymatchChar(G, '<')) goto l174;  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l174;  if (!yy_SourceContents(G)) { goto l174; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l174;  yyDo(G, yy_2_Source, G->begin, G->end);  if (!yymatchChar(G, '>')) goto l174;  goto l173;
  l174:;	  G->pos= yypos173; G->thunkpos= yythunkpos173;  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l172;  if (!yy_SourceContents(G)) { goto l172; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l172;  yyDo(G, yy_3_Source, G->begin, G->end);
  }
  l173:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Source", G->buf+G->pos));
  return 1;
  l172:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Source", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Label(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "Label"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l175;  if (!yy_LocMarker(G)) { goto l175; }  yyDo(G, yySet, -1, 0);  if (!yymatchChar(G, '[')) goto l175;
  {  int yypos176= G->pos, yythunkpos176= G->thunkpos;
  {  int yypos178= G->pos, yythunkpos178= G->thunkpos;  if (!yymatchChar(G, '^')) goto l178;  goto l177;
  l178:;	  G->pos= yypos178; G->thunkpos= yythunkpos178;
  }  yyText(G, G->begin, G->end);  if (!( EXT(pmh_EXT_NOTES) )) goto l177;  goto l176;
  l177:;	  G->pos= yypos176; G->thunkpos= yythunkpos176;
  {  int yypos179= G->pos, yythunkpos179= G->thunkpos;  if (!yymatchDot(G)) goto l175;  G->pos= yypos179; G->thunkpos= yythunkpos179;
  }  yyText(G, G->begin, G->end);  if (!( !EXT(pmh_EXT_NOTES) )) goto l175;
  }
  l176:;	  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l175;
  l180:;	
  {  int yypos181= G->pos, yythunkpos181= G->thunkpos;
  {  int yypos182= G->pos, yythunkpos182= G->thunkpos;  if (!yymatchChar(G, ']')) goto l182;  goto l181;
  l182:;	  G->pos= yypos182; G->thunkpos= yythunkpos182;
  }  if (!yy_Inline(G)) { goto l181; }  goto l180;
  l181:;	  G->pos= yypos181; G->thunkpos= yythunkpos181;
  }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l175;  yyDo(G, yy_1_Label, G->begin, G->end);  if (!yymatchChar(G, ']')) goto l175;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l175;  yyDo(G, yy_2_Label, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Label", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l175:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Label", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ReferenceLinkSingle(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "ReferenceLinkSingle"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l183;  if (!yy_Label(G)) { goto l183; }  yyDo(G, yySet, -1, 0);
  {  int yypos184= G->pos, yythunkpos184= G->thunkpos;  if (!yy_Spnl(G)) { goto l184; }  if (!yymatchString(G, "[]")) goto l184;  goto l185;
  l184:;	  G->pos= yypos184; G->thunkpos= yythunkpos184;
  }
  l185:;	  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l183;  yyDo(G, yy_1_ReferenceLinkSingle, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "ReferenceLinkSingle", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l183:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ReferenceLinkSingle", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ReferenceLinkDouble(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 2, 0);
  yyprintf((stderr, "%s\n", "ReferenceLinkDouble"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l186;  if (!yy_Label(G)) { goto l186; }  yyDo(G, yySet, -2, 0);  if (!yy_Spnl(G)) { goto l186; }
  {  int yypos187= G->pos, yythunkpos187= G->thunkpos;  if (!yymatchString(G, "[]")) goto l187;  goto l186;
  l187:;	  G->pos= yypos187; G->thunkpos= yythunkpos187;
  }  if (!yy_Label(G)) { goto l186; }  yyDo(G, yySet, -1, 0);  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l186;  yyDo(G, yy_1_ReferenceLinkDouble, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "ReferenceLinkDouble", G->buf+G->pos));  yyDo(G, yyPop, 2, 0);
  return 1;
  l186:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ReferenceLinkDouble", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_AutoLink(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "AutoLink"));
  {  int yypos189= G->pos, yythunkpos189= G->thunkpos;  if (!yy_AutoLinkUrl(G)) { goto l190; }  goto l189;
  l190:;	  G->pos= yypos189; G->thunkpos= yythunkpos189;  if (!yy_AutoLinkEmail(G)) { goto l188; }
  }
  l189:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "AutoLink", G->buf+G->pos));
  return 1;
  l188:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "AutoLink", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ReferenceLink(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "ReferenceLink"));
  {  int yypos192= G->pos, yythunkpos192= G->thunkpos;  if (!yy_ReferenceLinkDouble(G)) { goto l193; }  goto l192;
  l193:;	  G->pos= yypos192; G->thunkpos= yythunkpos192;  if (!yy_ReferenceLinkSingle(G)) { goto l191; }
  }
  l192:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "ReferenceLink", G->buf+G->pos));
  return 1;
  l191:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ReferenceLink", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ExplicitLinkSize(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 2, 0);
  yyprintf((stderr, "%s\n", "ExplicitLinkSize"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l194;  if (!yy_Label(G)) { goto l194; }  yyDo(G, yySet, -2, 0);  if (!yy_Spnl(G)) { goto l194; }  if (!yymatchChar(G, '(')) goto l194;  if (!yy_Sp(G)) { goto l194; }  if (!yy_Source(G)) { goto l194; }  yyDo(G, yySet, -1, 0);  if (!yy_Spnl(G)) { goto l194; }  if (!yy_TitleExt(G)) { goto l194; }  if (!yy_Sp(G)) { goto l194; }  if (!yy_ImageSize(G)) { goto l194; }  if (!yy_Sp(G)) { goto l194; }  if (!yymatchChar(G, ')')) goto l194;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l194;  yyDo(G, yy_1_ExplicitLinkSize, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "ExplicitLinkSize", G->buf+G->pos));  yyDo(G, yyPop, 2, 0);
  return 1;
  l194:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ExplicitLinkSize", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ExplicitLink(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 2, 0);
  yyprintf((stderr, "%s\n", "ExplicitLink"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l195;  if (!yy_Label(G)) { goto l195; }  yyDo(G, yySet, -2, 0);  if (!yy_Spnl(G)) { goto l195; }  if (!yymatchChar(G, '(')) goto l195;  if (!yy_Sp(G)) { goto l195; }  if (!yy_Source(G)) { goto l195; }  yyDo(G, yySet, -1, 0);  if (!yy_Spnl(G)) { goto l195; }  if (!yy_Title(G)) { goto l195; }  if (!yy_Sp(G)) { goto l195; }  if (!yymatchChar(G, ')')) goto l195;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l195;  yyDo(G, yy_1_ExplicitLink, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "ExplicitLink", G->buf+G->pos));  yyDo(G, yyPop, 2, 0);
  return 1;
  l195:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ExplicitLink", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_StrongUl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "StrongUl"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l196;  if (!yy_LocMarker(G)) { goto l196; }  yyDo(G, yySet, -1, 0);  if (!yymatchString(G, "__")) goto l196;
  {  int yypos197= G->pos, yythunkpos197= G->thunkpos;  if (!yy_Whitespace(G)) { goto l197; }  goto l196;
  l197:;	  G->pos= yypos197; G->thunkpos= yythunkpos197;
  }
  {  int yypos200= G->pos, yythunkpos200= G->thunkpos;  if (!yymatchString(G, "__")) goto l200;  goto l196;
  l200:;	  G->pos= yypos200; G->thunkpos= yythunkpos200;
  }  if (!yy_Inline(G)) { goto l196; }
  l198:;	
  {  int yypos199= G->pos, yythunkpos199= G->thunkpos;
  {  int yypos201= G->pos, yythunkpos201= G->thunkpos;  if (!yymatchString(G, "__")) goto l201;  goto l199;
  l201:;	  G->pos= yypos201; G->thunkpos= yythunkpos201;
  }  if (!yy_Inline(G)) { goto l199; }  goto l198;
  l199:;	  G->pos= yypos199; G->thunkpos= yythunkpos199;
  }  if (!yymatchString(G, "__")) goto l196;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l196;  yyDo(G, yy_1_StrongUl, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "StrongUl", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l196:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "StrongUl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_StrongStar(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "StrongStar"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l202;  if (!yy_LocMarker(G)) { goto l202; }  yyDo(G, yySet, -1, 0);  if (!yymatchString(G, "**")) goto l202;
  {  int yypos203= G->pos, yythunkpos203= G->thunkpos;  if (!yy_Whitespace(G)) { goto l203; }  goto l202;
  l203:;	  G->pos= yypos203; G->thunkpos= yythunkpos203;
  }
  {  int yypos206= G->pos, yythunkpos206= G->thunkpos;  if (!yymatchString(G, "**")) goto l206;  goto l202;
  l206:;	  G->pos= yypos206; G->thunkpos= yythunkpos206;
  }  if (!yy_Inline(G)) { goto l202; }
  l204:;	
  {  int yypos205= G->pos, yythunkpos205= G->thunkpos;
  {  int yypos207= G->pos, yythunkpos207= G->thunkpos;  if (!yymatchString(G, "**")) goto l207;  goto l205;
  l207:;	  G->pos= yypos207; G->thunkpos= yythunkpos207;
  }  if (!yy_Inline(G)) { goto l205; }  goto l204;
  l205:;	  G->pos= yypos205; G->thunkpos= yythunkpos205;
  }  if (!yymatchString(G, "**")) goto l202;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l202;  yyDo(G, yy_1_StrongStar, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "StrongStar", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l202:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "StrongStar", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Whitespace(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Whitespace"));
  {  int yypos209= G->pos, yythunkpos209= G->thunkpos;  if (!yy_Spacechar(G)) { goto l210; }  goto l209;
  l210:;	  G->pos= yypos209; G->thunkpos= yythunkpos209;  if (!yy_Newline(G)) { goto l208; }
  }
  l209:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Whitespace", G->buf+G->pos));
  return 1;
  l208:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Whitespace", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_EmphUl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "EmphUl"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l211;  if (!yy_LocMarker(G)) { goto l211; }  yyDo(G, yySet, -1, 0);  if (!yymatchChar(G, '_')) goto l211;
  {  int yypos212= G->pos, yythunkpos212= G->thunkpos;  if (!yy_Whitespace(G)) { goto l212; }  goto l211;
  l212:;	  G->pos= yypos212; G->thunkpos= yythunkpos212;
  }
  {  int yypos215= G->pos, yythunkpos215= G->thunkpos;
  {  int yypos217= G->pos, yythunkpos217= G->thunkpos;  if (!yymatchChar(G, '_')) goto l217;  goto l216;
  l217:;	  G->pos= yypos217; G->thunkpos= yythunkpos217;
  }  if (!yy_Inline(G)) { goto l216; }  goto l215;
  l216:;	  G->pos= yypos215; G->thunkpos= yythunkpos215;  if (!yy_StrongUl(G)) { goto l211; }
  }
  l215:;	
  l213:;	
  {  int yypos214= G->pos, yythunkpos214= G->thunkpos;
  {  int yypos218= G->pos, yythunkpos218= G->thunkpos;
  {  int yypos220= G->pos, yythunkpos220= G->thunkpos;  if (!yymatchChar(G, '_')) goto l220;  goto l219;
  l220:;	  G->pos= yypos220; G->thunkpos= yythunkpos220;
  }  if (!yy_Inline(G)) { goto l219; }  goto l218;
  l219:;	  G->pos= yypos218; G->thunkpos= yythunkpos218;  if (!yy_StrongUl(G)) { goto l214; }
  }
  l218:;	  goto l213;
  l214:;	  G->pos= yypos214; G->thunkpos= yythunkpos214;
  }  if (!yymatchChar(G, '_')) goto l211;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l211;  yyDo(G, yy_1_EmphUl, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "EmphUl", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l211:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "EmphUl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_EmphStar(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "EmphStar"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l221;  if (!yy_LocMarker(G)) { goto l221; }  yyDo(G, yySet, -1, 0);  if (!yymatchChar(G, '*')) goto l221;
  {  int yypos222= G->pos, yythunkpos222= G->thunkpos;  if (!yy_Whitespace(G)) { goto l222; }  goto l221;
  l222:;	  G->pos= yypos222; G->thunkpos= yythunkpos222;
  }
  {  int yypos225= G->pos, yythunkpos225= G->thunkpos;
  {  int yypos227= G->pos, yythunkpos227= G->thunkpos;  if (!yymatchChar(G, '*')) goto l227;  goto l226;
  l227:;	  G->pos= yypos227; G->thunkpos= yythunkpos227;
  }  if (!yy_Inline(G)) { goto l226; }  goto l225;
  l226:;	  G->pos= yypos225; G->thunkpos= yythunkpos225;  if (!yy_StrongStar(G)) { goto l221; }
  }
  l225:;	
  l223:;	
  {  int yypos224= G->pos, yythunkpos224= G->thunkpos;
  {  int yypos228= G->pos, yythunkpos228= G->thunkpos;
  {  int yypos230= G->pos, yythunkpos230= G->thunkpos;  if (!yymatchChar(G, '*')) goto l230;  goto l229;
  l230:;	  G->pos= yypos230; G->thunkpos= yythunkpos230;
  }  if (!yy_Inline(G)) { goto l229; }  goto l228;
  l229:;	  G->pos= yypos228; G->thunkpos= yythunkpos228;  if (!yy_StrongStar(G)) { goto l224; }
  }
  l228:;	  goto l223;
  l224:;	  G->pos= yypos224; G->thunkpos= yythunkpos224;
  }  if (!yymatchChar(G, '*')) goto l221;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l221;  yyDo(G, yy_1_EmphStar, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "EmphStar", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l221:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "EmphStar", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_StarLine(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "StarLine"));
  {  int yypos232= G->pos, yythunkpos232= G->thunkpos;  if (!yymatchString(G, "****")) goto l233;
  l234:;	
  {  int yypos235= G->pos, yythunkpos235= G->thunkpos;  if (!yymatchChar(G, '*')) goto l235;  goto l234;
  l235:;	  G->pos= yypos235; G->thunkpos= yythunkpos235;
  }  goto l232;
  l233:;	  G->pos= yypos232; G->thunkpos= yythunkpos232;  if (!yy_Spacechar(G)) { goto l231; }  if (!yymatchChar(G, '*')) goto l231;
  l236:;	
  {  int yypos237= G->pos, yythunkpos237= G->thunkpos;  if (!yymatchChar(G, '*')) goto l237;  goto l236;
  l237:;	  G->pos= yypos237; G->thunkpos= yythunkpos237;
  }
  {  int yypos238= G->pos, yythunkpos238= G->thunkpos;  if (!yy_Spacechar(G)) { goto l231; }  G->pos= yypos238; G->thunkpos= yythunkpos238;
  }
  }
  l232:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "StarLine", G->buf+G->pos));
  return 1;
  l231:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "StarLine", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_UlLine(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "UlLine"));
  {  int yypos240= G->pos, yythunkpos240= G->thunkpos;  if (!yymatchString(G, "____")) goto l241;
  l242:;	
  {  int yypos243= G->pos, yythunkpos243= G->thunkpos;  if (!yymatchChar(G, '_')) goto l243;  goto l242;
  l243:;	  G->pos= yypos243; G->thunkpos= yythunkpos243;
  }  goto l240;
  l241:;	  G->pos= yypos240; G->thunkpos= yythunkpos240;  if (!yy_Spacechar(G)) { goto l239; }  if (!yymatchChar(G, '_')) goto l239;
  l244:;	
  {  int yypos245= G->pos, yythunkpos245= G->thunkpos;  if (!yymatchChar(G, '_')) goto l245;  goto l244;
  l245:;	  G->pos= yypos245; G->thunkpos= yythunkpos245;
  }
  {  int yypos246= G->pos, yythunkpos246= G->thunkpos;  if (!yy_Spacechar(G)) { goto l239; }  G->pos= yypos246; G->thunkpos= yythunkpos246;
  }
  }
  l240:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "UlLine", G->buf+G->pos));
  return 1;
  l239:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "UlLine", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_SpecialChar(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "SpecialChar"));
  {  int yypos248= G->pos, yythunkpos248= G->thunkpos;  if (!yymatchChar(G, '~')) goto l249;  goto l248;
  l249:;	  G->pos= yypos248; G->thunkpos= yythunkpos248;  if (!yymatchChar(G, '*')) goto l250;  goto l248;
  l250:;	  G->pos= yypos248; G->thunkpos= yythunkpos248;  if (!yymatchChar(G, '_')) goto l251;  goto l248;
  l251:;	  G->pos= yypos248; G->thunkpos= yythunkpos248;  if (!yymatchChar(G, '`')) goto l252;  goto l248;
  l252:;	  G->pos= yypos248; G->thunkpos= yythunkpos248;  if (!yymatchChar(G, '&')) goto l253;  goto l248;
  l253:;	  G->pos= yypos248; G->thunkpos= yythunkpos248;  if (!yymatchChar(G, '[')) goto l254;  goto l248;
  l254:;	  G->pos= yypos248; G->thunkpos= yythunkpos248;  if (!yymatchChar(G, ']')) goto l255;  goto l248;
  l255:;	  G->pos= yypos248; G->thunkpos= yythunkpos248;  if (!yymatchChar(G, '(')) goto l256;  goto l248;
  l256:;	  G->pos= yypos248; G->thunkpos= yythunkpos248;  if (!yymatchChar(G, ')')) goto l257;  goto l248;
  l257:;	  G->pos= yypos248; G->thunkpos= yythunkpos248;  if (!yymatchChar(G, '<')) goto l258;  goto l248;
  l258:;	  G->pos= yypos248; G->thunkpos= yythunkpos248;  if (!yymatchChar(G, '!')) goto l259;  goto l248;
  l259:;	  G->pos= yypos248; G->thunkpos= yythunkpos248;  if (!yymatchChar(G, '#')) goto l260;  goto l248;
  l260:;	  G->pos= yypos248; G->thunkpos= yythunkpos248;  if (!yymatchChar(G, '\\')) goto l261;  goto l248;
  l261:;	  G->pos= yypos248; G->thunkpos= yythunkpos248;  if (!yymatchChar(G, '\'')) goto l262;  goto l248;
  l262:;	  G->pos= yypos248; G->thunkpos= yythunkpos248;  if (!yymatchChar(G, '"')) goto l263;  goto l248;
  l263:;	  G->pos= yypos248; G->thunkpos= yythunkpos248;  if (!yy_ExtendedSpecialChar(G)) { goto l247; }
  }
  l248:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "SpecialChar", G->buf+G->pos));
  return 1;
  l247:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "SpecialChar", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Eof(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Eof"));
  {  int yypos265= G->pos, yythunkpos265= G->thunkpos;  if (!yymatchDot(G)) goto l265;  goto l264;
  l265:;	  G->pos= yypos265; G->thunkpos= yythunkpos265;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "Eof", G->buf+G->pos));
  return 1;
  l264:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Eof", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_NormalEndline(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "NormalEndline"));  if (!yy_Sp(G)) { goto l266; }  if (!yy_Newline(G)) { goto l266; }
  {  int yypos267= G->pos, yythunkpos267= G->thunkpos;  if (!yy_BlankLine(G)) { goto l267; }  goto l266;
  l267:;	  G->pos= yypos267; G->thunkpos= yythunkpos267;
  }
  {  int yypos268= G->pos, yythunkpos268= G->thunkpos;  if (!yymatchChar(G, '>')) goto l268;  goto l266;
  l268:;	  G->pos= yypos268; G->thunkpos= yythunkpos268;
  }
  {  int yypos269= G->pos, yythunkpos269= G->thunkpos;  if (!yy_AtxStart(G)) { goto l269; }  goto l266;
  l269:;	  G->pos= yypos269; G->thunkpos= yythunkpos269;
  }
  {  int yypos270= G->pos, yythunkpos270= G->thunkpos;  if (!yy_Line(G)) { goto l270; }
  {  int yypos271= G->pos, yythunkpos271= G->thunkpos;  if (!yymatchChar(G, '=')) goto l272;
  l273:;	
  {  int yypos274= G->pos, yythunkpos274= G->thunkpos;  if (!yymatchChar(G, '=')) goto l274;  goto l273;
  l274:;	  G->pos= yypos274; G->thunkpos= yythunkpos274;
  }  goto l271;
  l272:;	  G->pos= yypos271; G->thunkpos= yythunkpos271;  if (!yymatchChar(G, '-')) goto l270;
  l275:;	
  {  int yypos276= G->pos, yythunkpos276= G->thunkpos;  if (!yymatchChar(G, '-')) goto l276;  goto l275;
  l276:;	  G->pos= yypos276; G->thunkpos= yythunkpos276;
  }
  }
  l271:;	  if (!yy_Newline(G)) { goto l270; }  goto l266;
  l270:;	  G->pos= yypos270; G->thunkpos= yythunkpos270;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "NormalEndline", G->buf+G->pos));
  return 1;
  l266:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "NormalEndline", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_TerminalEndline(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "TerminalEndline"));  if (!yy_Sp(G)) { goto l277; }  if (!yy_Newline(G)) { goto l277; }  if (!yy_Eof(G)) { goto l277; }
  yyprintf((stderr, "  ok   %s @ %s\n", "TerminalEndline", G->buf+G->pos));
  return 1;
  l277:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "TerminalEndline", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_LineBreak(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "LineBreak"));  if (!yymatchString(G, "  ")) goto l278;  if (!yy_NormalEndline(G)) { goto l278; }
  yyprintf((stderr, "  ok   %s @ %s\n", "LineBreak", G->buf+G->pos));
  return 1;
  l278:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "LineBreak", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_CharEntity(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "CharEntity"));  if (!yymatchChar(G, '&')) goto l279;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\376\377\377\007\376\377\377\007\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l279;
  l280:;	
  {  int yypos281= G->pos, yythunkpos281= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\376\377\377\007\376\377\377\007\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l281;  goto l280;
  l281:;	  G->pos= yypos281; G->thunkpos= yythunkpos281;
  }  if (!yymatchChar(G, ';')) goto l279;
  yyprintf((stderr, "  ok   %s @ %s\n", "CharEntity", G->buf+G->pos));
  return 1;
  l279:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "CharEntity", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_DecEntity(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "DecEntity"));  if (!yymatchChar(G, '&')) goto l282;  if (!yymatchChar(G, '#')) goto l282;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l282;
  l283:;	
  {  int yypos284= G->pos, yythunkpos284= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l284;  goto l283;
  l284:;	  G->pos= yypos284; G->thunkpos= yythunkpos284;
  }  if (!yymatchChar(G, ';')) goto l282;
  yyprintf((stderr, "  ok   %s @ %s\n", "DecEntity", G->buf+G->pos));
  return 1;
  l282:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "DecEntity", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HexEntity(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HexEntity"));  if (!yymatchChar(G, '&')) goto l285;  if (!yymatchChar(G, '#')) goto l285;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\000\000\000\000\000\001\000\000\000\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l285;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\176\000\000\000\176\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l285;
  l286:;	
  {  int yypos287= G->pos, yythunkpos287= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\176\000\000\000\176\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l287;  goto l286;
  l287:;	  G->pos= yypos287; G->thunkpos= yythunkpos287;
  }  if (!yymatchChar(G, ';')) goto l285;
  yyprintf((stderr, "  ok   %s @ %s\n", "HexEntity", G->buf+G->pos));
  return 1;
  l285:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HexEntity", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Alphanumeric(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Alphanumeric"));
  {  int yypos289= G->pos, yythunkpos289= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\376\377\377\007\376\377\377\007\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l290;  goto l289;
  l290:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\200")) goto l291;  goto l289;
  l291:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\201")) goto l292;  goto l289;
  l292:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\202")) goto l293;  goto l289;
  l293:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\203")) goto l294;  goto l289;
  l294:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\204")) goto l295;  goto l289;
  l295:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\205")) goto l296;  goto l289;
  l296:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\206")) goto l297;  goto l289;
  l297:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\207")) goto l298;  goto l289;
  l298:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\210")) goto l299;  goto l289;
  l299:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\211")) goto l300;  goto l289;
  l300:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\212")) goto l301;  goto l289;
  l301:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\213")) goto l302;  goto l289;
  l302:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\214")) goto l303;  goto l289;
  l303:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\215")) goto l304;  goto l289;
  l304:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\216")) goto l305;  goto l289;
  l305:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\217")) goto l306;  goto l289;
  l306:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\220")) goto l307;  goto l289;
  l307:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\221")) goto l308;  goto l289;
  l308:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\222")) goto l309;  goto l289;
  l309:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\223")) goto l310;  goto l289;
  l310:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\224")) goto l311;  goto l289;
  l311:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\225")) goto l312;  goto l289;
  l312:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\226")) goto l313;  goto l289;
  l313:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\227")) goto l314;  goto l289;
  l314:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\230")) goto l315;  goto l289;
  l315:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\231")) goto l316;  goto l289;
  l316:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\232")) goto l317;  goto l289;
  l317:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\233")) goto l318;  goto l289;
  l318:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\234")) goto l319;  goto l289;
  l319:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\235")) goto l320;  goto l289;
  l320:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\236")) goto l321;  goto l289;
  l321:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\237")) goto l322;  goto l289;
  l322:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\240")) goto l323;  goto l289;
  l323:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\241")) goto l324;  goto l289;
  l324:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\242")) goto l325;  goto l289;
  l325:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\243")) goto l326;  goto l289;
  l326:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\244")) goto l327;  goto l289;
  l327:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\245")) goto l328;  goto l289;
  l328:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\246")) goto l329;  goto l289;
  l329:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\247")) goto l330;  goto l289;
  l330:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\250")) goto l331;  goto l289;
  l331:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\251")) goto l332;  goto l289;
  l332:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\252")) goto l333;  goto l289;
  l333:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\253")) goto l334;  goto l289;
  l334:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\254")) goto l335;  goto l289;
  l335:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\255")) goto l336;  goto l289;
  l336:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\256")) goto l337;  goto l289;
  l337:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\257")) goto l338;  goto l289;
  l338:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\260")) goto l339;  goto l289;
  l339:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\261")) goto l340;  goto l289;
  l340:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\262")) goto l341;  goto l289;
  l341:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\263")) goto l342;  goto l289;
  l342:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\264")) goto l343;  goto l289;
  l343:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\265")) goto l344;  goto l289;
  l344:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\266")) goto l345;  goto l289;
  l345:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\267")) goto l346;  goto l289;
  l346:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\270")) goto l347;  goto l289;
  l347:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\271")) goto l348;  goto l289;
  l348:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\272")) goto l349;  goto l289;
  l349:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\273")) goto l350;  goto l289;
  l350:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\274")) goto l351;  goto l289;
  l351:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\275")) goto l352;  goto l289;
  l352:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\276")) goto l353;  goto l289;
  l353:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\277")) goto l354;  goto l289;
  l354:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\300")) goto l355;  goto l289;
  l355:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\301")) goto l356;  goto l289;
  l356:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\302")) goto l357;  goto l289;
  l357:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\303")) goto l358;  goto l289;
  l358:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\304")) goto l359;  goto l289;
  l359:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\305")) goto l360;  goto l289;
  l360:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\306")) goto l361;  goto l289;
  l361:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\307")) goto l362;  goto l289;
  l362:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\310")) goto l363;  goto l289;
  l363:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\311")) goto l364;  goto l289;
  l364:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\312")) goto l365;  goto l289;
  l365:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\313")) goto l366;  goto l289;
  l366:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\314")) goto l367;  goto l289;
  l367:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\315")) goto l368;  goto l289;
  l368:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\316")) goto l369;  goto l289;
  l369:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\317")) goto l370;  goto l289;
  l370:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\320")) goto l371;  goto l289;
  l371:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\321")) goto l372;  goto l289;
  l372:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\322")) goto l373;  goto l289;
  l373:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\323")) goto l374;  goto l289;
  l374:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\324")) goto l375;  goto l289;
  l375:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\325")) goto l376;  goto l289;
  l376:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\326")) goto l377;  goto l289;
  l377:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\327")) goto l378;  goto l289;
  l378:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\330")) goto l379;  goto l289;
  l379:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\331")) goto l380;  goto l289;
  l380:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\332")) goto l381;  goto l289;
  l381:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\333")) goto l382;  goto l289;
  l382:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\334")) goto l383;  goto l289;
  l383:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\335")) goto l384;  goto l289;
  l384:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\336")) goto l385;  goto l289;
  l385:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\337")) goto l386;  goto l289;
  l386:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\340")) goto l387;  goto l289;
  l387:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\341")) goto l388;  goto l289;
  l388:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\342")) goto l389;  goto l289;
  l389:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\343")) goto l390;  goto l289;
  l390:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\344")) goto l391;  goto l289;
  l391:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\345")) goto l392;  goto l289;
  l392:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\346")) goto l393;  goto l289;
  l393:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\347")) goto l394;  goto l289;
  l394:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\350")) goto l395;  goto l289;
  l395:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\351")) goto l396;  goto l289;
  l396:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\352")) goto l397;  goto l289;
  l397:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\353")) goto l398;  goto l289;
  l398:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\354")) goto l399;  goto l289;
  l399:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\355")) goto l400;  goto l289;
  l400:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\356")) goto l401;  goto l289;
  l401:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\357")) goto l402;  goto l289;
  l402:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\360")) goto l403;  goto l289;
  l403:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\361")) goto l404;  goto l289;
  l404:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\362")) goto l405;  goto l289;
  l405:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\363")) goto l406;  goto l289;
  l406:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\364")) goto l407;  goto l289;
  l407:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\365")) goto l408;  goto l289;
  l408:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\366")) goto l409;  goto l289;
  l409:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\367")) goto l410;  goto l289;
  l410:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\370")) goto l411;  goto l289;
  l411:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\371")) goto l412;  goto l289;
  l412:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\372")) goto l413;  goto l289;
  l413:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\373")) goto l414;  goto l289;
  l414:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\374")) goto l415;  goto l289;
  l415:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\375")) goto l416;  goto l289;
  l416:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\376")) goto l417;  goto l289;
  l417:;	  G->pos= yypos289; G->thunkpos= yythunkpos289;  if (!yymatchString(G, "\377")) goto l288;
  }
  l289:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Alphanumeric", G->buf+G->pos));
  return 1;
  l288:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Alphanumeric", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_NormalChar(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "NormalChar"));
  {  int yypos419= G->pos, yythunkpos419= G->thunkpos;
  {  int yypos420= G->pos, yythunkpos420= G->thunkpos;  if (!yy_SpecialChar(G)) { goto l421; }  goto l420;
  l421:;	  G->pos= yypos420; G->thunkpos= yythunkpos420;  if (!yy_Spacechar(G)) { goto l422; }  goto l420;
  l422:;	  G->pos= yypos420; G->thunkpos= yythunkpos420;  if (!yy_Newline(G)) { goto l419; }
  }
  l420:;	  goto l418;
  l419:;	  G->pos= yypos419; G->thunkpos= yythunkpos419;
  }  if (!yymatchDot(G)) goto l418;
  yyprintf((stderr, "  ok   %s @ %s\n", "NormalChar", G->buf+G->pos));
  return 1;
  l418:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "NormalChar", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Symbol(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Symbol"));  if (!yy_SpecialChar(G)) { goto l423; }
  yyprintf((stderr, "  ok   %s @ %s\n", "Symbol", G->buf+G->pos));
  return 1;
  l423:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Symbol", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_EscapedChar(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "EscapedChar"));  if (!yymatchChar(G, '\\')) goto l424;
  {  int yypos425= G->pos, yythunkpos425= G->thunkpos;  if (!yy_Newline(G)) { goto l425; }  goto l424;
  l425:;	  G->pos= yypos425; G->thunkpos= yythunkpos425;
  }  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\012\157\000\120\000\000\000\270\001\000\000\070\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l424;
  yyprintf((stderr, "  ok   %s @ %s\n", "EscapedChar", G->buf+G->pos));
  return 1;
  l424:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "EscapedChar", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Entity(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "Entity"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l426;  if (!yy_LocMarker(G)) { goto l426; }  yyDo(G, yySet, -1, 0);
  {  int yypos427= G->pos, yythunkpos427= G->thunkpos;  if (!yy_HexEntity(G)) { goto l428; }  goto l427;
  l428:;	  G->pos= yypos427; G->thunkpos= yythunkpos427;  if (!yy_DecEntity(G)) { goto l429; }  goto l427;
  l429:;	  G->pos= yypos427; G->thunkpos= yythunkpos427;  if (!yy_CharEntity(G)) { goto l426; }
  }
  l427:;	  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l426;  yyDo(G, yy_1_Entity, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Entity", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l426:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Entity", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_RawHtml(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "RawHtml"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l430;  if (!yy_LocMarker(G)) { goto l430; }  yyDo(G, yySet, -1, 0);
  {  int yypos431= G->pos, yythunkpos431= G->thunkpos;  if (!yy_HtmlComment(G)) { goto l432; }  goto l431;
  l432:;	  G->pos= yypos431; G->thunkpos= yythunkpos431;  if (!yy_HtmlBlockScript(G)) { goto l433; }  goto l431;
  l433:;	  G->pos= yypos431; G->thunkpos= yythunkpos431;  if (!yy_HtmlTag(G)) { goto l430; }
  }
  l431:;	  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l430;  yyDo(G, yy_1_RawHtml, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "RawHtml", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l430:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "RawHtml", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Code(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "Code"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l434;
  {  int yypos435= G->pos, yythunkpos435= G->thunkpos;  if (!yy_Ticks1(G)) { goto l436; }  yyDo(G, yySet, -1, 0);  if (!yy_Sp(G)) { goto l436; }
  {  int yypos439= G->pos, yythunkpos439= G->thunkpos;
  {  int yypos443= G->pos, yythunkpos443= G->thunkpos;  if (!yymatchChar(G, '`')) goto l443;  goto l440;
  l443:;	  G->pos= yypos443; G->thunkpos= yythunkpos443;
  }  if (!yy_Nonspacechar(G)) { goto l440; }
  l441:;	
  {  int yypos442= G->pos, yythunkpos442= G->thunkpos;
  {  int yypos444= G->pos, yythunkpos444= G->thunkpos;  if (!yymatchChar(G, '`')) goto l444;  goto l442;
  l444:;	  G->pos= yypos444; G->thunkpos= yythunkpos444;
  }  if (!yy_Nonspacechar(G)) { goto l442; }  goto l441;
  l442:;	  G->pos= yypos442; G->thunkpos= yythunkpos442;
  }  goto l439;
  l440:;	  G->pos= yypos439; G->thunkpos= yythunkpos439;
  {  int yypos446= G->pos, yythunkpos446= G->thunkpos;  if (!yy_Ticks1(G)) { goto l446; }  goto l445;
  l446:;	  G->pos= yypos446; G->thunkpos= yythunkpos446;
  }  if (!yymatchChar(G, '`')) goto l445;
  l447:;	
  {  int yypos448= G->pos, yythunkpos448= G->thunkpos;  if (!yymatchChar(G, '`')) goto l448;  goto l447;
  l448:;	  G->pos= yypos448; G->thunkpos= yythunkpos448;
  }  goto l439;
  l445:;	  G->pos= yypos439; G->thunkpos= yythunkpos439;
  {  int yypos449= G->pos, yythunkpos449= G->thunkpos;  if (!yy_Sp(G)) { goto l449; }  if (!yy_Ticks1(G)) { goto l449; }  goto l436;
  l449:;	  G->pos= yypos449; G->thunkpos= yythunkpos449;
  }
  {  int yypos450= G->pos, yythunkpos450= G->thunkpos;  if (!yy_Spacechar(G)) { goto l451; }  goto l450;
  l451:;	  G->pos= yypos450; G->thunkpos= yythunkpos450;  if (!yy_Newline(G)) { goto l436; }
  {  int yypos452= G->pos, yythunkpos452= G->thunkpos;  if (!yy_BlankLine(G)) { goto l452; }  goto l436;
  l452:;	  G->pos= yypos452; G->thunkpos= yythunkpos452;
  }
  }
  l450:;	
  }
  l439:;	
  l437:;	
  {  int yypos438= G->pos, yythunkpos438= G->thunkpos;
  {  int yypos453= G->pos, yythunkpos453= G->thunkpos;
  {  int yypos457= G->pos, yythunkpos457= G->thunkpos;  if (!yymatchChar(G, '`')) goto l457;  goto l454;
  l457:;	  G->pos= yypos457; G->thunkpos= yythunkpos457;
  }  if (!yy_Nonspacechar(G)) { goto l454; }
  l455:;	
  {  int yypos456= G->pos, yythunkpos456= G->thunkpos;
  {  int yypos458= G->pos, yythunkpos458= G->thunkpos;  if (!yymatchChar(G, '`')) goto l458;  goto l456;
  l458:;	  G->pos= yypos458; G->thunkpos= yythunkpos458;
  }  if (!yy_Nonspacechar(G)) { goto l456; }  goto l455;
  l456:;	  G->pos= yypos456; G->thunkpos= yythunkpos456;
  }  goto l453;
  l454:;	  G->pos= yypos453; G->thunkpos= yythunkpos453;
  {  int yypos460= G->pos, yythunkpos460= G->thunkpos;  if (!yy_Ticks1(G)) { goto l460; }  goto l459;
  l460:;	  G->pos= yypos460; G->thunkpos= yythunkpos460;
  }  if (!yymatchChar(G, '`')) goto l459;
  l461:;	
  {  int yypos462= G->pos, yythunkpos462= G->thunkpos;  if (!yymatchChar(G, '`')) goto l462;  goto l461;
  l462:;	  G->pos= yypos462; G->thunkpos= yythunkpos462;
  }  goto l453;
  l459:;	  G->pos= yypos453; G->thunkpos= yythunkpos453;
  {  int yypos463= G->pos, yythunkpos463= G->thunkpos;  if (!yy_Sp(G)) { goto l463; }  if (!yy_Ticks1(G)) { goto l463; }  goto l438;
  l463:;	  G->pos= yypos463; G->thunkpos= yythunkpos463;
  }
  {  int yypos464= G->pos, yythunkpos464= G->thunkpos;  if (!yy_Spacechar(G)) { goto l465; }  goto l464;
  l465:;	  G->pos= yypos464; G->thunkpos= yythunkpos464;  if (!yy_Newline(G)) { goto l438; }
  {  int yypos466= G->pos, yythunkpos466= G->thunkpos;  if (!yy_BlankLine(G)) { goto l466; }  goto l438;
  l466:;	  G->pos= yypos466; G->thunkpos= yythunkpos466;
  }
  }
  l464:;	
  }
  l453:;	  goto l437;
  l438:;	  G->pos= yypos438; G->thunkpos= yythunkpos438;
  }  if (!yy_Sp(G)) { goto l436; }  if (!yy_Ticks1(G)) { goto l436; }  goto l435;
  l436:;	  G->pos= yypos435; G->thunkpos= yythunkpos435;  if (!yy_Ticks2(G)) { goto l467; }  yyDo(G, yySet, -1, 0);  if (!yy_Sp(G)) { goto l467; }
  {  int yypos470= G->pos, yythunkpos470= G->thunkpos;
  {  int yypos474= G->pos, yythunkpos474= G->thunkpos;  if (!yymatchChar(G, '`')) goto l474;  goto l471;
  l474:;	  G->pos= yypos474; G->thunkpos= yythunkpos474;
  }  if (!yy_Nonspacechar(G)) { goto l471; }
  l472:;	
  {  int yypos473= G->pos, yythunkpos473= G->thunkpos;
  {  int yypos475= G->pos, yythunkpos475= G->thunkpos;  if (!yymatchChar(G, '`')) goto l475;  goto l473;
  l475:;	  G->pos= yypos475; G->thunkpos= yythunkpos475;
  }  if (!yy_Nonspacechar(G)) { goto l473; }  goto l472;
  l473:;	  G->pos= yypos473; G->thunkpos= yythunkpos473;
  }  goto l470;
  l471:;	  G->pos= yypos470; G->thunkpos= yythunkpos470;
  {  int yypos477= G->pos, yythunkpos477= G->thunkpos;  if (!yy_Ticks2(G)) { goto l477; }  goto l476;
  l477:;	  G->pos= yypos477; G->thunkpos= yythunkpos477;
  }  if (!yymatchChar(G, '`')) goto l476;
  l478:;	
  {  int yypos479= G->pos, yythunkpos479= G->thunkpos;  if (!yymatchChar(G, '`')) goto l479;  goto l478;
  l479:;	  G->pos= yypos479; G->thunkpos= yythunkpos479;
  }  goto l470;
  l476:;	  G->pos= yypos470; G->thunkpos= yythunkpos470;
  {  int yypos480= G->pos, yythunkpos480= G->thunkpos;  if (!yy_Sp(G)) { goto l480; }  if (!yy_Ticks2(G)) { goto l480; }  goto l467;
  l480:;	  G->pos= yypos480; G->thunkpos= yythunkpos480;
  }
  {  int yypos481= G->pos, yythunkpos481= G->thunkpos;  if (!yy_Spacechar(G)) { goto l482; }  goto l481;
  l482:;	  G->pos= yypos481; G->thunkpos= yythunkpos481;  if (!yy_Newline(G)) { goto l467; }
  {  int yypos483= G->pos, yythunkpos483= G->thunkpos;  if (!yy_BlankLine(G)) { goto l483; }  goto l467;
  l483:;	  G->pos= yypos483; G->thunkpos= yythunkpos483;
  }
  }
  l481:;	
  }
  l470:;	
  l468:;	
  {  int yypos469= G->pos, yythunkpos469= G->thunkpos;
  {  int yypos484= G->pos, yythunkpos484= G->thunkpos;
  {  int yypos488= G->pos, yythunkpos488= G->thunkpos;  if (!yymatchChar(G, '`')) goto l488;  goto l485;
  l488:;	  G->pos= yypos488; G->thunkpos= yythunkpos488;
  }  if (!yy_Nonspacechar(G)) { goto l485; }
  l486:;	
  {  int yypos487= G->pos, yythunkpos487= G->thunkpos;
  {  int yypos489= G->pos, yythunkpos489= G->thunkpos;  if (!yymatchChar(G, '`')) goto l489;  goto l487;
  l489:;	  G->pos= yypos489; G->thunkpos= yythunkpos489;
  }  if (!yy_Nonspacechar(G)) { goto l487; }  goto l486;
  l487:;	  G->pos= yypos487; G->thunkpos= yythunkpos487;
  }  goto l484;
  l485:;	  G->pos= yypos484; G->thunkpos= yythunkpos484;
  {  int yypos491= G->pos, yythunkpos491= G->thunkpos;  if (!yy_Ticks2(G)) { goto l491; }  goto l490;
  l491:;	  G->pos= yypos491; G->thunkpos= yythunkpos491;
  }  if (!yymatchChar(G, '`')) goto l490;
  l492:;	
  {  int yypos493= G->pos, yythunkpos493= G->thunkpos;  if (!yymatchChar(G, '`')) goto l493;  goto l492;
  l493:;	  G->pos= yypos493; G->thunkpos= yythunkpos493;
  }  goto l484;
  l490:;	  G->pos= yypos484; G->thunkpos= yythunkpos484;
  {  int yypos494= G->pos, yythunkpos494= G->thunkpos;  if (!yy_Sp(G)) { goto l494; }  if (!yy_Ticks2(G)) { goto l494; }  goto l469;
  l494:;	  G->pos= yypos494; G->thunkpos= yythunkpos494;
  }
  {  int yypos495= G->pos, yythunkpos495= G->thunkpos;  if (!yy_Spacechar(G)) { goto l496; }  goto l495;
  l496:;	  G->pos= yypos495; G->thunkpos= yythunkpos495;  if (!yy_Newline(G)) { goto l469; }
  {  int yypos497= G->pos, yythunkpos497= G->thunkpos;  if (!yy_BlankLine(G)) { goto l497; }  goto l469;
  l497:;	  G->pos= yypos497; G->thunkpos= yythunkpos497;
  }
  }
  l495:;	
  }
  l484:;	  goto l468;
  l469:;	  G->pos= yypos469; G->thunkpos= yythunkpos469;
  }  if (!yy_Sp(G)) { goto l467; }  if (!yy_Ticks2(G)) { goto l467; }  goto l435;
  l467:;	  G->pos= yypos435; G->thunkpos= yythunkpos435;  if (!yy_Ticks3(G)) { goto l498; }  yyDo(G, yySet, -1, 0);  if (!yy_Sp(G)) { goto l498; }
  {  int yypos501= G->pos, yythunkpos501= G->thunkpos;
  {  int yypos505= G->pos, yythunkpos505= G->thunkpos;  if (!yymatchChar(G, '`')) goto l505;  goto l502;
  l505:;	  G->pos= yypos505; G->thunkpos= yythunkpos505;
  }  if (!yy_Nonspacechar(G)) { goto l502; }
  l503:;	
  {  int yypos504= G->pos, yythunkpos504= G->thunkpos;
  {  int yypos506= G->pos, yythunkpos506= G->thunkpos;  if (!yymatchChar(G, '`')) goto l506;  goto l504;
  l506:;	  G->pos= yypos506; G->thunkpos= yythunkpos506;
  }  if (!yy_Nonspacechar(G)) { goto l504; }  goto l503;
  l504:;	  G->pos= yypos504; G->thunkpos= yythunkpos504;
  }  goto l501;
  l502:;	  G->pos= yypos501; G->thunkpos= yythunkpos501;
  {  int yypos508= G->pos, yythunkpos508= G->thunkpos;  if (!yy_Ticks3(G)) { goto l508; }  goto l507;
  l508:;	  G->pos= yypos508; G->thunkpos= yythunkpos508;
  }  if (!yymatchChar(G, '`')) goto l507;
  l509:;	
  {  int yypos510= G->pos, yythunkpos510= G->thunkpos;  if (!yymatchChar(G, '`')) goto l510;  goto l509;
  l510:;	  G->pos= yypos510; G->thunkpos= yythunkpos510;
  }  goto l501;
  l507:;	  G->pos= yypos501; G->thunkpos= yythunkpos501;
  {  int yypos511= G->pos, yythunkpos511= G->thunkpos;  if (!yy_Sp(G)) { goto l511; }  if (!yy_Ticks3(G)) { goto l511; }  goto l498;
  l511:;	  G->pos= yypos511; G->thunkpos= yythunkpos511;
  }
  {  int yypos512= G->pos, yythunkpos512= G->thunkpos;  if (!yy_Spacechar(G)) { goto l513; }  goto l512;
  l513:;	  G->pos= yypos512; G->thunkpos= yythunkpos512;  if (!yy_Newline(G)) { goto l498; }
  {  int yypos514= G->pos, yythunkpos514= G->thunkpos;  if (!yy_BlankLine(G)) { goto l514; }  goto l498;
  l514:;	  G->pos= yypos514; G->thunkpos= yythunkpos514;
  }
  }
  l512:;	
  }
  l501:;	
  l499:;	
  {  int yypos500= G->pos, yythunkpos500= G->thunkpos;
  {  int yypos515= G->pos, yythunkpos515= G->thunkpos;
  {  int yypos519= G->pos, yythunkpos519= G->thunkpos;  if (!yymatchChar(G, '`')) goto l519;  goto l516;
  l519:;	  G->pos= yypos519; G->thunkpos= yythunkpos519;
  }  if (!yy_Nonspacechar(G)) { goto l516; }
  l517:;	
  {  int yypos518= G->pos, yythunkpos518= G->thunkpos;
  {  int yypos520= G->pos, yythunkpos520= G->thunkpos;  if (!yymatchChar(G, '`')) goto l520;  goto l518;
  l520:;	  G->pos= yypos520; G->thunkpos= yythunkpos520;
  }  if (!yy_Nonspacechar(G)) { goto l518; }  goto l517;
  l518:;	  G->pos= yypos518; G->thunkpos= yythunkpos518;
  }  goto l515;
  l516:;	  G->pos= yypos515; G->thunkpos= yythunkpos515;
  {  int yypos522= G->pos, yythunkpos522= G->thunkpos;  if (!yy_Ticks3(G)) { goto l522; }  goto l521;
  l522:;	  G->pos= yypos522; G->thunkpos= yythunkpos522;
  }  if (!yymatchChar(G, '`')) goto l521;
  l523:;	
  {  int yypos524= G->pos, yythunkpos524= G->thunkpos;  if (!yymatchChar(G, '`')) goto l524;  goto l523;
  l524:;	  G->pos= yypos524; G->thunkpos= yythunkpos524;
  }  goto l515;
  l521:;	  G->pos= yypos515; G->thunkpos= yythunkpos515;
  {  int yypos525= G->pos, yythunkpos525= G->thunkpos;  if (!yy_Sp(G)) { goto l525; }  if (!yy_Ticks3(G)) { goto l525; }  goto l500;
  l525:;	  G->pos= yypos525; G->thunkpos= yythunkpos525;
  }
  {  int yypos526= G->pos, yythunkpos526= G->thunkpos;  if (!yy_Spacechar(G)) { goto l527; }  goto l526;
  l527:;	  G->pos= yypos526; G->thunkpos= yythunkpos526;  if (!yy_Newline(G)) { goto l500; }
  {  int yypos528= G->pos, yythunkpos528= G->thunkpos;  if (!yy_BlankLine(G)) { goto l528; }  goto l500;
  l528:;	  G->pos= yypos528; G->thunkpos= yythunkpos528;
  }
  }
  l526:;	
  }
  l515:;	  goto l499;
  l500:;	  G->pos= yypos500; G->thunkpos= yythunkpos500;
  }  if (!yy_Sp(G)) { goto l498; }  if (!yy_Ticks3(G)) { goto l498; }  goto l435;
  l498:;	  G->pos= yypos435; G->thunkpos= yythunkpos435;  if (!yy_Ticks4(G)) { goto l529; }  yyDo(G, yySet, -1, 0);  if (!yy_Sp(G)) { goto l529; }
  {  int yypos532= G->pos, yythunkpos532= G->thunkpos;
  {  int yypos536= G->pos, yythunkpos536= G->thunkpos;  if (!yymatchChar(G, '`')) goto l536;  goto l533;
  l536:;	  G->pos= yypos536; G->thunkpos= yythunkpos536;
  }  if (!yy_Nonspacechar(G)) { goto l533; }
  l534:;	
  {  int yypos535= G->pos, yythunkpos535= G->thunkpos;
  {  int yypos537= G->pos, yythunkpos537= G->thunkpos;  if (!yymatchChar(G, '`')) goto l537;  goto l535;
  l537:;	  G->pos= yypos537; G->thunkpos= yythunkpos537;
  }  if (!yy_Nonspacechar(G)) { goto l535; }  goto l534;
  l535:;	  G->pos= yypos535; G->thunkpos= yythunkpos535;
  }  goto l532;
  l533:;	  G->pos= yypos532; G->thunkpos= yythunkpos532;
  {  int yypos539= G->pos, yythunkpos539= G->thunkpos;  if (!yy_Ticks4(G)) { goto l539; }  goto l538;
  l539:;	  G->pos= yypos539; G->thunkpos= yythunkpos539;
  }  if (!yymatchChar(G, '`')) goto l538;
  l540:;	
  {  int yypos541= G->pos, yythunkpos541= G->thunkpos;  if (!yymatchChar(G, '`')) goto l541;  goto l540;
  l541:;	  G->pos= yypos541; G->thunkpos= yythunkpos541;
  }  goto l532;
  l538:;	  G->pos= yypos532; G->thunkpos= yythunkpos532;
  {  int yypos542= G->pos, yythunkpos542= G->thunkpos;  if (!yy_Sp(G)) { goto l542; }  if (!yy_Ticks4(G)) { goto l542; }  goto l529;
  l542:;	  G->pos= yypos542; G->thunkpos= yythunkpos542;
  }
  {  int yypos543= G->pos, yythunkpos543= G->thunkpos;  if (!yy_Spacechar(G)) { goto l544; }  goto l543;
  l544:;	  G->pos= yypos543; G->thunkpos= yythunkpos543;  if (!yy_Newline(G)) { goto l529; }
  {  int yypos545= G->pos, yythunkpos545= G->thunkpos;  if (!yy_BlankLine(G)) { goto l545; }  goto l529;
  l545:;	  G->pos= yypos545; G->thunkpos= yythunkpos545;
  }
  }
  l543:;	
  }
  l532:;	
  l530:;	
  {  int yypos531= G->pos, yythunkpos531= G->thunkpos;
  {  int yypos546= G->pos, yythunkpos546= G->thunkpos;
  {  int yypos550= G->pos, yythunkpos550= G->thunkpos;  if (!yymatchChar(G, '`')) goto l550;  goto l547;
  l550:;	  G->pos= yypos550; G->thunkpos= yythunkpos550;
  }  if (!yy_Nonspacechar(G)) { goto l547; }
  l548:;	
  {  int yypos549= G->pos, yythunkpos549= G->thunkpos;
  {  int yypos551= G->pos, yythunkpos551= G->thunkpos;  if (!yymatchChar(G, '`')) goto l551;  goto l549;
  l551:;	  G->pos= yypos551; G->thunkpos= yythunkpos551;
  }  if (!yy_Nonspacechar(G)) { goto l549; }  goto l548;
  l549:;	  G->pos= yypos549; G->thunkpos= yythunkpos549;
  }  goto l546;
  l547:;	  G->pos= yypos546; G->thunkpos= yythunkpos546;
  {  int yypos553= G->pos, yythunkpos553= G->thunkpos;  if (!yy_Ticks4(G)) { goto l553; }  goto l552;
  l553:;	  G->pos= yypos553; G->thunkpos= yythunkpos553;
  }  if (!yymatchChar(G, '`')) goto l552;
  l554:;	
  {  int yypos555= G->pos, yythunkpos555= G->thunkpos;  if (!yymatchChar(G, '`')) goto l555;  goto l554;
  l555:;	  G->pos= yypos555; G->thunkpos= yythunkpos555;
  }  goto l546;
  l552:;	  G->pos= yypos546; G->thunkpos= yythunkpos546;
  {  int yypos556= G->pos, yythunkpos556= G->thunkpos;  if (!yy_Sp(G)) { goto l556; }  if (!yy_Ticks4(G)) { goto l556; }  goto l531;
  l556:;	  G->pos= yypos556; G->thunkpos= yythunkpos556;
  }
  {  int yypos557= G->pos, yythunkpos557= G->thunkpos;  if (!yy_Spacechar(G)) { goto l558; }  goto l557;
  l558:;	  G->pos= yypos557; G->thunkpos= yythunkpos557;  if (!yy_Newline(G)) { goto l531; }
  {  int yypos559= G->pos, yythunkpos559= G->thunkpos;  if (!yy_BlankLine(G)) { goto l559; }  goto l531;
  l559:;	  G->pos= yypos559; G->thunkpos= yythunkpos559;
  }
  }
  l557:;	
  }
  l546:;	  goto l530;
  l531:;	  G->pos= yypos531; G->thunkpos= yythunkpos531;
  }  if (!yy_Sp(G)) { goto l529; }  if (!yy_Ticks4(G)) { goto l529; }  goto l435;
  l529:;	  G->pos= yypos435; G->thunkpos= yythunkpos435;  if (!yy_Ticks5(G)) { goto l434; }  yyDo(G, yySet, -1, 0);  if (!yy_Sp(G)) { goto l434; }
  {  int yypos562= G->pos, yythunkpos562= G->thunkpos;
  {  int yypos566= G->pos, yythunkpos566= G->thunkpos;  if (!yymatchChar(G, '`')) goto l566;  goto l563;
  l566:;	  G->pos= yypos566; G->thunkpos= yythunkpos566;
  }  if (!yy_Nonspacechar(G)) { goto l563; }
  l564:;	
  {  int yypos565= G->pos, yythunkpos565= G->thunkpos;
  {  int yypos567= G->pos, yythunkpos567= G->thunkpos;  if (!yymatchChar(G, '`')) goto l567;  goto l565;
  l567:;	  G->pos= yypos567; G->thunkpos= yythunkpos567;
  }  if (!yy_Nonspacechar(G)) { goto l565; }  goto l564;
  l565:;	  G->pos= yypos565; G->thunkpos= yythunkpos565;
  }  goto l562;
  l563:;	  G->pos= yypos562; G->thunkpos= yythunkpos562;
  {  int yypos569= G->pos, yythunkpos569= G->thunkpos;  if (!yy_Ticks5(G)) { goto l569; }  goto l568;
  l569:;	  G->pos= yypos569; G->thunkpos= yythunkpos569;
  }  if (!yymatchChar(G, '`')) goto l568;
  l570:;	
  {  int yypos571= G->pos, yythunkpos571= G->thunkpos;  if (!yymatchChar(G, '`')) goto l571;  goto l570;
  l571:;	  G->pos= yypos571; G->thunkpos= yythunkpos571;
  }  goto l562;
  l568:;	  G->pos= yypos562; G->thunkpos= yythunkpos562;
  {  int yypos572= G->pos, yythunkpos572= G->thunkpos;  if (!yy_Sp(G)) { goto l572; }  if (!yy_Ticks5(G)) { goto l572; }  goto l434;
  l572:;	  G->pos= yypos572; G->thunkpos= yythunkpos572;
  }
  {  int yypos573= G->pos, yythunkpos573= G->thunkpos;  if (!yy_Spacechar(G)) { goto l574; }  goto l573;
  l574:;	  G->pos= yypos573; G->thunkpos= yythunkpos573;  if (!yy_Newline(G)) { goto l434; }
  {  int yypos575= G->pos, yythunkpos575= G->thunkpos;  if (!yy_BlankLine(G)) { goto l575; }  goto l434;
  l575:;	  G->pos= yypos575; G->thunkpos= yythunkpos575;
  }
  }
  l573:;	
  }
  l562:;	
  l560:;	
  {  int yypos561= G->pos, yythunkpos561= G->thunkpos;
  {  int yypos576= G->pos, yythunkpos576= G->thunkpos;
  {  int yypos580= G->pos, yythunkpos580= G->thunkpos;  if (!yymatchChar(G, '`')) goto l580;  goto l577;
  l580:;	  G->pos= yypos580; G->thunkpos= yythunkpos580;
  }  if (!yy_Nonspacechar(G)) { goto l577; }
  l578:;	
  {  int yypos579= G->pos, yythunkpos579= G->thunkpos;
  {  int yypos581= G->pos, yythunkpos581= G->thunkpos;  if (!yymatchChar(G, '`')) goto l581;  goto l579;
  l581:;	  G->pos= yypos581; G->thunkpos= yythunkpos581;
  }  if (!yy_Nonspacechar(G)) { goto l579; }  goto l578;
  l579:;	  G->pos= yypos579; G->thunkpos= yythunkpos579;
  }  goto l576;
  l577:;	  G->pos= yypos576; G->thunkpos= yythunkpos576;
  {  int yypos583= G->pos, yythunkpos583= G->thunkpos;  if (!yy_Ticks5(G)) { goto l583; }  goto l582;
  l583:;	  G->pos= yypos583; G->thunkpos= yythunkpos583;
  }  if (!yymatchChar(G, '`')) goto l582;
  l584:;	
  {  int yypos585= G->pos, yythunkpos585= G->thunkpos;  if (!yymatchChar(G, '`')) goto l585;  goto l584;
  l585:;	  G->pos= yypos585; G->thunkpos= yythunkpos585;
  }  goto l576;
  l582:;	  G->pos= yypos576; G->thunkpos= yythunkpos576;
  {  int yypos586= G->pos, yythunkpos586= G->thunkpos;  if (!yy_Sp(G)) { goto l586; }  if (!yy_Ticks5(G)) { goto l586; }  goto l561;
  l586:;	  G->pos= yypos586; G->thunkpos= yythunkpos586;
  }
  {  int yypos587= G->pos, yythunkpos587= G->thunkpos;  if (!yy_Spacechar(G)) { goto l588; }  goto l587;
  l588:;	  G->pos= yypos587; G->thunkpos= yythunkpos587;  if (!yy_Newline(G)) { goto l561; }
  {  int yypos589= G->pos, yythunkpos589= G->thunkpos;  if (!yy_BlankLine(G)) { goto l589; }  goto l561;
  l589:;	  G->pos= yypos589; G->thunkpos= yythunkpos589;
  }
  }
  l587:;	
  }
  l576:;	  goto l560;
  l561:;	  G->pos= yypos561; G->thunkpos= yythunkpos561;
  }  if (!yy_Sp(G)) { goto l434; }  if (!yy_Ticks5(G)) { goto l434; }
  }
  l435:;	  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l434;  yyDo(G, yy_1_Code, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Code", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l434:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Code", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_InlineNote(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "InlineNote"));  yyText(G, G->begin, G->end);  if (!( EXT(pmh_EXT_NOTES) )) goto l590;  if (!yymatchString(G, "^[")) goto l590;
  {  int yypos593= G->pos, yythunkpos593= G->thunkpos;  if (!yymatchChar(G, ']')) goto l593;  goto l590;
  l593:;	  G->pos= yypos593; G->thunkpos= yythunkpos593;
  }  if (!yy_Inline(G)) { goto l590; }
  l591:;	
  {  int yypos592= G->pos, yythunkpos592= G->thunkpos;
  {  int yypos594= G->pos, yythunkpos594= G->thunkpos;  if (!yymatchChar(G, ']')) goto l594;  goto l592;
  l594:;	  G->pos= yypos594; G->thunkpos= yythunkpos594;
  }  if (!yy_Inline(G)) { goto l592; }  goto l591;
  l592:;	  G->pos= yypos592; G->thunkpos= yythunkpos592;
  }  if (!yymatchChar(G, ']')) goto l590;
  yyprintf((stderr, "  ok   %s @ %s\n", "InlineNote", G->buf+G->pos));
  return 1;
  l590:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "InlineNote", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_NoteReference(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "NoteReference"));  yyText(G, G->begin, G->end);  if (!( EXT(pmh_EXT_NOTES) )) goto l595;  if (!yy_RawNoteReference(G)) { goto l595; }
  yyprintf((stderr, "  ok   %s @ %s\n", "NoteReference", G->buf+G->pos));
  return 1;
  l595:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "NoteReference", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Link(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Link"));
  {  int yypos597= G->pos, yythunkpos597= G->thunkpos;  if (!yy_ExplicitLink(G)) { goto l598; }  goto l597;
  l598:;	  G->pos= yypos597; G->thunkpos= yythunkpos597;  if (!yy_ReferenceLink(G)) { goto l599; }  goto l597;
  l599:;	  G->pos= yypos597; G->thunkpos= yythunkpos597;  if (!yy_AutoLink(G)) { goto l596; }
  }
  l597:;	  yyDo(G, yy_1_Link, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Link", G->buf+G->pos));
  return 1;
  l596:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Link", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Image(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Image"));  if (!yymatchChar(G, '!')) goto l600;
  {  int yypos601= G->pos, yythunkpos601= G->thunkpos;  if (!yy_ExplicitLink(G)) { goto l602; }  goto l601;
  l602:;	  G->pos= yypos601; G->thunkpos= yythunkpos601;  if (!yy_ExplicitLinkSize(G)) { goto l603; }  goto l601;
  l603:;	  G->pos= yypos601; G->thunkpos= yythunkpos601;  if (!yy_ReferenceLink(G)) { goto l600; }
  }
  l601:;	  yyDo(G, yy_1_Image, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Image", G->buf+G->pos));
  return 1;
  l600:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Image", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Strike(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "Strike"));  yyText(G, G->begin, G->end);  if (!( EXT(pmh_EXT_STRIKE) )) goto l604;  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l604;  if (!yy_LocMarker(G)) { goto l604; }  yyDo(G, yySet, -1, 0);  if (!yymatchString(G, "~~")) goto l604;
  {  int yypos605= G->pos, yythunkpos605= G->thunkpos;  if (!yy_Whitespace(G)) { goto l605; }  goto l604;
  l605:;	  G->pos= yypos605; G->thunkpos= yythunkpos605;
  }
  {  int yypos608= G->pos, yythunkpos608= G->thunkpos;  if (!yymatchString(G, "~~")) goto l608;  goto l604;
  l608:;	  G->pos= yypos608; G->thunkpos= yythunkpos608;
  }  if (!yy_Inline(G)) { goto l604; }
  l606:;	
  {  int yypos607= G->pos, yythunkpos607= G->thunkpos;
  {  int yypos609= G->pos, yythunkpos609= G->thunkpos;  if (!yymatchString(G, "~~")) goto l609;  goto l607;
  l609:;	  G->pos= yypos609; G->thunkpos= yythunkpos609;
  }  if (!yy_Inline(G)) { goto l607; }  goto l606;
  l607:;	  G->pos= yypos607; G->thunkpos= yythunkpos607;
  }  if (!yymatchString(G, "~~")) goto l604;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l604;  yyDo(G, yy_1_Strike, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Strike", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l604:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Strike", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Emph(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Emph"));
  {  int yypos611= G->pos, yythunkpos611= G->thunkpos;  if (!yy_EmphStar(G)) { goto l612; }  goto l611;
  l612:;	  G->pos= yypos611; G->thunkpos= yythunkpos611;  if (!yy_EmphUl(G)) { goto l610; }
  }
  l611:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Emph", G->buf+G->pos));
  return 1;
  l610:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Emph", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Strong(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Strong"));
  {  int yypos614= G->pos, yythunkpos614= G->thunkpos;  if (!yy_StrongStar(G)) { goto l615; }  goto l614;
  l615:;	  G->pos= yypos614; G->thunkpos= yythunkpos614;  if (!yy_StrongUl(G)) { goto l613; }
  }
  l614:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Strong", G->buf+G->pos));
  return 1;
  l613:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Strong", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_UlOrStarLine(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "UlOrStarLine"));
  {  int yypos617= G->pos, yythunkpos617= G->thunkpos;  if (!yy_UlLine(G)) { goto l618; }  goto l617;
  l618:;	  G->pos= yypos617; G->thunkpos= yythunkpos617;  if (!yy_StarLine(G)) { goto l616; }
  }
  l617:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "UlOrStarLine", G->buf+G->pos));
  return 1;
  l616:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "UlOrStarLine", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Str(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Str"));  if (!yy_NormalChar(G)) { goto l619; }
  l620:;	
  {  int yypos621= G->pos, yythunkpos621= G->thunkpos;
  {  int yypos622= G->pos, yythunkpos622= G->thunkpos;  if (!yy_NormalChar(G)) { goto l623; }  goto l622;
  l623:;	  G->pos= yypos622; G->thunkpos= yythunkpos622;  if (!yymatchChar(G, '_')) goto l621;
  l624:;	
  {  int yypos625= G->pos, yythunkpos625= G->thunkpos;  if (!yymatchChar(G, '_')) goto l625;  goto l624;
  l625:;	  G->pos= yypos625; G->thunkpos= yythunkpos625;
  }
  {  int yypos626= G->pos, yythunkpos626= G->thunkpos;  if (!yy_Alphanumeric(G)) { goto l621; }  G->pos= yypos626; G->thunkpos= yythunkpos626;
  }
  }
  l622:;	  goto l620;
  l621:;	  G->pos= yypos621; G->thunkpos= yythunkpos621;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "Str", G->buf+G->pos));
  return 1;
  l619:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Str", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_InStyleTags(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "InStyleTags"));  if (!yy_StyleOpen(G)) { goto l627; }
  l628:;	
  {  int yypos629= G->pos, yythunkpos629= G->thunkpos;
  {  int yypos630= G->pos, yythunkpos630= G->thunkpos;  if (!yy_StyleClose(G)) { goto l630; }  goto l629;
  l630:;	  G->pos= yypos630; G->thunkpos= yythunkpos630;
  }  if (!yymatchDot(G)) goto l629;  goto l628;
  l629:;	  G->pos= yypos629; G->thunkpos= yythunkpos629;
  }  if (!yy_StyleClose(G)) { goto l627; }
  yyprintf((stderr, "  ok   %s @ %s\n", "InStyleTags", G->buf+G->pos));
  return 1;
  l627:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "InStyleTags", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_StyleClose(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "StyleClose"));  if (!yymatchChar(G, '<')) goto l631;  if (!yy_Spnl(G)) { goto l631; }  if (!yymatchChar(G, '/')) goto l631;
  {  int yypos632= G->pos, yythunkpos632= G->thunkpos;  if (!yymatchString(G, "style")) goto l633;  goto l632;
  l633:;	  G->pos= yypos632; G->thunkpos= yythunkpos632;  if (!yymatchString(G, "STYLE")) goto l631;
  }
  l632:;	  if (!yy_Spnl(G)) { goto l631; }  if (!yymatchChar(G, '>')) goto l631;
  yyprintf((stderr, "  ok   %s @ %s\n", "StyleClose", G->buf+G->pos));
  return 1;
  l631:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "StyleClose", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_StyleOpen(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "StyleOpen"));  if (!yymatchChar(G, '<')) goto l634;  if (!yy_Spnl(G)) { goto l634; }
  {  int yypos635= G->pos, yythunkpos635= G->thunkpos;  if (!yymatchString(G, "style")) goto l636;  goto l635;
  l636:;	  G->pos= yypos635; G->thunkpos= yythunkpos635;  if (!yymatchString(G, "STYLE")) goto l634;
  }
  l635:;	  if (!yy_Spnl(G)) { goto l634; }
  l637:;	
  {  int yypos638= G->pos, yythunkpos638= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l638; }  goto l637;
  l638:;	  G->pos= yypos638; G->thunkpos= yythunkpos638;
  }  if (!yymatchChar(G, '>')) goto l634;
  yyprintf((stderr, "  ok   %s @ %s\n", "StyleOpen", G->buf+G->pos));
  return 1;
  l634:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "StyleOpen", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockType(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockType"));
  {  int yypos640= G->pos, yythunkpos640= G->thunkpos;  if (!yymatchString(G, "address")) goto l641;  goto l640;
  l641:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "blockquote")) goto l642;  goto l640;
  l642:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "center")) goto l643;  goto l640;
  l643:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "dir")) goto l644;  goto l640;
  l644:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "div")) goto l645;  goto l640;
  l645:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "dl")) goto l646;  goto l640;
  l646:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "fieldset")) goto l647;  goto l640;
  l647:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "form")) goto l648;  goto l640;
  l648:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "h1")) goto l649;  goto l640;
  l649:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "h2")) goto l650;  goto l640;
  l650:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "h3")) goto l651;  goto l640;
  l651:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "h4")) goto l652;  goto l640;
  l652:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "h5")) goto l653;  goto l640;
  l653:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "h6")) goto l654;  goto l640;
  l654:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "hr")) goto l655;  goto l640;
  l655:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "isindex")) goto l656;  goto l640;
  l656:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "menu")) goto l657;  goto l640;
  l657:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "noframes")) goto l658;  goto l640;
  l658:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "noscript")) goto l659;  goto l640;
  l659:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "ol")) goto l660;  goto l640;
  l660:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchChar(G, 'p')) goto l661;  goto l640;
  l661:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "pre")) goto l662;  goto l640;
  l662:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "table")) goto l663;  goto l640;
  l663:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "ul")) goto l664;  goto l640;
  l664:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "dd")) goto l665;  goto l640;
  l665:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "dt")) goto l666;  goto l640;
  l666:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "frameset")) goto l667;  goto l640;
  l667:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "li")) goto l668;  goto l640;
  l668:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "tbody")) goto l669;  goto l640;
  l669:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "td")) goto l670;  goto l640;
  l670:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "tfoot")) goto l671;  goto l640;
  l671:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "th")) goto l672;  goto l640;
  l672:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "thead")) goto l673;  goto l640;
  l673:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "tr")) goto l674;  goto l640;
  l674:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "script")) goto l675;  goto l640;
  l675:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "ADDRESS")) goto l676;  goto l640;
  l676:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "BLOCKQUOTE")) goto l677;  goto l640;
  l677:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "CENTER")) goto l678;  goto l640;
  l678:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "DIR")) goto l679;  goto l640;
  l679:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "DIV")) goto l680;  goto l640;
  l680:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "DL")) goto l681;  goto l640;
  l681:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "FIELDSET")) goto l682;  goto l640;
  l682:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "FORM")) goto l683;  goto l640;
  l683:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "H1")) goto l684;  goto l640;
  l684:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "H2")) goto l685;  goto l640;
  l685:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "H3")) goto l686;  goto l640;
  l686:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "H4")) goto l687;  goto l640;
  l687:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "H5")) goto l688;  goto l640;
  l688:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "H6")) goto l689;  goto l640;
  l689:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "HR")) goto l690;  goto l640;
  l690:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "ISINDEX")) goto l691;  goto l640;
  l691:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "MENU")) goto l692;  goto l640;
  l692:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "NOFRAMES")) goto l693;  goto l640;
  l693:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "NOSCRIPT")) goto l694;  goto l640;
  l694:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "OL")) goto l695;  goto l640;
  l695:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchChar(G, 'P')) goto l696;  goto l640;
  l696:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "PRE")) goto l697;  goto l640;
  l697:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "TABLE")) goto l698;  goto l640;
  l698:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "UL")) goto l699;  goto l640;
  l699:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "DD")) goto l700;  goto l640;
  l700:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "DT")) goto l701;  goto l640;
  l701:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "FRAMESET")) goto l702;  goto l640;
  l702:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "LI")) goto l703;  goto l640;
  l703:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "TBODY")) goto l704;  goto l640;
  l704:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "TD")) goto l705;  goto l640;
  l705:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "TFOOT")) goto l706;  goto l640;
  l706:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "TH")) goto l707;  goto l640;
  l707:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "THEAD")) goto l708;  goto l640;
  l708:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "TR")) goto l709;  goto l640;
  l709:;	  G->pos= yypos640; G->thunkpos= yythunkpos640;  if (!yymatchString(G, "SCRIPT")) goto l639;
  }
  l640:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockType", G->buf+G->pos));
  return 1;
  l639:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockType", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockSelfClosing(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockSelfClosing"));  if (!yymatchChar(G, '<')) goto l710;  if (!yy_Spnl(G)) { goto l710; }  if (!yy_HtmlBlockType(G)) { goto l710; }  if (!yy_Spnl(G)) { goto l710; }
  l711:;	
  {  int yypos712= G->pos, yythunkpos712= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l712; }  goto l711;
  l712:;	  G->pos= yypos712; G->thunkpos= yythunkpos712;
  }  if (!yymatchChar(G, '/')) goto l710;  if (!yy_Spnl(G)) { goto l710; }  if (!yymatchChar(G, '>')) goto l710;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockSelfClosing", G->buf+G->pos));
  return 1;
  l710:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockSelfClosing", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlComment(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "HtmlComment"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l713;  if (!yy_LocMarker(G)) { goto l713; }  yyDo(G, yySet, -1, 0);  if (!yymatchString(G, "<!--")) goto l713;
  l714:;	
  {  int yypos715= G->pos, yythunkpos715= G->thunkpos;
  {  int yypos716= G->pos, yythunkpos716= G->thunkpos;  if (!yymatchString(G, "-->")) goto l716;  goto l715;
  l716:;	  G->pos= yypos716; G->thunkpos= yythunkpos716;
  }  if (!yymatchDot(G)) goto l715;  goto l714;
  l715:;	  G->pos= yypos715; G->thunkpos= yythunkpos715;
  }  if (!yymatchString(G, "-->")) goto l713;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l713;  yyDo(G, yy_1_HtmlComment, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlComment", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l713:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlComment", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockInTags(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockInTags"));
  {  int yypos718= G->pos, yythunkpos718= G->thunkpos;  if (!yy_HtmlBlockAddress(G)) { goto l719; }  goto l718;
  l719:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockBlockquote(G)) { goto l720; }  goto l718;
  l720:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockCenter(G)) { goto l721; }  goto l718;
  l721:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockDir(G)) { goto l722; }  goto l718;
  l722:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockDiv(G)) { goto l723; }  goto l718;
  l723:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockDl(G)) { goto l724; }  goto l718;
  l724:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockFieldset(G)) { goto l725; }  goto l718;
  l725:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockForm(G)) { goto l726; }  goto l718;
  l726:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockH1(G)) { goto l727; }  goto l718;
  l727:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockH2(G)) { goto l728; }  goto l718;
  l728:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockH3(G)) { goto l729; }  goto l718;
  l729:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockH4(G)) { goto l730; }  goto l718;
  l730:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockH5(G)) { goto l731; }  goto l718;
  l731:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockH6(G)) { goto l732; }  goto l718;
  l732:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockMenu(G)) { goto l733; }  goto l718;
  l733:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockNoframes(G)) { goto l734; }  goto l718;
  l734:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockNoscript(G)) { goto l735; }  goto l718;
  l735:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockOl(G)) { goto l736; }  goto l718;
  l736:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockP(G)) { goto l737; }  goto l718;
  l737:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockPre(G)) { goto l738; }  goto l718;
  l738:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockTable(G)) { goto l739; }  goto l718;
  l739:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockUl(G)) { goto l740; }  goto l718;
  l740:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockDd(G)) { goto l741; }  goto l718;
  l741:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockDt(G)) { goto l742; }  goto l718;
  l742:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockFrameset(G)) { goto l743; }  goto l718;
  l743:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockLi(G)) { goto l744; }  goto l718;
  l744:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockTbody(G)) { goto l745; }  goto l718;
  l745:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockTd(G)) { goto l746; }  goto l718;
  l746:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockTfoot(G)) { goto l747; }  goto l718;
  l747:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockTh(G)) { goto l748; }  goto l718;
  l748:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockThead(G)) { goto l749; }  goto l718;
  l749:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockTr(G)) { goto l750; }  goto l718;
  l750:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockScript(G)) { goto l751; }  goto l718;
  l751:;	  G->pos= yypos718; G->thunkpos= yythunkpos718;  if (!yy_HtmlBlockHead(G)) { goto l717; }
  }
  l718:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockInTags", G->buf+G->pos));
  return 1;
  l717:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockInTags", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockHead(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockHead"));  if (!yy_HtmlBlockOpenHead(G)) { goto l752; }
  l753:;	
  {  int yypos754= G->pos, yythunkpos754= G->thunkpos;
  {  int yypos755= G->pos, yythunkpos755= G->thunkpos;  if (!yy_HtmlBlockCloseHead(G)) { goto l755; }  goto l754;
  l755:;	  G->pos= yypos755; G->thunkpos= yythunkpos755;
  }  if (!yymatchDot(G)) goto l754;  goto l753;
  l754:;	  G->pos= yypos754; G->thunkpos= yythunkpos754;
  }  if (!yy_HtmlBlockCloseHead(G)) { goto l752; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockHead", G->buf+G->pos));
  return 1;
  l752:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockHead", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseHead(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseHead"));  if (!yymatchChar(G, '<')) goto l756;  if (!yy_Spnl(G)) { goto l756; }  if (!yymatchChar(G, '/')) goto l756;
  {  int yypos757= G->pos, yythunkpos757= G->thunkpos;  if (!yymatchString(G, "head")) goto l758;  goto l757;
  l758:;	  G->pos= yypos757; G->thunkpos= yythunkpos757;  if (!yymatchString(G, "HEAD")) goto l756;
  }
  l757:;	  if (!yy_Spnl(G)) { goto l756; }  if (!yymatchChar(G, '>')) goto l756;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseHead", G->buf+G->pos));
  return 1;
  l756:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseHead", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenHead(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenHead"));  if (!yymatchChar(G, '<')) goto l759;  if (!yy_Spnl(G)) { goto l759; }
  {  int yypos760= G->pos, yythunkpos760= G->thunkpos;  if (!yymatchString(G, "head")) goto l761;  goto l760;
  l761:;	  G->pos= yypos760; G->thunkpos= yythunkpos760;  if (!yymatchString(G, "HEAD")) goto l759;
  }
  l760:;	  if (!yy_Spnl(G)) { goto l759; }
  l762:;	
  {  int yypos763= G->pos, yythunkpos763= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l763; }  goto l762;
  l763:;	  G->pos= yypos763; G->thunkpos= yythunkpos763;
  }  if (!yymatchChar(G, '>')) goto l759;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenHead", G->buf+G->pos));
  return 1;
  l759:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenHead", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockScript(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockScript"));  if (!yy_HtmlBlockOpenScript(G)) { goto l764; }
  l765:;	
  {  int yypos766= G->pos, yythunkpos766= G->thunkpos;
  {  int yypos767= G->pos, yythunkpos767= G->thunkpos;  if (!yy_HtmlBlockCloseScript(G)) { goto l767; }  goto l766;
  l767:;	  G->pos= yypos767; G->thunkpos= yythunkpos767;
  }  if (!yymatchDot(G)) goto l766;  goto l765;
  l766:;	  G->pos= yypos766; G->thunkpos= yythunkpos766;
  }  if (!yy_HtmlBlockCloseScript(G)) { goto l764; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockScript", G->buf+G->pos));
  return 1;
  l764:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockScript", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseScript(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseScript"));  if (!yymatchChar(G, '<')) goto l768;  if (!yy_Spnl(G)) { goto l768; }  if (!yymatchChar(G, '/')) goto l768;
  {  int yypos769= G->pos, yythunkpos769= G->thunkpos;  if (!yymatchString(G, "script")) goto l770;  goto l769;
  l770:;	  G->pos= yypos769; G->thunkpos= yythunkpos769;  if (!yymatchString(G, "SCRIPT")) goto l768;
  }
  l769:;	  if (!yy_Spnl(G)) { goto l768; }  if (!yymatchChar(G, '>')) goto l768;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseScript", G->buf+G->pos));
  return 1;
  l768:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseScript", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenScript(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenScript"));  if (!yymatchChar(G, '<')) goto l771;  if (!yy_Spnl(G)) { goto l771; }
  {  int yypos772= G->pos, yythunkpos772= G->thunkpos;  if (!yymatchString(G, "script")) goto l773;  goto l772;
  l773:;	  G->pos= yypos772; G->thunkpos= yythunkpos772;  if (!yymatchString(G, "SCRIPT")) goto l771;
  }
  l772:;	  if (!yy_Spnl(G)) { goto l771; }
  l774:;	
  {  int yypos775= G->pos, yythunkpos775= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l775; }  goto l774;
  l775:;	  G->pos= yypos775; G->thunkpos= yythunkpos775;
  }  if (!yymatchChar(G, '>')) goto l771;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenScript", G->buf+G->pos));
  return 1;
  l771:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenScript", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockTr(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockTr"));  if (!yy_HtmlBlockOpenTr(G)) { goto l776; }
  l777:;	
  {  int yypos778= G->pos, yythunkpos778= G->thunkpos;
  {  int yypos779= G->pos, yythunkpos779= G->thunkpos;  if (!yy_HtmlBlockTr(G)) { goto l780; }  goto l779;
  l780:;	  G->pos= yypos779; G->thunkpos= yythunkpos779;
  {  int yypos781= G->pos, yythunkpos781= G->thunkpos;  if (!yy_HtmlBlockCloseTr(G)) { goto l781; }  goto l778;
  l781:;	  G->pos= yypos781; G->thunkpos= yythunkpos781;
  }  if (!yymatchDot(G)) goto l778;
  }
  l779:;	  goto l777;
  l778:;	  G->pos= yypos778; G->thunkpos= yythunkpos778;
  }  if (!yy_HtmlBlockCloseTr(G)) { goto l776; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockTr", G->buf+G->pos));
  return 1;
  l776:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockTr", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseTr(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseTr"));  if (!yymatchChar(G, '<')) goto l782;  if (!yy_Spnl(G)) { goto l782; }  if (!yymatchChar(G, '/')) goto l782;
  {  int yypos783= G->pos, yythunkpos783= G->thunkpos;  if (!yymatchString(G, "tr")) goto l784;  goto l783;
  l784:;	  G->pos= yypos783; G->thunkpos= yythunkpos783;  if (!yymatchString(G, "TR")) goto l782;
  }
  l783:;	  if (!yy_Spnl(G)) { goto l782; }  if (!yymatchChar(G, '>')) goto l782;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseTr", G->buf+G->pos));
  return 1;
  l782:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseTr", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenTr(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenTr"));  if (!yymatchChar(G, '<')) goto l785;  if (!yy_Spnl(G)) { goto l785; }
  {  int yypos786= G->pos, yythunkpos786= G->thunkpos;  if (!yymatchString(G, "tr")) goto l787;  goto l786;
  l787:;	  G->pos= yypos786; G->thunkpos= yythunkpos786;  if (!yymatchString(G, "TR")) goto l785;
  }
  l786:;	  if (!yy_Spnl(G)) { goto l785; }
  l788:;	
  {  int yypos789= G->pos, yythunkpos789= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l789; }  goto l788;
  l789:;	  G->pos= yypos789; G->thunkpos= yythunkpos789;
  }  if (!yymatchChar(G, '>')) goto l785;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenTr", G->buf+G->pos));
  return 1;
  l785:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenTr", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockThead(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockThead"));  if (!yy_HtmlBlockOpenThead(G)) { goto l790; }
  l791:;	
  {  int yypos792= G->pos, yythunkpos792= G->thunkpos;
  {  int yypos793= G->pos, yythunkpos793= G->thunkpos;  if (!yy_HtmlBlockThead(G)) { goto l794; }  goto l793;
  l794:;	  G->pos= yypos793; G->thunkpos= yythunkpos793;
  {  int yypos795= G->pos, yythunkpos795= G->thunkpos;  if (!yy_HtmlBlockCloseThead(G)) { goto l795; }  goto l792;
  l795:;	  G->pos= yypos795; G->thunkpos= yythunkpos795;
  }  if (!yymatchDot(G)) goto l792;
  }
  l793:;	  goto l791;
  l792:;	  G->pos= yypos792; G->thunkpos= yythunkpos792;
  }  if (!yy_HtmlBlockCloseThead(G)) { goto l790; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockThead", G->buf+G->pos));
  return 1;
  l790:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockThead", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseThead(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseThead"));  if (!yymatchChar(G, '<')) goto l796;  if (!yy_Spnl(G)) { goto l796; }  if (!yymatchChar(G, '/')) goto l796;
  {  int yypos797= G->pos, yythunkpos797= G->thunkpos;  if (!yymatchString(G, "thead")) goto l798;  goto l797;
  l798:;	  G->pos= yypos797; G->thunkpos= yythunkpos797;  if (!yymatchString(G, "THEAD")) goto l796;
  }
  l797:;	  if (!yy_Spnl(G)) { goto l796; }  if (!yymatchChar(G, '>')) goto l796;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseThead", G->buf+G->pos));
  return 1;
  l796:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseThead", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenThead(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenThead"));  if (!yymatchChar(G, '<')) goto l799;  if (!yy_Spnl(G)) { goto l799; }
  {  int yypos800= G->pos, yythunkpos800= G->thunkpos;  if (!yymatchString(G, "thead")) goto l801;  goto l800;
  l801:;	  G->pos= yypos800; G->thunkpos= yythunkpos800;  if (!yymatchString(G, "THEAD")) goto l799;
  }
  l800:;	  if (!yy_Spnl(G)) { goto l799; }
  l802:;	
  {  int yypos803= G->pos, yythunkpos803= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l803; }  goto l802;
  l803:;	  G->pos= yypos803; G->thunkpos= yythunkpos803;
  }  if (!yymatchChar(G, '>')) goto l799;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenThead", G->buf+G->pos));
  return 1;
  l799:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenThead", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockTh(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockTh"));  if (!yy_HtmlBlockOpenTh(G)) { goto l804; }
  l805:;	
  {  int yypos806= G->pos, yythunkpos806= G->thunkpos;
  {  int yypos807= G->pos, yythunkpos807= G->thunkpos;  if (!yy_HtmlBlockTh(G)) { goto l808; }  goto l807;
  l808:;	  G->pos= yypos807; G->thunkpos= yythunkpos807;
  {  int yypos809= G->pos, yythunkpos809= G->thunkpos;  if (!yy_HtmlBlockCloseTh(G)) { goto l809; }  goto l806;
  l809:;	  G->pos= yypos809; G->thunkpos= yythunkpos809;
  }  if (!yymatchDot(G)) goto l806;
  }
  l807:;	  goto l805;
  l806:;	  G->pos= yypos806; G->thunkpos= yythunkpos806;
  }  if (!yy_HtmlBlockCloseTh(G)) { goto l804; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockTh", G->buf+G->pos));
  return 1;
  l804:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockTh", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseTh(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseTh"));  if (!yymatchChar(G, '<')) goto l810;  if (!yy_Spnl(G)) { goto l810; }  if (!yymatchChar(G, '/')) goto l810;
  {  int yypos811= G->pos, yythunkpos811= G->thunkpos;  if (!yymatchString(G, "th")) goto l812;  goto l811;
  l812:;	  G->pos= yypos811; G->thunkpos= yythunkpos811;  if (!yymatchString(G, "TH")) goto l810;
  }
  l811:;	  if (!yy_Spnl(G)) { goto l810; }  if (!yymatchChar(G, '>')) goto l810;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseTh", G->buf+G->pos));
  return 1;
  l810:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseTh", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenTh(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenTh"));  if (!yymatchChar(G, '<')) goto l813;  if (!yy_Spnl(G)) { goto l813; }
  {  int yypos814= G->pos, yythunkpos814= G->thunkpos;  if (!yymatchString(G, "th")) goto l815;  goto l814;
  l815:;	  G->pos= yypos814; G->thunkpos= yythunkpos814;  if (!yymatchString(G, "TH")) goto l813;
  }
  l814:;	  if (!yy_Spnl(G)) { goto l813; }
  l816:;	
  {  int yypos817= G->pos, yythunkpos817= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l817; }  goto l816;
  l817:;	  G->pos= yypos817; G->thunkpos= yythunkpos817;
  }  if (!yymatchChar(G, '>')) goto l813;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenTh", G->buf+G->pos));
  return 1;
  l813:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenTh", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockTfoot(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockTfoot"));  if (!yy_HtmlBlockOpenTfoot(G)) { goto l818; }
  l819:;	
  {  int yypos820= G->pos, yythunkpos820= G->thunkpos;
  {  int yypos821= G->pos, yythunkpos821= G->thunkpos;  if (!yy_HtmlBlockTfoot(G)) { goto l822; }  goto l821;
  l822:;	  G->pos= yypos821; G->thunkpos= yythunkpos821;
  {  int yypos823= G->pos, yythunkpos823= G->thunkpos;  if (!yy_HtmlBlockCloseTfoot(G)) { goto l823; }  goto l820;
  l823:;	  G->pos= yypos823; G->thunkpos= yythunkpos823;
  }  if (!yymatchDot(G)) goto l820;
  }
  l821:;	  goto l819;
  l820:;	  G->pos= yypos820; G->thunkpos= yythunkpos820;
  }  if (!yy_HtmlBlockCloseTfoot(G)) { goto l818; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockTfoot", G->buf+G->pos));
  return 1;
  l818:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockTfoot", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseTfoot(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseTfoot"));  if (!yymatchChar(G, '<')) goto l824;  if (!yy_Spnl(G)) { goto l824; }  if (!yymatchChar(G, '/')) goto l824;
  {  int yypos825= G->pos, yythunkpos825= G->thunkpos;  if (!yymatchString(G, "tfoot")) goto l826;  goto l825;
  l826:;	  G->pos= yypos825; G->thunkpos= yythunkpos825;  if (!yymatchString(G, "TFOOT")) goto l824;
  }
  l825:;	  if (!yy_Spnl(G)) { goto l824; }  if (!yymatchChar(G, '>')) goto l824;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseTfoot", G->buf+G->pos));
  return 1;
  l824:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseTfoot", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenTfoot(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenTfoot"));  if (!yymatchChar(G, '<')) goto l827;  if (!yy_Spnl(G)) { goto l827; }
  {  int yypos828= G->pos, yythunkpos828= G->thunkpos;  if (!yymatchString(G, "tfoot")) goto l829;  goto l828;
  l829:;	  G->pos= yypos828; G->thunkpos= yythunkpos828;  if (!yymatchString(G, "TFOOT")) goto l827;
  }
  l828:;	  if (!yy_Spnl(G)) { goto l827; }
  l830:;	
  {  int yypos831= G->pos, yythunkpos831= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l831; }  goto l830;
  l831:;	  G->pos= yypos831; G->thunkpos= yythunkpos831;
  }  if (!yymatchChar(G, '>')) goto l827;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenTfoot", G->buf+G->pos));
  return 1;
  l827:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenTfoot", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockTd(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockTd"));  if (!yy_HtmlBlockOpenTd(G)) { goto l832; }
  l833:;	
  {  int yypos834= G->pos, yythunkpos834= G->thunkpos;
  {  int yypos835= G->pos, yythunkpos835= G->thunkpos;  if (!yy_HtmlBlockTd(G)) { goto l836; }  goto l835;
  l836:;	  G->pos= yypos835; G->thunkpos= yythunkpos835;
  {  int yypos837= G->pos, yythunkpos837= G->thunkpos;  if (!yy_HtmlBlockCloseTd(G)) { goto l837; }  goto l834;
  l837:;	  G->pos= yypos837; G->thunkpos= yythunkpos837;
  }  if (!yymatchDot(G)) goto l834;
  }
  l835:;	  goto l833;
  l834:;	  G->pos= yypos834; G->thunkpos= yythunkpos834;
  }  if (!yy_HtmlBlockCloseTd(G)) { goto l832; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockTd", G->buf+G->pos));
  return 1;
  l832:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockTd", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseTd(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseTd"));  if (!yymatchChar(G, '<')) goto l838;  if (!yy_Spnl(G)) { goto l838; }  if (!yymatchChar(G, '/')) goto l838;
  {  int yypos839= G->pos, yythunkpos839= G->thunkpos;  if (!yymatchString(G, "td")) goto l840;  goto l839;
  l840:;	  G->pos= yypos839; G->thunkpos= yythunkpos839;  if (!yymatchString(G, "TD")) goto l838;
  }
  l839:;	  if (!yy_Spnl(G)) { goto l838; }  if (!yymatchChar(G, '>')) goto l838;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseTd", G->buf+G->pos));
  return 1;
  l838:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseTd", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenTd(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenTd"));  if (!yymatchChar(G, '<')) goto l841;  if (!yy_Spnl(G)) { goto l841; }
  {  int yypos842= G->pos, yythunkpos842= G->thunkpos;  if (!yymatchString(G, "td")) goto l843;  goto l842;
  l843:;	  G->pos= yypos842; G->thunkpos= yythunkpos842;  if (!yymatchString(G, "TD")) goto l841;
  }
  l842:;	  if (!yy_Spnl(G)) { goto l841; }
  l844:;	
  {  int yypos845= G->pos, yythunkpos845= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l845; }  goto l844;
  l845:;	  G->pos= yypos845; G->thunkpos= yythunkpos845;
  }  if (!yymatchChar(G, '>')) goto l841;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenTd", G->buf+G->pos));
  return 1;
  l841:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenTd", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockTbody(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockTbody"));  if (!yy_HtmlBlockOpenTbody(G)) { goto l846; }
  l847:;	
  {  int yypos848= G->pos, yythunkpos848= G->thunkpos;
  {  int yypos849= G->pos, yythunkpos849= G->thunkpos;  if (!yy_HtmlBlockTbody(G)) { goto l850; }  goto l849;
  l850:;	  G->pos= yypos849; G->thunkpos= yythunkpos849;
  {  int yypos851= G->pos, yythunkpos851= G->thunkpos;  if (!yy_HtmlBlockCloseTbody(G)) { goto l851; }  goto l848;
  l851:;	  G->pos= yypos851; G->thunkpos= yythunkpos851;
  }  if (!yymatchDot(G)) goto l848;
  }
  l849:;	  goto l847;
  l848:;	  G->pos= yypos848; G->thunkpos= yythunkpos848;
  }  if (!yy_HtmlBlockCloseTbody(G)) { goto l846; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockTbody", G->buf+G->pos));
  return 1;
  l846:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockTbody", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseTbody(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseTbody"));  if (!yymatchChar(G, '<')) goto l852;  if (!yy_Spnl(G)) { goto l852; }  if (!yymatchChar(G, '/')) goto l852;
  {  int yypos853= G->pos, yythunkpos853= G->thunkpos;  if (!yymatchString(G, "tbody")) goto l854;  goto l853;
  l854:;	  G->pos= yypos853; G->thunkpos= yythunkpos853;  if (!yymatchString(G, "TBODY")) goto l852;
  }
  l853:;	  if (!yy_Spnl(G)) { goto l852; }  if (!yymatchChar(G, '>')) goto l852;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseTbody", G->buf+G->pos));
  return 1;
  l852:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseTbody", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenTbody(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenTbody"));  if (!yymatchChar(G, '<')) goto l855;  if (!yy_Spnl(G)) { goto l855; }
  {  int yypos856= G->pos, yythunkpos856= G->thunkpos;  if (!yymatchString(G, "tbody")) goto l857;  goto l856;
  l857:;	  G->pos= yypos856; G->thunkpos= yythunkpos856;  if (!yymatchString(G, "TBODY")) goto l855;
  }
  l856:;	  if (!yy_Spnl(G)) { goto l855; }
  l858:;	
  {  int yypos859= G->pos, yythunkpos859= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l859; }  goto l858;
  l859:;	  G->pos= yypos859; G->thunkpos= yythunkpos859;
  }  if (!yymatchChar(G, '>')) goto l855;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenTbody", G->buf+G->pos));
  return 1;
  l855:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenTbody", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockLi(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockLi"));  if (!yy_HtmlBlockOpenLi(G)) { goto l860; }
  l861:;	
  {  int yypos862= G->pos, yythunkpos862= G->thunkpos;
  {  int yypos863= G->pos, yythunkpos863= G->thunkpos;  if (!yy_HtmlBlockLi(G)) { goto l864; }  goto l863;
  l864:;	  G->pos= yypos863; G->thunkpos= yythunkpos863;
  {  int yypos865= G->pos, yythunkpos865= G->thunkpos;  if (!yy_HtmlBlockCloseLi(G)) { goto l865; }  goto l862;
  l865:;	  G->pos= yypos865; G->thunkpos= yythunkpos865;
  }  if (!yymatchDot(G)) goto l862;
  }
  l863:;	  goto l861;
  l862:;	  G->pos= yypos862; G->thunkpos= yythunkpos862;
  }  if (!yy_HtmlBlockCloseLi(G)) { goto l860; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockLi", G->buf+G->pos));
  return 1;
  l860:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockLi", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseLi(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseLi"));  if (!yymatchChar(G, '<')) goto l866;  if (!yy_Spnl(G)) { goto l866; }  if (!yymatchChar(G, '/')) goto l866;
  {  int yypos867= G->pos, yythunkpos867= G->thunkpos;  if (!yymatchString(G, "li")) goto l868;  goto l867;
  l868:;	  G->pos= yypos867; G->thunkpos= yythunkpos867;  if (!yymatchString(G, "LI")) goto l866;
  }
  l867:;	  if (!yy_Spnl(G)) { goto l866; }  if (!yymatchChar(G, '>')) goto l866;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseLi", G->buf+G->pos));
  return 1;
  l866:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseLi", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenLi(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenLi"));  if (!yymatchChar(G, '<')) goto l869;  if (!yy_Spnl(G)) { goto l869; }
  {  int yypos870= G->pos, yythunkpos870= G->thunkpos;  if (!yymatchString(G, "li")) goto l871;  goto l870;
  l871:;	  G->pos= yypos870; G->thunkpos= yythunkpos870;  if (!yymatchString(G, "LI")) goto l869;
  }
  l870:;	  if (!yy_Spnl(G)) { goto l869; }
  l872:;	
  {  int yypos873= G->pos, yythunkpos873= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l873; }  goto l872;
  l873:;	  G->pos= yypos873; G->thunkpos= yythunkpos873;
  }  if (!yymatchChar(G, '>')) goto l869;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenLi", G->buf+G->pos));
  return 1;
  l869:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenLi", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockFrameset(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockFrameset"));  if (!yy_HtmlBlockOpenFrameset(G)) { goto l874; }
  l875:;	
  {  int yypos876= G->pos, yythunkpos876= G->thunkpos;
  {  int yypos877= G->pos, yythunkpos877= G->thunkpos;  if (!yy_HtmlBlockFrameset(G)) { goto l878; }  goto l877;
  l878:;	  G->pos= yypos877; G->thunkpos= yythunkpos877;
  {  int yypos879= G->pos, yythunkpos879= G->thunkpos;  if (!yy_HtmlBlockCloseFrameset(G)) { goto l879; }  goto l876;
  l879:;	  G->pos= yypos879; G->thunkpos= yythunkpos879;
  }  if (!yymatchDot(G)) goto l876;
  }
  l877:;	  goto l875;
  l876:;	  G->pos= yypos876; G->thunkpos= yythunkpos876;
  }  if (!yy_HtmlBlockCloseFrameset(G)) { goto l874; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockFrameset", G->buf+G->pos));
  return 1;
  l874:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockFrameset", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseFrameset(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseFrameset"));  if (!yymatchChar(G, '<')) goto l880;  if (!yy_Spnl(G)) { goto l880; }  if (!yymatchChar(G, '/')) goto l880;
  {  int yypos881= G->pos, yythunkpos881= G->thunkpos;  if (!yymatchString(G, "frameset")) goto l882;  goto l881;
  l882:;	  G->pos= yypos881; G->thunkpos= yythunkpos881;  if (!yymatchString(G, "FRAMESET")) goto l880;
  }
  l881:;	  if (!yy_Spnl(G)) { goto l880; }  if (!yymatchChar(G, '>')) goto l880;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseFrameset", G->buf+G->pos));
  return 1;
  l880:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseFrameset", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenFrameset(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenFrameset"));  if (!yymatchChar(G, '<')) goto l883;  if (!yy_Spnl(G)) { goto l883; }
  {  int yypos884= G->pos, yythunkpos884= G->thunkpos;  if (!yymatchString(G, "frameset")) goto l885;  goto l884;
  l885:;	  G->pos= yypos884; G->thunkpos= yythunkpos884;  if (!yymatchString(G, "FRAMESET")) goto l883;
  }
  l884:;	  if (!yy_Spnl(G)) { goto l883; }
  l886:;	
  {  int yypos887= G->pos, yythunkpos887= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l887; }  goto l886;
  l887:;	  G->pos= yypos887; G->thunkpos= yythunkpos887;
  }  if (!yymatchChar(G, '>')) goto l883;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenFrameset", G->buf+G->pos));
  return 1;
  l883:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenFrameset", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockDt(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockDt"));  if (!yy_HtmlBlockOpenDt(G)) { goto l888; }
  l889:;	
  {  int yypos890= G->pos, yythunkpos890= G->thunkpos;
  {  int yypos891= G->pos, yythunkpos891= G->thunkpos;  if (!yy_HtmlBlockDt(G)) { goto l892; }  goto l891;
  l892:;	  G->pos= yypos891; G->thunkpos= yythunkpos891;
  {  int yypos893= G->pos, yythunkpos893= G->thunkpos;  if (!yy_HtmlBlockCloseDt(G)) { goto l893; }  goto l890;
  l893:;	  G->pos= yypos893; G->thunkpos= yythunkpos893;
  }  if (!yymatchDot(G)) goto l890;
  }
  l891:;	  goto l889;
  l890:;	  G->pos= yypos890; G->thunkpos= yythunkpos890;
  }  if (!yy_HtmlBlockCloseDt(G)) { goto l888; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockDt", G->buf+G->pos));
  return 1;
  l888:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockDt", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseDt(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseDt"));  if (!yymatchChar(G, '<')) goto l894;  if (!yy_Spnl(G)) { goto l894; }  if (!yymatchChar(G, '/')) goto l894;
  {  int yypos895= G->pos, yythunkpos895= G->thunkpos;  if (!yymatchString(G, "dt")) goto l896;  goto l895;
  l896:;	  G->pos= yypos895; G->thunkpos= yythunkpos895;  if (!yymatchString(G, "DT")) goto l894;
  }
  l895:;	  if (!yy_Spnl(G)) { goto l894; }  if (!yymatchChar(G, '>')) goto l894;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseDt", G->buf+G->pos));
  return 1;
  l894:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseDt", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenDt(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenDt"));  if (!yymatchChar(G, '<')) goto l897;  if (!yy_Spnl(G)) { goto l897; }
  {  int yypos898= G->pos, yythunkpos898= G->thunkpos;  if (!yymatchString(G, "dt")) goto l899;  goto l898;
  l899:;	  G->pos= yypos898; G->thunkpos= yythunkpos898;  if (!yymatchString(G, "DT")) goto l897;
  }
  l898:;	  if (!yy_Spnl(G)) { goto l897; }
  l900:;	
  {  int yypos901= G->pos, yythunkpos901= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l901; }  goto l900;
  l901:;	  G->pos= yypos901; G->thunkpos= yythunkpos901;
  }  if (!yymatchChar(G, '>')) goto l897;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenDt", G->buf+G->pos));
  return 1;
  l897:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenDt", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockDd(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockDd"));  if (!yy_HtmlBlockOpenDd(G)) { goto l902; }
  l903:;	
  {  int yypos904= G->pos, yythunkpos904= G->thunkpos;
  {  int yypos905= G->pos, yythunkpos905= G->thunkpos;  if (!yy_HtmlBlockDd(G)) { goto l906; }  goto l905;
  l906:;	  G->pos= yypos905; G->thunkpos= yythunkpos905;
  {  int yypos907= G->pos, yythunkpos907= G->thunkpos;  if (!yy_HtmlBlockCloseDd(G)) { goto l907; }  goto l904;
  l907:;	  G->pos= yypos907; G->thunkpos= yythunkpos907;
  }  if (!yymatchDot(G)) goto l904;
  }
  l905:;	  goto l903;
  l904:;	  G->pos= yypos904; G->thunkpos= yythunkpos904;
  }  if (!yy_HtmlBlockCloseDd(G)) { goto l902; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockDd", G->buf+G->pos));
  return 1;
  l902:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockDd", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseDd(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseDd"));  if (!yymatchChar(G, '<')) goto l908;  if (!yy_Spnl(G)) { goto l908; }  if (!yymatchChar(G, '/')) goto l908;
  {  int yypos909= G->pos, yythunkpos909= G->thunkpos;  if (!yymatchString(G, "dd")) goto l910;  goto l909;
  l910:;	  G->pos= yypos909; G->thunkpos= yythunkpos909;  if (!yymatchString(G, "DD")) goto l908;
  }
  l909:;	  if (!yy_Spnl(G)) { goto l908; }  if (!yymatchChar(G, '>')) goto l908;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseDd", G->buf+G->pos));
  return 1;
  l908:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseDd", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenDd(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenDd"));  if (!yymatchChar(G, '<')) goto l911;  if (!yy_Spnl(G)) { goto l911; }
  {  int yypos912= G->pos, yythunkpos912= G->thunkpos;  if (!yymatchString(G, "dd")) goto l913;  goto l912;
  l913:;	  G->pos= yypos912; G->thunkpos= yythunkpos912;  if (!yymatchString(G, "DD")) goto l911;
  }
  l912:;	  if (!yy_Spnl(G)) { goto l911; }
  l914:;	
  {  int yypos915= G->pos, yythunkpos915= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l915; }  goto l914;
  l915:;	  G->pos= yypos915; G->thunkpos= yythunkpos915;
  }  if (!yymatchChar(G, '>')) goto l911;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenDd", G->buf+G->pos));
  return 1;
  l911:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenDd", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockUl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockUl"));  if (!yy_HtmlBlockOpenUl(G)) { goto l916; }
  l917:;	
  {  int yypos918= G->pos, yythunkpos918= G->thunkpos;
  {  int yypos919= G->pos, yythunkpos919= G->thunkpos;  if (!yy_HtmlBlockUl(G)) { goto l920; }  goto l919;
  l920:;	  G->pos= yypos919; G->thunkpos= yythunkpos919;
  {  int yypos921= G->pos, yythunkpos921= G->thunkpos;  if (!yy_HtmlBlockCloseUl(G)) { goto l921; }  goto l918;
  l921:;	  G->pos= yypos921; G->thunkpos= yythunkpos921;
  }  if (!yymatchDot(G)) goto l918;
  }
  l919:;	  goto l917;
  l918:;	  G->pos= yypos918; G->thunkpos= yythunkpos918;
  }  if (!yy_HtmlBlockCloseUl(G)) { goto l916; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockUl", G->buf+G->pos));
  return 1;
  l916:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockUl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseUl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseUl"));  if (!yymatchChar(G, '<')) goto l922;  if (!yy_Spnl(G)) { goto l922; }  if (!yymatchChar(G, '/')) goto l922;
  {  int yypos923= G->pos, yythunkpos923= G->thunkpos;  if (!yymatchString(G, "ul")) goto l924;  goto l923;
  l924:;	  G->pos= yypos923; G->thunkpos= yythunkpos923;  if (!yymatchString(G, "UL")) goto l922;
  }
  l923:;	  if (!yy_Spnl(G)) { goto l922; }  if (!yymatchChar(G, '>')) goto l922;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseUl", G->buf+G->pos));
  return 1;
  l922:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseUl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenUl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenUl"));  if (!yymatchChar(G, '<')) goto l925;  if (!yy_Spnl(G)) { goto l925; }
  {  int yypos926= G->pos, yythunkpos926= G->thunkpos;  if (!yymatchString(G, "ul")) goto l927;  goto l926;
  l927:;	  G->pos= yypos926; G->thunkpos= yythunkpos926;  if (!yymatchString(G, "UL")) goto l925;
  }
  l926:;	  if (!yy_Spnl(G)) { goto l925; }
  l928:;	
  {  int yypos929= G->pos, yythunkpos929= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l929; }  goto l928;
  l929:;	  G->pos= yypos929; G->thunkpos= yythunkpos929;
  }  if (!yymatchChar(G, '>')) goto l925;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenUl", G->buf+G->pos));
  return 1;
  l925:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenUl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockTable(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockTable"));  if (!yy_HtmlBlockOpenTable(G)) { goto l930; }
  l931:;	
  {  int yypos932= G->pos, yythunkpos932= G->thunkpos;
  {  int yypos933= G->pos, yythunkpos933= G->thunkpos;  if (!yy_HtmlBlockTable(G)) { goto l934; }  goto l933;
  l934:;	  G->pos= yypos933; G->thunkpos= yythunkpos933;
  {  int yypos935= G->pos, yythunkpos935= G->thunkpos;  if (!yy_HtmlBlockCloseTable(G)) { goto l935; }  goto l932;
  l935:;	  G->pos= yypos935; G->thunkpos= yythunkpos935;
  }  if (!yymatchDot(G)) goto l932;
  }
  l933:;	  goto l931;
  l932:;	  G->pos= yypos932; G->thunkpos= yythunkpos932;
  }  if (!yy_HtmlBlockCloseTable(G)) { goto l930; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockTable", G->buf+G->pos));
  return 1;
  l930:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockTable", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseTable(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseTable"));  if (!yymatchChar(G, '<')) goto l936;  if (!yy_Spnl(G)) { goto l936; }  if (!yymatchChar(G, '/')) goto l936;
  {  int yypos937= G->pos, yythunkpos937= G->thunkpos;  if (!yymatchString(G, "table")) goto l938;  goto l937;
  l938:;	  G->pos= yypos937; G->thunkpos= yythunkpos937;  if (!yymatchString(G, "TABLE")) goto l936;
  }
  l937:;	  if (!yy_Spnl(G)) { goto l936; }  if (!yymatchChar(G, '>')) goto l936;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseTable", G->buf+G->pos));
  return 1;
  l936:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseTable", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenTable(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenTable"));  if (!yymatchChar(G, '<')) goto l939;  if (!yy_Spnl(G)) { goto l939; }
  {  int yypos940= G->pos, yythunkpos940= G->thunkpos;  if (!yymatchString(G, "table")) goto l941;  goto l940;
  l941:;	  G->pos= yypos940; G->thunkpos= yythunkpos940;  if (!yymatchString(G, "TABLE")) goto l939;
  }
  l940:;	  if (!yy_Spnl(G)) { goto l939; }
  l942:;	
  {  int yypos943= G->pos, yythunkpos943= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l943; }  goto l942;
  l943:;	  G->pos= yypos943; G->thunkpos= yythunkpos943;
  }  if (!yymatchChar(G, '>')) goto l939;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenTable", G->buf+G->pos));
  return 1;
  l939:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenTable", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockPre(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockPre"));  if (!yy_HtmlBlockOpenPre(G)) { goto l944; }
  l945:;	
  {  int yypos946= G->pos, yythunkpos946= G->thunkpos;
  {  int yypos947= G->pos, yythunkpos947= G->thunkpos;  if (!yy_HtmlBlockPre(G)) { goto l948; }  goto l947;
  l948:;	  G->pos= yypos947; G->thunkpos= yythunkpos947;
  {  int yypos949= G->pos, yythunkpos949= G->thunkpos;  if (!yy_HtmlBlockClosePre(G)) { goto l949; }  goto l946;
  l949:;	  G->pos= yypos949; G->thunkpos= yythunkpos949;
  }  if (!yymatchDot(G)) goto l946;
  }
  l947:;	  goto l945;
  l946:;	  G->pos= yypos946; G->thunkpos= yythunkpos946;
  }  if (!yy_HtmlBlockClosePre(G)) { goto l944; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockPre", G->buf+G->pos));
  return 1;
  l944:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockPre", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockClosePre(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockClosePre"));  if (!yymatchChar(G, '<')) goto l950;  if (!yy_Spnl(G)) { goto l950; }  if (!yymatchChar(G, '/')) goto l950;
  {  int yypos951= G->pos, yythunkpos951= G->thunkpos;  if (!yymatchString(G, "pre")) goto l952;  goto l951;
  l952:;	  G->pos= yypos951; G->thunkpos= yythunkpos951;  if (!yymatchString(G, "PRE")) goto l950;
  }
  l951:;	  if (!yy_Spnl(G)) { goto l950; }  if (!yymatchChar(G, '>')) goto l950;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockClosePre", G->buf+G->pos));
  return 1;
  l950:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockClosePre", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenPre(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenPre"));  if (!yymatchChar(G, '<')) goto l953;  if (!yy_Spnl(G)) { goto l953; }
  {  int yypos954= G->pos, yythunkpos954= G->thunkpos;  if (!yymatchString(G, "pre")) goto l955;  goto l954;
  l955:;	  G->pos= yypos954; G->thunkpos= yythunkpos954;  if (!yymatchString(G, "PRE")) goto l953;
  }
  l954:;	  if (!yy_Spnl(G)) { goto l953; }
  l956:;	
  {  int yypos957= G->pos, yythunkpos957= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l957; }  goto l956;
  l957:;	  G->pos= yypos957; G->thunkpos= yythunkpos957;
  }  if (!yymatchChar(G, '>')) goto l953;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenPre", G->buf+G->pos));
  return 1;
  l953:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenPre", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockP(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockP"));  if (!yy_HtmlBlockOpenP(G)) { goto l958; }
  l959:;	
  {  int yypos960= G->pos, yythunkpos960= G->thunkpos;
  {  int yypos961= G->pos, yythunkpos961= G->thunkpos;  if (!yy_HtmlBlockP(G)) { goto l962; }  goto l961;
  l962:;	  G->pos= yypos961; G->thunkpos= yythunkpos961;
  {  int yypos963= G->pos, yythunkpos963= G->thunkpos;  if (!yy_HtmlBlockCloseP(G)) { goto l963; }  goto l960;
  l963:;	  G->pos= yypos963; G->thunkpos= yythunkpos963;
  }  if (!yymatchDot(G)) goto l960;
  }
  l961:;	  goto l959;
  l960:;	  G->pos= yypos960; G->thunkpos= yythunkpos960;
  }  if (!yy_HtmlBlockCloseP(G)) { goto l958; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockP", G->buf+G->pos));
  return 1;
  l958:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockP", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseP(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseP"));  if (!yymatchChar(G, '<')) goto l964;  if (!yy_Spnl(G)) { goto l964; }  if (!yymatchChar(G, '/')) goto l964;
  {  int yypos965= G->pos, yythunkpos965= G->thunkpos;  if (!yymatchChar(G, 'p')) goto l966;  goto l965;
  l966:;	  G->pos= yypos965; G->thunkpos= yythunkpos965;  if (!yymatchChar(G, 'P')) goto l964;
  }
  l965:;	  if (!yy_Spnl(G)) { goto l964; }  if (!yymatchChar(G, '>')) goto l964;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseP", G->buf+G->pos));
  return 1;
  l964:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseP", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenP(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenP"));  if (!yymatchChar(G, '<')) goto l967;  if (!yy_Spnl(G)) { goto l967; }
  {  int yypos968= G->pos, yythunkpos968= G->thunkpos;  if (!yymatchChar(G, 'p')) goto l969;  goto l968;
  l969:;	  G->pos= yypos968; G->thunkpos= yythunkpos968;  if (!yymatchChar(G, 'P')) goto l967;
  }
  l968:;	  if (!yy_Spnl(G)) { goto l967; }
  l970:;	
  {  int yypos971= G->pos, yythunkpos971= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l971; }  goto l970;
  l971:;	  G->pos= yypos971; G->thunkpos= yythunkpos971;
  }  if (!yymatchChar(G, '>')) goto l967;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenP", G->buf+G->pos));
  return 1;
  l967:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenP", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOl"));  if (!yy_HtmlBlockOpenOl(G)) { goto l972; }
  l973:;	
  {  int yypos974= G->pos, yythunkpos974= G->thunkpos;
  {  int yypos975= G->pos, yythunkpos975= G->thunkpos;  if (!yy_HtmlBlockOl(G)) { goto l976; }  goto l975;
  l976:;	  G->pos= yypos975; G->thunkpos= yythunkpos975;
  {  int yypos977= G->pos, yythunkpos977= G->thunkpos;  if (!yy_HtmlBlockCloseOl(G)) { goto l977; }  goto l974;
  l977:;	  G->pos= yypos977; G->thunkpos= yythunkpos977;
  }  if (!yymatchDot(G)) goto l974;
  }
  l975:;	  goto l973;
  l974:;	  G->pos= yypos974; G->thunkpos= yythunkpos974;
  }  if (!yy_HtmlBlockCloseOl(G)) { goto l972; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOl", G->buf+G->pos));
  return 1;
  l972:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseOl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseOl"));  if (!yymatchChar(G, '<')) goto l978;  if (!yy_Spnl(G)) { goto l978; }  if (!yymatchChar(G, '/')) goto l978;
  {  int yypos979= G->pos, yythunkpos979= G->thunkpos;  if (!yymatchString(G, "ol")) goto l980;  goto l979;
  l980:;	  G->pos= yypos979; G->thunkpos= yythunkpos979;  if (!yymatchString(G, "OL")) goto l978;
  }
  l979:;	  if (!yy_Spnl(G)) { goto l978; }  if (!yymatchChar(G, '>')) goto l978;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseOl", G->buf+G->pos));
  return 1;
  l978:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseOl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenOl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenOl"));  if (!yymatchChar(G, '<')) goto l981;  if (!yy_Spnl(G)) { goto l981; }
  {  int yypos982= G->pos, yythunkpos982= G->thunkpos;  if (!yymatchString(G, "ol")) goto l983;  goto l982;
  l983:;	  G->pos= yypos982; G->thunkpos= yythunkpos982;  if (!yymatchString(G, "OL")) goto l981;
  }
  l982:;	  if (!yy_Spnl(G)) { goto l981; }
  l984:;	
  {  int yypos985= G->pos, yythunkpos985= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l985; }  goto l984;
  l985:;	  G->pos= yypos985; G->thunkpos= yythunkpos985;
  }  if (!yymatchChar(G, '>')) goto l981;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenOl", G->buf+G->pos));
  return 1;
  l981:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenOl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockNoscript(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockNoscript"));  if (!yy_HtmlBlockOpenNoscript(G)) { goto l986; }
  l987:;	
  {  int yypos988= G->pos, yythunkpos988= G->thunkpos;
  {  int yypos989= G->pos, yythunkpos989= G->thunkpos;  if (!yy_HtmlBlockNoscript(G)) { goto l990; }  goto l989;
  l990:;	  G->pos= yypos989; G->thunkpos= yythunkpos989;
  {  int yypos991= G->pos, yythunkpos991= G->thunkpos;  if (!yy_HtmlBlockCloseNoscript(G)) { goto l991; }  goto l988;
  l991:;	  G->pos= yypos991; G->thunkpos= yythunkpos991;
  }  if (!yymatchDot(G)) goto l988;
  }
  l989:;	  goto l987;
  l988:;	  G->pos= yypos988; G->thunkpos= yythunkpos988;
  }  if (!yy_HtmlBlockCloseNoscript(G)) { goto l986; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockNoscript", G->buf+G->pos));
  return 1;
  l986:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockNoscript", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseNoscript(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseNoscript"));  if (!yymatchChar(G, '<')) goto l992;  if (!yy_Spnl(G)) { goto l992; }  if (!yymatchChar(G, '/')) goto l992;
  {  int yypos993= G->pos, yythunkpos993= G->thunkpos;  if (!yymatchString(G, "noscript")) goto l994;  goto l993;
  l994:;	  G->pos= yypos993; G->thunkpos= yythunkpos993;  if (!yymatchString(G, "NOSCRIPT")) goto l992;
  }
  l993:;	  if (!yy_Spnl(G)) { goto l992; }  if (!yymatchChar(G, '>')) goto l992;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseNoscript", G->buf+G->pos));
  return 1;
  l992:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseNoscript", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenNoscript(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenNoscript"));  if (!yymatchChar(G, '<')) goto l995;  if (!yy_Spnl(G)) { goto l995; }
  {  int yypos996= G->pos, yythunkpos996= G->thunkpos;  if (!yymatchString(G, "noscript")) goto l997;  goto l996;
  l997:;	  G->pos= yypos996; G->thunkpos= yythunkpos996;  if (!yymatchString(G, "NOSCRIPT")) goto l995;
  }
  l996:;	  if (!yy_Spnl(G)) { goto l995; }
  l998:;	
  {  int yypos999= G->pos, yythunkpos999= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l999; }  goto l998;
  l999:;	  G->pos= yypos999; G->thunkpos= yythunkpos999;
  }  if (!yymatchChar(G, '>')) goto l995;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenNoscript", G->buf+G->pos));
  return 1;
  l995:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenNoscript", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockNoframes(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockNoframes"));  if (!yy_HtmlBlockOpenNoframes(G)) { goto l1000; }
  l1001:;	
  {  int yypos1002= G->pos, yythunkpos1002= G->thunkpos;
  {  int yypos1003= G->pos, yythunkpos1003= G->thunkpos;  if (!yy_HtmlBlockNoframes(G)) { goto l1004; }  goto l1003;
  l1004:;	  G->pos= yypos1003; G->thunkpos= yythunkpos1003;
  {  int yypos1005= G->pos, yythunkpos1005= G->thunkpos;  if (!yy_HtmlBlockCloseNoframes(G)) { goto l1005; }  goto l1002;
  l1005:;	  G->pos= yypos1005; G->thunkpos= yythunkpos1005;
  }  if (!yymatchDot(G)) goto l1002;
  }
  l1003:;	  goto l1001;
  l1002:;	  G->pos= yypos1002; G->thunkpos= yythunkpos1002;
  }  if (!yy_HtmlBlockCloseNoframes(G)) { goto l1000; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockNoframes", G->buf+G->pos));
  return 1;
  l1000:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockNoframes", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseNoframes(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseNoframes"));  if (!yymatchChar(G, '<')) goto l1006;  if (!yy_Spnl(G)) { goto l1006; }  if (!yymatchChar(G, '/')) goto l1006;
  {  int yypos1007= G->pos, yythunkpos1007= G->thunkpos;  if (!yymatchString(G, "noframes")) goto l1008;  goto l1007;
  l1008:;	  G->pos= yypos1007; G->thunkpos= yythunkpos1007;  if (!yymatchString(G, "NOFRAMES")) goto l1006;
  }
  l1007:;	  if (!yy_Spnl(G)) { goto l1006; }  if (!yymatchChar(G, '>')) goto l1006;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseNoframes", G->buf+G->pos));
  return 1;
  l1006:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseNoframes", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenNoframes(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenNoframes"));  if (!yymatchChar(G, '<')) goto l1009;  if (!yy_Spnl(G)) { goto l1009; }
  {  int yypos1010= G->pos, yythunkpos1010= G->thunkpos;  if (!yymatchString(G, "noframes")) goto l1011;  goto l1010;
  l1011:;	  G->pos= yypos1010; G->thunkpos= yythunkpos1010;  if (!yymatchString(G, "NOFRAMES")) goto l1009;
  }
  l1010:;	  if (!yy_Spnl(G)) { goto l1009; }
  l1012:;	
  {  int yypos1013= G->pos, yythunkpos1013= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1013; }  goto l1012;
  l1013:;	  G->pos= yypos1013; G->thunkpos= yythunkpos1013;
  }  if (!yymatchChar(G, '>')) goto l1009;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenNoframes", G->buf+G->pos));
  return 1;
  l1009:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenNoframes", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockMenu(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockMenu"));  if (!yy_HtmlBlockOpenMenu(G)) { goto l1014; }
  l1015:;	
  {  int yypos1016= G->pos, yythunkpos1016= G->thunkpos;
  {  int yypos1017= G->pos, yythunkpos1017= G->thunkpos;  if (!yy_HtmlBlockMenu(G)) { goto l1018; }  goto l1017;
  l1018:;	  G->pos= yypos1017; G->thunkpos= yythunkpos1017;
  {  int yypos1019= G->pos, yythunkpos1019= G->thunkpos;  if (!yy_HtmlBlockCloseMenu(G)) { goto l1019; }  goto l1016;
  l1019:;	  G->pos= yypos1019; G->thunkpos= yythunkpos1019;
  }  if (!yymatchDot(G)) goto l1016;
  }
  l1017:;	  goto l1015;
  l1016:;	  G->pos= yypos1016; G->thunkpos= yythunkpos1016;
  }  if (!yy_HtmlBlockCloseMenu(G)) { goto l1014; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockMenu", G->buf+G->pos));
  return 1;
  l1014:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockMenu", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseMenu(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseMenu"));  if (!yymatchChar(G, '<')) goto l1020;  if (!yy_Spnl(G)) { goto l1020; }  if (!yymatchChar(G, '/')) goto l1020;
  {  int yypos1021= G->pos, yythunkpos1021= G->thunkpos;  if (!yymatchString(G, "menu")) goto l1022;  goto l1021;
  l1022:;	  G->pos= yypos1021; G->thunkpos= yythunkpos1021;  if (!yymatchString(G, "MENU")) goto l1020;
  }
  l1021:;	  if (!yy_Spnl(G)) { goto l1020; }  if (!yymatchChar(G, '>')) goto l1020;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseMenu", G->buf+G->pos));
  return 1;
  l1020:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseMenu", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenMenu(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenMenu"));  if (!yymatchChar(G, '<')) goto l1023;  if (!yy_Spnl(G)) { goto l1023; }
  {  int yypos1024= G->pos, yythunkpos1024= G->thunkpos;  if (!yymatchString(G, "menu")) goto l1025;  goto l1024;
  l1025:;	  G->pos= yypos1024; G->thunkpos= yythunkpos1024;  if (!yymatchString(G, "MENU")) goto l1023;
  }
  l1024:;	  if (!yy_Spnl(G)) { goto l1023; }
  l1026:;	
  {  int yypos1027= G->pos, yythunkpos1027= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1027; }  goto l1026;
  l1027:;	  G->pos= yypos1027; G->thunkpos= yythunkpos1027;
  }  if (!yymatchChar(G, '>')) goto l1023;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenMenu", G->buf+G->pos));
  return 1;
  l1023:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenMenu", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockH6(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "HtmlBlockH6"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1028;  if (!yy_LocMarker(G)) { goto l1028; }  yyDo(G, yySet, -1, 0);  if (!yy_HtmlBlockOpenH6(G)) { goto l1028; }
  l1029:;	
  {  int yypos1030= G->pos, yythunkpos1030= G->thunkpos;
  {  int yypos1031= G->pos, yythunkpos1031= G->thunkpos;  if (!yy_HtmlBlockH6(G)) { goto l1032; }  goto l1031;
  l1032:;	  G->pos= yypos1031; G->thunkpos= yythunkpos1031;
  {  int yypos1033= G->pos, yythunkpos1033= G->thunkpos;  if (!yy_HtmlBlockCloseH6(G)) { goto l1033; }  goto l1030;
  l1033:;	  G->pos= yypos1033; G->thunkpos= yythunkpos1033;
  }  if (!yymatchDot(G)) goto l1030;
  }
  l1031:;	  goto l1029;
  l1030:;	  G->pos= yypos1030; G->thunkpos= yythunkpos1030;
  }  if (!yy_HtmlBlockCloseH6(G)) { goto l1028; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1028;  yyDo(G, yy_1_HtmlBlockH6, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockH6", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1028:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockH6", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseH6(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseH6"));  if (!yymatchChar(G, '<')) goto l1034;  if (!yy_Spnl(G)) { goto l1034; }  if (!yymatchChar(G, '/')) goto l1034;
  {  int yypos1035= G->pos, yythunkpos1035= G->thunkpos;  if (!yymatchString(G, "h6")) goto l1036;  goto l1035;
  l1036:;	  G->pos= yypos1035; G->thunkpos= yythunkpos1035;  if (!yymatchString(G, "H6")) goto l1034;
  }
  l1035:;	  if (!yy_Spnl(G)) { goto l1034; }  if (!yymatchChar(G, '>')) goto l1034;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseH6", G->buf+G->pos));
  return 1;
  l1034:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseH6", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenH6(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenH6"));  if (!yymatchChar(G, '<')) goto l1037;  if (!yy_Spnl(G)) { goto l1037; }
  {  int yypos1038= G->pos, yythunkpos1038= G->thunkpos;  if (!yymatchString(G, "h6")) goto l1039;  goto l1038;
  l1039:;	  G->pos= yypos1038; G->thunkpos= yythunkpos1038;  if (!yymatchString(G, "H6")) goto l1037;
  }
  l1038:;	  if (!yy_Spnl(G)) { goto l1037; }
  l1040:;	
  {  int yypos1041= G->pos, yythunkpos1041= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1041; }  goto l1040;
  l1041:;	  G->pos= yypos1041; G->thunkpos= yythunkpos1041;
  }  if (!yymatchChar(G, '>')) goto l1037;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenH6", G->buf+G->pos));
  return 1;
  l1037:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenH6", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockH5(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "HtmlBlockH5"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1042;  if (!yy_LocMarker(G)) { goto l1042; }  yyDo(G, yySet, -1, 0);  if (!yy_HtmlBlockOpenH5(G)) { goto l1042; }
  l1043:;	
  {  int yypos1044= G->pos, yythunkpos1044= G->thunkpos;
  {  int yypos1045= G->pos, yythunkpos1045= G->thunkpos;  if (!yy_HtmlBlockH5(G)) { goto l1046; }  goto l1045;
  l1046:;	  G->pos= yypos1045; G->thunkpos= yythunkpos1045;
  {  int yypos1047= G->pos, yythunkpos1047= G->thunkpos;  if (!yy_HtmlBlockCloseH5(G)) { goto l1047; }  goto l1044;
  l1047:;	  G->pos= yypos1047; G->thunkpos= yythunkpos1047;
  }  if (!yymatchDot(G)) goto l1044;
  }
  l1045:;	  goto l1043;
  l1044:;	  G->pos= yypos1044; G->thunkpos= yythunkpos1044;
  }  if (!yy_HtmlBlockCloseH5(G)) { goto l1042; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1042;  yyDo(G, yy_1_HtmlBlockH5, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockH5", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1042:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockH5", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseH5(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseH5"));  if (!yymatchChar(G, '<')) goto l1048;  if (!yy_Spnl(G)) { goto l1048; }  if (!yymatchChar(G, '/')) goto l1048;
  {  int yypos1049= G->pos, yythunkpos1049= G->thunkpos;  if (!yymatchString(G, "h5")) goto l1050;  goto l1049;
  l1050:;	  G->pos= yypos1049; G->thunkpos= yythunkpos1049;  if (!yymatchString(G, "H5")) goto l1048;
  }
  l1049:;	  if (!yy_Spnl(G)) { goto l1048; }  if (!yymatchChar(G, '>')) goto l1048;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseH5", G->buf+G->pos));
  return 1;
  l1048:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseH5", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenH5(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenH5"));  if (!yymatchChar(G, '<')) goto l1051;  if (!yy_Spnl(G)) { goto l1051; }
  {  int yypos1052= G->pos, yythunkpos1052= G->thunkpos;  if (!yymatchString(G, "h5")) goto l1053;  goto l1052;
  l1053:;	  G->pos= yypos1052; G->thunkpos= yythunkpos1052;  if (!yymatchString(G, "H5")) goto l1051;
  }
  l1052:;	  if (!yy_Spnl(G)) { goto l1051; }
  l1054:;	
  {  int yypos1055= G->pos, yythunkpos1055= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1055; }  goto l1054;
  l1055:;	  G->pos= yypos1055; G->thunkpos= yythunkpos1055;
  }  if (!yymatchChar(G, '>')) goto l1051;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenH5", G->buf+G->pos));
  return 1;
  l1051:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenH5", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockH4(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "HtmlBlockH4"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1056;  if (!yy_LocMarker(G)) { goto l1056; }  yyDo(G, yySet, -1, 0);  if (!yy_HtmlBlockOpenH4(G)) { goto l1056; }
  l1057:;	
  {  int yypos1058= G->pos, yythunkpos1058= G->thunkpos;
  {  int yypos1059= G->pos, yythunkpos1059= G->thunkpos;  if (!yy_HtmlBlockH4(G)) { goto l1060; }  goto l1059;
  l1060:;	  G->pos= yypos1059; G->thunkpos= yythunkpos1059;
  {  int yypos1061= G->pos, yythunkpos1061= G->thunkpos;  if (!yy_HtmlBlockCloseH4(G)) { goto l1061; }  goto l1058;
  l1061:;	  G->pos= yypos1061; G->thunkpos= yythunkpos1061;
  }  if (!yymatchDot(G)) goto l1058;
  }
  l1059:;	  goto l1057;
  l1058:;	  G->pos= yypos1058; G->thunkpos= yythunkpos1058;
  }  if (!yy_HtmlBlockCloseH4(G)) { goto l1056; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1056;  yyDo(G, yy_1_HtmlBlockH4, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockH4", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1056:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockH4", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseH4(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseH4"));  if (!yymatchChar(G, '<')) goto l1062;  if (!yy_Spnl(G)) { goto l1062; }  if (!yymatchChar(G, '/')) goto l1062;
  {  int yypos1063= G->pos, yythunkpos1063= G->thunkpos;  if (!yymatchString(G, "h4")) goto l1064;  goto l1063;
  l1064:;	  G->pos= yypos1063; G->thunkpos= yythunkpos1063;  if (!yymatchString(G, "H4")) goto l1062;
  }
  l1063:;	  if (!yy_Spnl(G)) { goto l1062; }  if (!yymatchChar(G, '>')) goto l1062;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseH4", G->buf+G->pos));
  return 1;
  l1062:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseH4", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenH4(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenH4"));  if (!yymatchChar(G, '<')) goto l1065;  if (!yy_Spnl(G)) { goto l1065; }
  {  int yypos1066= G->pos, yythunkpos1066= G->thunkpos;  if (!yymatchString(G, "h4")) goto l1067;  goto l1066;
  l1067:;	  G->pos= yypos1066; G->thunkpos= yythunkpos1066;  if (!yymatchString(G, "H4")) goto l1065;
  }
  l1066:;	  if (!yy_Spnl(G)) { goto l1065; }
  l1068:;	
  {  int yypos1069= G->pos, yythunkpos1069= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1069; }  goto l1068;
  l1069:;	  G->pos= yypos1069; G->thunkpos= yythunkpos1069;
  }  if (!yymatchChar(G, '>')) goto l1065;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenH4", G->buf+G->pos));
  return 1;
  l1065:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenH4", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockH3(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "HtmlBlockH3"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1070;  if (!yy_LocMarker(G)) { goto l1070; }  yyDo(G, yySet, -1, 0);  if (!yy_HtmlBlockOpenH3(G)) { goto l1070; }
  l1071:;	
  {  int yypos1072= G->pos, yythunkpos1072= G->thunkpos;
  {  int yypos1073= G->pos, yythunkpos1073= G->thunkpos;  if (!yy_HtmlBlockH3(G)) { goto l1074; }  goto l1073;
  l1074:;	  G->pos= yypos1073; G->thunkpos= yythunkpos1073;
  {  int yypos1075= G->pos, yythunkpos1075= G->thunkpos;  if (!yy_HtmlBlockCloseH3(G)) { goto l1075; }  goto l1072;
  l1075:;	  G->pos= yypos1075; G->thunkpos= yythunkpos1075;
  }  if (!yymatchDot(G)) goto l1072;
  }
  l1073:;	  goto l1071;
  l1072:;	  G->pos= yypos1072; G->thunkpos= yythunkpos1072;
  }  if (!yy_HtmlBlockCloseH3(G)) { goto l1070; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1070;  yyDo(G, yy_1_HtmlBlockH3, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockH3", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1070:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockH3", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseH3(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseH3"));  if (!yymatchChar(G, '<')) goto l1076;  if (!yy_Spnl(G)) { goto l1076; }  if (!yymatchChar(G, '/')) goto l1076;
  {  int yypos1077= G->pos, yythunkpos1077= G->thunkpos;  if (!yymatchString(G, "h3")) goto l1078;  goto l1077;
  l1078:;	  G->pos= yypos1077; G->thunkpos= yythunkpos1077;  if (!yymatchString(G, "H3")) goto l1076;
  }
  l1077:;	  if (!yy_Spnl(G)) { goto l1076; }  if (!yymatchChar(G, '>')) goto l1076;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseH3", G->buf+G->pos));
  return 1;
  l1076:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseH3", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenH3(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenH3"));  if (!yymatchChar(G, '<')) goto l1079;  if (!yy_Spnl(G)) { goto l1079; }
  {  int yypos1080= G->pos, yythunkpos1080= G->thunkpos;  if (!yymatchString(G, "h3")) goto l1081;  goto l1080;
  l1081:;	  G->pos= yypos1080; G->thunkpos= yythunkpos1080;  if (!yymatchString(G, "H3")) goto l1079;
  }
  l1080:;	  if (!yy_Spnl(G)) { goto l1079; }
  l1082:;	
  {  int yypos1083= G->pos, yythunkpos1083= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1083; }  goto l1082;
  l1083:;	  G->pos= yypos1083; G->thunkpos= yythunkpos1083;
  }  if (!yymatchChar(G, '>')) goto l1079;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenH3", G->buf+G->pos));
  return 1;
  l1079:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenH3", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockH2(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "HtmlBlockH2"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1084;  if (!yy_LocMarker(G)) { goto l1084; }  yyDo(G, yySet, -1, 0);  if (!yy_HtmlBlockOpenH2(G)) { goto l1084; }
  l1085:;	
  {  int yypos1086= G->pos, yythunkpos1086= G->thunkpos;
  {  int yypos1087= G->pos, yythunkpos1087= G->thunkpos;  if (!yy_HtmlBlockH2(G)) { goto l1088; }  goto l1087;
  l1088:;	  G->pos= yypos1087; G->thunkpos= yythunkpos1087;
  {  int yypos1089= G->pos, yythunkpos1089= G->thunkpos;  if (!yy_HtmlBlockCloseH2(G)) { goto l1089; }  goto l1086;
  l1089:;	  G->pos= yypos1089; G->thunkpos= yythunkpos1089;
  }  if (!yymatchDot(G)) goto l1086;
  }
  l1087:;	  goto l1085;
  l1086:;	  G->pos= yypos1086; G->thunkpos= yythunkpos1086;
  }  if (!yy_HtmlBlockCloseH2(G)) { goto l1084; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1084;  yyDo(G, yy_1_HtmlBlockH2, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockH2", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1084:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockH2", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseH2(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseH2"));  if (!yymatchChar(G, '<')) goto l1090;  if (!yy_Spnl(G)) { goto l1090; }  if (!yymatchChar(G, '/')) goto l1090;
  {  int yypos1091= G->pos, yythunkpos1091= G->thunkpos;  if (!yymatchString(G, "h2")) goto l1092;  goto l1091;
  l1092:;	  G->pos= yypos1091; G->thunkpos= yythunkpos1091;  if (!yymatchString(G, "H2")) goto l1090;
  }
  l1091:;	  if (!yy_Spnl(G)) { goto l1090; }  if (!yymatchChar(G, '>')) goto l1090;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseH2", G->buf+G->pos));
  return 1;
  l1090:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseH2", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenH2(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenH2"));  if (!yymatchChar(G, '<')) goto l1093;  if (!yy_Spnl(G)) { goto l1093; }
  {  int yypos1094= G->pos, yythunkpos1094= G->thunkpos;  if (!yymatchString(G, "h2")) goto l1095;  goto l1094;
  l1095:;	  G->pos= yypos1094; G->thunkpos= yythunkpos1094;  if (!yymatchString(G, "H2")) goto l1093;
  }
  l1094:;	  if (!yy_Spnl(G)) { goto l1093; }
  l1096:;	
  {  int yypos1097= G->pos, yythunkpos1097= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1097; }  goto l1096;
  l1097:;	  G->pos= yypos1097; G->thunkpos= yythunkpos1097;
  }  if (!yymatchChar(G, '>')) goto l1093;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenH2", G->buf+G->pos));
  return 1;
  l1093:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenH2", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockH1(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "HtmlBlockH1"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1098;  if (!yy_LocMarker(G)) { goto l1098; }  yyDo(G, yySet, -1, 0);  if (!yy_HtmlBlockOpenH1(G)) { goto l1098; }
  l1099:;	
  {  int yypos1100= G->pos, yythunkpos1100= G->thunkpos;
  {  int yypos1101= G->pos, yythunkpos1101= G->thunkpos;  if (!yy_HtmlBlockH1(G)) { goto l1102; }  goto l1101;
  l1102:;	  G->pos= yypos1101; G->thunkpos= yythunkpos1101;
  {  int yypos1103= G->pos, yythunkpos1103= G->thunkpos;  if (!yy_HtmlBlockCloseH1(G)) { goto l1103; }  goto l1100;
  l1103:;	  G->pos= yypos1103; G->thunkpos= yythunkpos1103;
  }  if (!yymatchDot(G)) goto l1100;
  }
  l1101:;	  goto l1099;
  l1100:;	  G->pos= yypos1100; G->thunkpos= yythunkpos1100;
  }  if (!yy_HtmlBlockCloseH1(G)) { goto l1098; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1098;  yyDo(G, yy_1_HtmlBlockH1, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockH1", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1098:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockH1", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseH1(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseH1"));  if (!yymatchChar(G, '<')) goto l1104;  if (!yy_Spnl(G)) { goto l1104; }  if (!yymatchChar(G, '/')) goto l1104;
  {  int yypos1105= G->pos, yythunkpos1105= G->thunkpos;  if (!yymatchString(G, "h1")) goto l1106;  goto l1105;
  l1106:;	  G->pos= yypos1105; G->thunkpos= yythunkpos1105;  if (!yymatchString(G, "H1")) goto l1104;
  }
  l1105:;	  if (!yy_Spnl(G)) { goto l1104; }  if (!yymatchChar(G, '>')) goto l1104;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseH1", G->buf+G->pos));
  return 1;
  l1104:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseH1", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenH1(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenH1"));  if (!yymatchChar(G, '<')) goto l1107;  if (!yy_Spnl(G)) { goto l1107; }
  {  int yypos1108= G->pos, yythunkpos1108= G->thunkpos;  if (!yymatchString(G, "h1")) goto l1109;  goto l1108;
  l1109:;	  G->pos= yypos1108; G->thunkpos= yythunkpos1108;  if (!yymatchString(G, "H1")) goto l1107;
  }
  l1108:;	  if (!yy_Spnl(G)) { goto l1107; }
  l1110:;	
  {  int yypos1111= G->pos, yythunkpos1111= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1111; }  goto l1110;
  l1111:;	  G->pos= yypos1111; G->thunkpos= yythunkpos1111;
  }  if (!yymatchChar(G, '>')) goto l1107;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenH1", G->buf+G->pos));
  return 1;
  l1107:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenH1", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockForm(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockForm"));  if (!yy_HtmlBlockOpenForm(G)) { goto l1112; }
  l1113:;	
  {  int yypos1114= G->pos, yythunkpos1114= G->thunkpos;
  {  int yypos1115= G->pos, yythunkpos1115= G->thunkpos;  if (!yy_HtmlBlockForm(G)) { goto l1116; }  goto l1115;
  l1116:;	  G->pos= yypos1115; G->thunkpos= yythunkpos1115;
  {  int yypos1117= G->pos, yythunkpos1117= G->thunkpos;  if (!yy_HtmlBlockCloseForm(G)) { goto l1117; }  goto l1114;
  l1117:;	  G->pos= yypos1117; G->thunkpos= yythunkpos1117;
  }  if (!yymatchDot(G)) goto l1114;
  }
  l1115:;	  goto l1113;
  l1114:;	  G->pos= yypos1114; G->thunkpos= yythunkpos1114;
  }  if (!yy_HtmlBlockCloseForm(G)) { goto l1112; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockForm", G->buf+G->pos));
  return 1;
  l1112:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockForm", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseForm(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseForm"));  if (!yymatchChar(G, '<')) goto l1118;  if (!yy_Spnl(G)) { goto l1118; }  if (!yymatchChar(G, '/')) goto l1118;
  {  int yypos1119= G->pos, yythunkpos1119= G->thunkpos;  if (!yymatchString(G, "form")) goto l1120;  goto l1119;
  l1120:;	  G->pos= yypos1119; G->thunkpos= yythunkpos1119;  if (!yymatchString(G, "FORM")) goto l1118;
  }
  l1119:;	  if (!yy_Spnl(G)) { goto l1118; }  if (!yymatchChar(G, '>')) goto l1118;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseForm", G->buf+G->pos));
  return 1;
  l1118:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseForm", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenForm(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenForm"));  if (!yymatchChar(G, '<')) goto l1121;  if (!yy_Spnl(G)) { goto l1121; }
  {  int yypos1122= G->pos, yythunkpos1122= G->thunkpos;  if (!yymatchString(G, "form")) goto l1123;  goto l1122;
  l1123:;	  G->pos= yypos1122; G->thunkpos= yythunkpos1122;  if (!yymatchString(G, "FORM")) goto l1121;
  }
  l1122:;	  if (!yy_Spnl(G)) { goto l1121; }
  l1124:;	
  {  int yypos1125= G->pos, yythunkpos1125= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1125; }  goto l1124;
  l1125:;	  G->pos= yypos1125; G->thunkpos= yythunkpos1125;
  }  if (!yymatchChar(G, '>')) goto l1121;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenForm", G->buf+G->pos));
  return 1;
  l1121:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenForm", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockFieldset(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockFieldset"));  if (!yy_HtmlBlockOpenFieldset(G)) { goto l1126; }
  l1127:;	
  {  int yypos1128= G->pos, yythunkpos1128= G->thunkpos;
  {  int yypos1129= G->pos, yythunkpos1129= G->thunkpos;  if (!yy_HtmlBlockFieldset(G)) { goto l1130; }  goto l1129;
  l1130:;	  G->pos= yypos1129; G->thunkpos= yythunkpos1129;
  {  int yypos1131= G->pos, yythunkpos1131= G->thunkpos;  if (!yy_HtmlBlockCloseFieldset(G)) { goto l1131; }  goto l1128;
  l1131:;	  G->pos= yypos1131; G->thunkpos= yythunkpos1131;
  }  if (!yymatchDot(G)) goto l1128;
  }
  l1129:;	  goto l1127;
  l1128:;	  G->pos= yypos1128; G->thunkpos= yythunkpos1128;
  }  if (!yy_HtmlBlockCloseFieldset(G)) { goto l1126; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockFieldset", G->buf+G->pos));
  return 1;
  l1126:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockFieldset", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseFieldset(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseFieldset"));  if (!yymatchChar(G, '<')) goto l1132;  if (!yy_Spnl(G)) { goto l1132; }  if (!yymatchChar(G, '/')) goto l1132;
  {  int yypos1133= G->pos, yythunkpos1133= G->thunkpos;  if (!yymatchString(G, "fieldset")) goto l1134;  goto l1133;
  l1134:;	  G->pos= yypos1133; G->thunkpos= yythunkpos1133;  if (!yymatchString(G, "FIELDSET")) goto l1132;
  }
  l1133:;	  if (!yy_Spnl(G)) { goto l1132; }  if (!yymatchChar(G, '>')) goto l1132;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseFieldset", G->buf+G->pos));
  return 1;
  l1132:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseFieldset", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenFieldset(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenFieldset"));  if (!yymatchChar(G, '<')) goto l1135;  if (!yy_Spnl(G)) { goto l1135; }
  {  int yypos1136= G->pos, yythunkpos1136= G->thunkpos;  if (!yymatchString(G, "fieldset")) goto l1137;  goto l1136;
  l1137:;	  G->pos= yypos1136; G->thunkpos= yythunkpos1136;  if (!yymatchString(G, "FIELDSET")) goto l1135;
  }
  l1136:;	  if (!yy_Spnl(G)) { goto l1135; }
  l1138:;	
  {  int yypos1139= G->pos, yythunkpos1139= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1139; }  goto l1138;
  l1139:;	  G->pos= yypos1139; G->thunkpos= yythunkpos1139;
  }  if (!yymatchChar(G, '>')) goto l1135;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenFieldset", G->buf+G->pos));
  return 1;
  l1135:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenFieldset", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockDl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockDl"));  if (!yy_HtmlBlockOpenDl(G)) { goto l1140; }
  l1141:;	
  {  int yypos1142= G->pos, yythunkpos1142= G->thunkpos;
  {  int yypos1143= G->pos, yythunkpos1143= G->thunkpos;  if (!yy_HtmlBlockDl(G)) { goto l1144; }  goto l1143;
  l1144:;	  G->pos= yypos1143; G->thunkpos= yythunkpos1143;
  {  int yypos1145= G->pos, yythunkpos1145= G->thunkpos;  if (!yy_HtmlBlockCloseDl(G)) { goto l1145; }  goto l1142;
  l1145:;	  G->pos= yypos1145; G->thunkpos= yythunkpos1145;
  }  if (!yymatchDot(G)) goto l1142;
  }
  l1143:;	  goto l1141;
  l1142:;	  G->pos= yypos1142; G->thunkpos= yythunkpos1142;
  }  if (!yy_HtmlBlockCloseDl(G)) { goto l1140; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockDl", G->buf+G->pos));
  return 1;
  l1140:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockDl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseDl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseDl"));  if (!yymatchChar(G, '<')) goto l1146;  if (!yy_Spnl(G)) { goto l1146; }  if (!yymatchChar(G, '/')) goto l1146;
  {  int yypos1147= G->pos, yythunkpos1147= G->thunkpos;  if (!yymatchString(G, "dl")) goto l1148;  goto l1147;
  l1148:;	  G->pos= yypos1147; G->thunkpos= yythunkpos1147;  if (!yymatchString(G, "DL")) goto l1146;
  }
  l1147:;	  if (!yy_Spnl(G)) { goto l1146; }  if (!yymatchChar(G, '>')) goto l1146;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseDl", G->buf+G->pos));
  return 1;
  l1146:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseDl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenDl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenDl"));  if (!yymatchChar(G, '<')) goto l1149;  if (!yy_Spnl(G)) { goto l1149; }
  {  int yypos1150= G->pos, yythunkpos1150= G->thunkpos;  if (!yymatchString(G, "dl")) goto l1151;  goto l1150;
  l1151:;	  G->pos= yypos1150; G->thunkpos= yythunkpos1150;  if (!yymatchString(G, "DL")) goto l1149;
  }
  l1150:;	  if (!yy_Spnl(G)) { goto l1149; }
  l1152:;	
  {  int yypos1153= G->pos, yythunkpos1153= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1153; }  goto l1152;
  l1153:;	  G->pos= yypos1153; G->thunkpos= yythunkpos1153;
  }  if (!yymatchChar(G, '>')) goto l1149;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenDl", G->buf+G->pos));
  return 1;
  l1149:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenDl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockDiv(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockDiv"));  if (!yy_HtmlBlockOpenDiv(G)) { goto l1154; }
  l1155:;	
  {  int yypos1156= G->pos, yythunkpos1156= G->thunkpos;
  {  int yypos1157= G->pos, yythunkpos1157= G->thunkpos;  if (!yy_HtmlBlockDiv(G)) { goto l1158; }  goto l1157;
  l1158:;	  G->pos= yypos1157; G->thunkpos= yythunkpos1157;
  {  int yypos1159= G->pos, yythunkpos1159= G->thunkpos;  if (!yy_HtmlBlockCloseDiv(G)) { goto l1159; }  goto l1156;
  l1159:;	  G->pos= yypos1159; G->thunkpos= yythunkpos1159;
  }  if (!yymatchDot(G)) goto l1156;
  }
  l1157:;	  goto l1155;
  l1156:;	  G->pos= yypos1156; G->thunkpos= yythunkpos1156;
  }  if (!yy_HtmlBlockCloseDiv(G)) { goto l1154; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockDiv", G->buf+G->pos));
  return 1;
  l1154:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockDiv", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseDiv(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseDiv"));  if (!yymatchChar(G, '<')) goto l1160;  if (!yy_Spnl(G)) { goto l1160; }  if (!yymatchChar(G, '/')) goto l1160;
  {  int yypos1161= G->pos, yythunkpos1161= G->thunkpos;  if (!yymatchString(G, "div")) goto l1162;  goto l1161;
  l1162:;	  G->pos= yypos1161; G->thunkpos= yythunkpos1161;  if (!yymatchString(G, "DIV")) goto l1160;
  }
  l1161:;	  if (!yy_Spnl(G)) { goto l1160; }  if (!yymatchChar(G, '>')) goto l1160;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseDiv", G->buf+G->pos));
  return 1;
  l1160:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseDiv", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenDiv(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenDiv"));  if (!yymatchChar(G, '<')) goto l1163;  if (!yy_Spnl(G)) { goto l1163; }
  {  int yypos1164= G->pos, yythunkpos1164= G->thunkpos;  if (!yymatchString(G, "div")) goto l1165;  goto l1164;
  l1165:;	  G->pos= yypos1164; G->thunkpos= yythunkpos1164;  if (!yymatchString(G, "DIV")) goto l1163;
  }
  l1164:;	  if (!yy_Spnl(G)) { goto l1163; }
  l1166:;	
  {  int yypos1167= G->pos, yythunkpos1167= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1167; }  goto l1166;
  l1167:;	  G->pos= yypos1167; G->thunkpos= yythunkpos1167;
  }  if (!yymatchChar(G, '>')) goto l1163;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenDiv", G->buf+G->pos));
  return 1;
  l1163:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenDiv", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockDir(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockDir"));  if (!yy_HtmlBlockOpenDir(G)) { goto l1168; }
  l1169:;	
  {  int yypos1170= G->pos, yythunkpos1170= G->thunkpos;
  {  int yypos1171= G->pos, yythunkpos1171= G->thunkpos;  if (!yy_HtmlBlockDir(G)) { goto l1172; }  goto l1171;
  l1172:;	  G->pos= yypos1171; G->thunkpos= yythunkpos1171;
  {  int yypos1173= G->pos, yythunkpos1173= G->thunkpos;  if (!yy_HtmlBlockCloseDir(G)) { goto l1173; }  goto l1170;
  l1173:;	  G->pos= yypos1173; G->thunkpos= yythunkpos1173;
  }  if (!yymatchDot(G)) goto l1170;
  }
  l1171:;	  goto l1169;
  l1170:;	  G->pos= yypos1170; G->thunkpos= yythunkpos1170;
  }  if (!yy_HtmlBlockCloseDir(G)) { goto l1168; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockDir", G->buf+G->pos));
  return 1;
  l1168:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockDir", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseDir(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseDir"));  if (!yymatchChar(G, '<')) goto l1174;  if (!yy_Spnl(G)) { goto l1174; }  if (!yymatchChar(G, '/')) goto l1174;
  {  int yypos1175= G->pos, yythunkpos1175= G->thunkpos;  if (!yymatchString(G, "dir")) goto l1176;  goto l1175;
  l1176:;	  G->pos= yypos1175; G->thunkpos= yythunkpos1175;  if (!yymatchString(G, "DIR")) goto l1174;
  }
  l1175:;	  if (!yy_Spnl(G)) { goto l1174; }  if (!yymatchChar(G, '>')) goto l1174;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseDir", G->buf+G->pos));
  return 1;
  l1174:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseDir", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenDir(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenDir"));  if (!yymatchChar(G, '<')) goto l1177;  if (!yy_Spnl(G)) { goto l1177; }
  {  int yypos1178= G->pos, yythunkpos1178= G->thunkpos;  if (!yymatchString(G, "dir")) goto l1179;  goto l1178;
  l1179:;	  G->pos= yypos1178; G->thunkpos= yythunkpos1178;  if (!yymatchString(G, "DIR")) goto l1177;
  }
  l1178:;	  if (!yy_Spnl(G)) { goto l1177; }
  l1180:;	
  {  int yypos1181= G->pos, yythunkpos1181= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1181; }  goto l1180;
  l1181:;	  G->pos= yypos1181; G->thunkpos= yythunkpos1181;
  }  if (!yymatchChar(G, '>')) goto l1177;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenDir", G->buf+G->pos));
  return 1;
  l1177:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenDir", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCenter(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCenter"));  if (!yy_HtmlBlockOpenCenter(G)) { goto l1182; }
  l1183:;	
  {  int yypos1184= G->pos, yythunkpos1184= G->thunkpos;
  {  int yypos1185= G->pos, yythunkpos1185= G->thunkpos;  if (!yy_HtmlBlockCenter(G)) { goto l1186; }  goto l1185;
  l1186:;	  G->pos= yypos1185; G->thunkpos= yythunkpos1185;
  {  int yypos1187= G->pos, yythunkpos1187= G->thunkpos;  if (!yy_HtmlBlockCloseCenter(G)) { goto l1187; }  goto l1184;
  l1187:;	  G->pos= yypos1187; G->thunkpos= yythunkpos1187;
  }  if (!yymatchDot(G)) goto l1184;
  }
  l1185:;	  goto l1183;
  l1184:;	  G->pos= yypos1184; G->thunkpos= yythunkpos1184;
  }  if (!yy_HtmlBlockCloseCenter(G)) { goto l1182; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCenter", G->buf+G->pos));
  return 1;
  l1182:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCenter", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseCenter(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseCenter"));  if (!yymatchChar(G, '<')) goto l1188;  if (!yy_Spnl(G)) { goto l1188; }  if (!yymatchChar(G, '/')) goto l1188;
  {  int yypos1189= G->pos, yythunkpos1189= G->thunkpos;  if (!yymatchString(G, "center")) goto l1190;  goto l1189;
  l1190:;	  G->pos= yypos1189; G->thunkpos= yythunkpos1189;  if (!yymatchString(G, "CENTER")) goto l1188;
  }
  l1189:;	  if (!yy_Spnl(G)) { goto l1188; }  if (!yymatchChar(G, '>')) goto l1188;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseCenter", G->buf+G->pos));
  return 1;
  l1188:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseCenter", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenCenter(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenCenter"));  if (!yymatchChar(G, '<')) goto l1191;  if (!yy_Spnl(G)) { goto l1191; }
  {  int yypos1192= G->pos, yythunkpos1192= G->thunkpos;  if (!yymatchString(G, "center")) goto l1193;  goto l1192;
  l1193:;	  G->pos= yypos1192; G->thunkpos= yythunkpos1192;  if (!yymatchString(G, "CENTER")) goto l1191;
  }
  l1192:;	  if (!yy_Spnl(G)) { goto l1191; }
  l1194:;	
  {  int yypos1195= G->pos, yythunkpos1195= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1195; }  goto l1194;
  l1195:;	  G->pos= yypos1195; G->thunkpos= yythunkpos1195;
  }  if (!yymatchChar(G, '>')) goto l1191;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenCenter", G->buf+G->pos));
  return 1;
  l1191:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenCenter", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockBlockquote(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockBlockquote"));  if (!yy_HtmlBlockOpenBlockquote(G)) { goto l1196; }
  l1197:;	
  {  int yypos1198= G->pos, yythunkpos1198= G->thunkpos;
  {  int yypos1199= G->pos, yythunkpos1199= G->thunkpos;  if (!yy_HtmlBlockBlockquote(G)) { goto l1200; }  goto l1199;
  l1200:;	  G->pos= yypos1199; G->thunkpos= yythunkpos1199;
  {  int yypos1201= G->pos, yythunkpos1201= G->thunkpos;  if (!yy_HtmlBlockCloseBlockquote(G)) { goto l1201; }  goto l1198;
  l1201:;	  G->pos= yypos1201; G->thunkpos= yythunkpos1201;
  }  if (!yymatchDot(G)) goto l1198;
  }
  l1199:;	  goto l1197;
  l1198:;	  G->pos= yypos1198; G->thunkpos= yythunkpos1198;
  }  if (!yy_HtmlBlockCloseBlockquote(G)) { goto l1196; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockBlockquote", G->buf+G->pos));
  return 1;
  l1196:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockBlockquote", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseBlockquote(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseBlockquote"));  if (!yymatchChar(G, '<')) goto l1202;  if (!yy_Spnl(G)) { goto l1202; }  if (!yymatchChar(G, '/')) goto l1202;
  {  int yypos1203= G->pos, yythunkpos1203= G->thunkpos;  if (!yymatchString(G, "blockquote")) goto l1204;  goto l1203;
  l1204:;	  G->pos= yypos1203; G->thunkpos= yythunkpos1203;  if (!yymatchString(G, "BLOCKQUOTE")) goto l1202;
  }
  l1203:;	  if (!yy_Spnl(G)) { goto l1202; }  if (!yymatchChar(G, '>')) goto l1202;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseBlockquote", G->buf+G->pos));
  return 1;
  l1202:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseBlockquote", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenBlockquote(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenBlockquote"));  if (!yymatchChar(G, '<')) goto l1205;  if (!yy_Spnl(G)) { goto l1205; }
  {  int yypos1206= G->pos, yythunkpos1206= G->thunkpos;  if (!yymatchString(G, "blockquote")) goto l1207;  goto l1206;
  l1207:;	  G->pos= yypos1206; G->thunkpos= yythunkpos1206;  if (!yymatchString(G, "BLOCKQUOTE")) goto l1205;
  }
  l1206:;	  if (!yy_Spnl(G)) { goto l1205; }
  l1208:;	
  {  int yypos1209= G->pos, yythunkpos1209= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1209; }  goto l1208;
  l1209:;	  G->pos= yypos1209; G->thunkpos= yythunkpos1209;
  }  if (!yymatchChar(G, '>')) goto l1205;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenBlockquote", G->buf+G->pos));
  return 1;
  l1205:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenBlockquote", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockAddress(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockAddress"));  if (!yy_HtmlBlockOpenAddress(G)) { goto l1210; }
  l1211:;	
  {  int yypos1212= G->pos, yythunkpos1212= G->thunkpos;
  {  int yypos1213= G->pos, yythunkpos1213= G->thunkpos;  if (!yy_HtmlBlockAddress(G)) { goto l1214; }  goto l1213;
  l1214:;	  G->pos= yypos1213; G->thunkpos= yythunkpos1213;
  {  int yypos1215= G->pos, yythunkpos1215= G->thunkpos;  if (!yy_HtmlBlockCloseAddress(G)) { goto l1215; }  goto l1212;
  l1215:;	  G->pos= yypos1215; G->thunkpos= yythunkpos1215;
  }  if (!yymatchDot(G)) goto l1212;
  }
  l1213:;	  goto l1211;
  l1212:;	  G->pos= yypos1212; G->thunkpos= yythunkpos1212;
  }  if (!yy_HtmlBlockCloseAddress(G)) { goto l1210; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockAddress", G->buf+G->pos));
  return 1;
  l1210:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockAddress", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseAddress(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseAddress"));  if (!yymatchChar(G, '<')) goto l1216;  if (!yy_Spnl(G)) { goto l1216; }  if (!yymatchChar(G, '/')) goto l1216;
  {  int yypos1217= G->pos, yythunkpos1217= G->thunkpos;  if (!yymatchString(G, "address")) goto l1218;  goto l1217;
  l1218:;	  G->pos= yypos1217; G->thunkpos= yythunkpos1217;  if (!yymatchString(G, "ADDRESS")) goto l1216;
  }
  l1217:;	  if (!yy_Spnl(G)) { goto l1216; }  if (!yymatchChar(G, '>')) goto l1216;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseAddress", G->buf+G->pos));
  return 1;
  l1216:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseAddress", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlAttribute(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlAttribute"));
  {  int yypos1222= G->pos, yythunkpos1222= G->thunkpos;  if (!yy_AlphanumericAscii(G)) { goto l1223; }  goto l1222;
  l1223:;	  G->pos= yypos1222; G->thunkpos= yythunkpos1222;  if (!yymatchChar(G, '-')) goto l1219;
  }
  l1222:;	
  l1220:;	
  {  int yypos1221= G->pos, yythunkpos1221= G->thunkpos;
  {  int yypos1224= G->pos, yythunkpos1224= G->thunkpos;  if (!yy_AlphanumericAscii(G)) { goto l1225; }  goto l1224;
  l1225:;	  G->pos= yypos1224; G->thunkpos= yythunkpos1224;  if (!yymatchChar(G, '-')) goto l1221;
  }
  l1224:;	  goto l1220;
  l1221:;	  G->pos= yypos1221; G->thunkpos= yythunkpos1221;
  }  if (!yy_Spnl(G)) { goto l1219; }
  {  int yypos1226= G->pos, yythunkpos1226= G->thunkpos;  if (!yymatchChar(G, '=')) goto l1226;  if (!yy_Spnl(G)) { goto l1226; }
  {  int yypos1228= G->pos, yythunkpos1228= G->thunkpos;  if (!yy_Quoted(G)) { goto l1229; }  goto l1228;
  l1229:;	  G->pos= yypos1228; G->thunkpos= yythunkpos1228;
  {  int yypos1232= G->pos, yythunkpos1232= G->thunkpos;  if (!yymatchChar(G, '>')) goto l1232;  goto l1226;
  l1232:;	  G->pos= yypos1232; G->thunkpos= yythunkpos1232;
  }  if (!yy_Nonspacechar(G)) { goto l1226; }
  l1230:;	
  {  int yypos1231= G->pos, yythunkpos1231= G->thunkpos;
  {  int yypos1233= G->pos, yythunkpos1233= G->thunkpos;  if (!yymatchChar(G, '>')) goto l1233;  goto l1231;
  l1233:;	  G->pos= yypos1233; G->thunkpos= yythunkpos1233;
  }  if (!yy_Nonspacechar(G)) { goto l1231; }  goto l1230;
  l1231:;	  G->pos= yypos1231; G->thunkpos= yythunkpos1231;
  }
  }
  l1228:;	  goto l1227;
  l1226:;	  G->pos= yypos1226; G->thunkpos= yythunkpos1226;
  }
  l1227:;	  if (!yy_Spnl(G)) { goto l1219; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlAttribute", G->buf+G->pos));
  return 1;
  l1219:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlAttribute", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Spnl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Spnl"));  if (!yy_Sp(G)) { goto l1234; }
  {  int yypos1235= G->pos, yythunkpos1235= G->thunkpos;  if (!yy_Newline(G)) { goto l1235; }  if (!yy_Sp(G)) { goto l1235; }  goto l1236;
  l1235:;	  G->pos= yypos1235; G->thunkpos= yythunkpos1235;
  }
  l1236:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Spnl", G->buf+G->pos));
  return 1;
  l1234:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Spnl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenAddress(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenAddress"));  if (!yymatchChar(G, '<')) goto l1237;  if (!yy_Spnl(G)) { goto l1237; }
  {  int yypos1238= G->pos, yythunkpos1238= G->thunkpos;  if (!yymatchString(G, "address")) goto l1239;  goto l1238;
  l1239:;	  G->pos= yypos1238; G->thunkpos= yythunkpos1238;  if (!yymatchString(G, "ADDRESS")) goto l1237;
  }
  l1238:;	  if (!yy_Spnl(G)) { goto l1237; }
  l1240:;	
  {  int yypos1241= G->pos, yythunkpos1241= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1241; }  goto l1240;
  l1241:;	  G->pos= yypos1241; G->thunkpos= yythunkpos1241;
  }  if (!yymatchChar(G, '>')) goto l1237;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenAddress", G->buf+G->pos));
  return 1;
  l1237:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenAddress", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_OptionallyIndentedLine(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "OptionallyIndentedLine"));
  {  int yypos1243= G->pos, yythunkpos1243= G->thunkpos;  if (!yy_Indent(G)) { goto l1243; }  goto l1244;
  l1243:;	  G->pos= yypos1243; G->thunkpos= yythunkpos1243;
  }
  l1244:;	  if (!yy_Line(G)) { goto l1242; }
  yyprintf((stderr, "  ok   %s @ %s\n", "OptionallyIndentedLine", G->buf+G->pos));
  return 1;
  l1242:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "OptionallyIndentedLine", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Indent(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Indent"));
  {  int yypos1246= G->pos, yythunkpos1246= G->thunkpos;  if (!yymatchChar(G, '\t')) goto l1247;  goto l1246;
  l1247:;	  G->pos= yypos1246; G->thunkpos= yythunkpos1246;  if (!yymatchString(G, "    ")) goto l1245;
  }
  l1246:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Indent", G->buf+G->pos));
  return 1;
  l1245:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Indent", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ListBlockLine(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "ListBlockLine"));
  {  int yypos1249= G->pos, yythunkpos1249= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1249; }  goto l1248;
  l1249:;	  G->pos= yypos1249; G->thunkpos= yythunkpos1249;
  }
  {  int yypos1250= G->pos, yythunkpos1250= G->thunkpos;
  {  int yypos1251= G->pos, yythunkpos1251= G->thunkpos;  if (!yy_Indent(G)) { goto l1251; }  goto l1252;
  l1251:;	  G->pos= yypos1251; G->thunkpos= yythunkpos1251;
  }
  l1252:;	
  {  int yypos1253= G->pos, yythunkpos1253= G->thunkpos;  if (!yy_Bullet(G)) { goto l1254; }  goto l1253;
  l1254:;	  G->pos= yypos1253; G->thunkpos= yythunkpos1253;  if (!yy_Enumerator(G)) { goto l1250; }
  }
  l1253:;	  goto l1248;
  l1250:;	  G->pos= yypos1250; G->thunkpos= yythunkpos1250;
  }
  {  int yypos1255= G->pos, yythunkpos1255= G->thunkpos;  if (!yy_HorizontalRule(G)) { goto l1255; }  goto l1248;
  l1255:;	  G->pos= yypos1255; G->thunkpos= yythunkpos1255;
  }  if (!yy_OptionallyIndentedLine(G)) { goto l1248; }
  yyprintf((stderr, "  ok   %s @ %s\n", "ListBlockLine", G->buf+G->pos));
  return 1;
  l1248:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ListBlockLine", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ListContinuationBlock(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "ListContinuationBlock"));  if (!yy_StartList(G)) { goto l1256; }  yyDo(G, yySet, -1, 0);  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1256;
  l1257:;	
  {  int yypos1258= G->pos, yythunkpos1258= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1258; }  goto l1257;
  l1258:;	  G->pos= yypos1258; G->thunkpos= yythunkpos1258;
  }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1256;  yyDo(G, yy_1_ListContinuationBlock, G->begin, G->end);  if (!yy_Indent(G)) { goto l1256; }  if (!yy_ListBlock(G)) { goto l1256; }  yyDo(G, yy_2_ListContinuationBlock, G->begin, G->end);
  l1259:;	
  {  int yypos1260= G->pos, yythunkpos1260= G->thunkpos;  if (!yy_Indent(G)) { goto l1260; }  if (!yy_ListBlock(G)) { goto l1260; }  yyDo(G, yy_2_ListContinuationBlock, G->begin, G->end);  goto l1259;
  l1260:;	  G->pos= yypos1260; G->thunkpos= yythunkpos1260;
  }  yyDo(G, yy_3_ListContinuationBlock, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "ListContinuationBlock", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1256:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ListContinuationBlock", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ListBlock(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "ListBlock"));  if (!yy_StartList(G)) { goto l1261; }  yyDo(G, yySet, -1, 0);
  {  int yypos1262= G->pos, yythunkpos1262= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1262; }  goto l1261;
  l1262:;	  G->pos= yypos1262; G->thunkpos= yythunkpos1262;
  }  if (!yy_Line(G)) { goto l1261; }  yyDo(G, yy_1_ListBlock, G->begin, G->end);
  l1263:;	
  {  int yypos1264= G->pos, yythunkpos1264= G->thunkpos;  if (!yy_ListBlockLine(G)) { goto l1264; }  yyDo(G, yy_2_ListBlock, G->begin, G->end);  goto l1263;
  l1264:;	  G->pos= yypos1264; G->thunkpos= yythunkpos1264;
  }  yyDo(G, yy_3_ListBlock, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "ListBlock", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1261:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ListBlock", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ListItem(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "ListItem"));
  {  int yypos1266= G->pos, yythunkpos1266= G->thunkpos;  if (!yy_Bullet(G)) { goto l1267; }  goto l1266;
  l1267:;	  G->pos= yypos1266; G->thunkpos= yythunkpos1266;  if (!yy_Enumerator(G)) { goto l1265; }
  }
  l1266:;	  if (!yy_StartList(G)) { goto l1265; }  yyDo(G, yySet, -1, 0);  if (!yy_ListBlock(G)) { goto l1265; }  yyDo(G, yy_1_ListItem, G->begin, G->end);
  l1268:;	
  {  int yypos1269= G->pos, yythunkpos1269= G->thunkpos;  if (!yy_ListContinuationBlock(G)) { goto l1269; }  yyDo(G, yy_2_ListItem, G->begin, G->end);  goto l1268;
  l1269:;	  G->pos= yypos1269; G->thunkpos= yythunkpos1269;
  }  yyDo(G, yy_3_ListItem, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "ListItem", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1265:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ListItem", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Enumerator(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Enumerator"));  if (!yy_NonindentSpace(G)) { goto l1270; }  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1270;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l1270;
  l1271:;	
  {  int yypos1272= G->pos, yythunkpos1272= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l1272;  goto l1271;
  l1272:;	  G->pos= yypos1272; G->thunkpos= yythunkpos1272;
  }  if (!yymatchChar(G, '.')) goto l1270;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1270;  if (!yy_Spacechar(G)) { goto l1270; }
  l1273:;	
  {  int yypos1274= G->pos, yythunkpos1274= G->thunkpos;  if (!yy_Spacechar(G)) { goto l1274; }  goto l1273;
  l1274:;	  G->pos= yypos1274; G->thunkpos= yythunkpos1274;
  }  yyDo(G, yy_1_Enumerator, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Enumerator", G->buf+G->pos));
  return 1;
  l1270:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Enumerator", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ListItemTight(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "ListItemTight"));
  {  int yypos1276= G->pos, yythunkpos1276= G->thunkpos;  if (!yy_Bullet(G)) { goto l1277; }  goto l1276;
  l1277:;	  G->pos= yypos1276; G->thunkpos= yythunkpos1276;  if (!yy_Enumerator(G)) { goto l1275; }
  }
  l1276:;	  if (!yy_StartList(G)) { goto l1275; }  yyDo(G, yySet, -1, 0);  if (!yy_ListBlock(G)) { goto l1275; }  yyDo(G, yy_1_ListItemTight, G->begin, G->end);
  l1278:;	
  {  int yypos1279= G->pos, yythunkpos1279= G->thunkpos;
  {  int yypos1280= G->pos, yythunkpos1280= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1280; }  goto l1279;
  l1280:;	  G->pos= yypos1280; G->thunkpos= yythunkpos1280;
  }  if (!yy_ListContinuationBlock(G)) { goto l1279; }  yyDo(G, yy_2_ListItemTight, G->begin, G->end);  goto l1278;
  l1279:;	  G->pos= yypos1279; G->thunkpos= yythunkpos1279;
  }
  {  int yypos1281= G->pos, yythunkpos1281= G->thunkpos;  if (!yy_ListContinuationBlock(G)) { goto l1281; }  goto l1275;
  l1281:;	  G->pos= yypos1281; G->thunkpos= yythunkpos1281;
  }  yyDo(G, yy_3_ListItemTight, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "ListItemTight", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1275:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ListItemTight", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ListLoose(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 2, 0);
  yyprintf((stderr, "%s\n", "ListLoose"));  if (!yy_StartList(G)) { goto l1282; }  yyDo(G, yySet, -2, 0);  if (!yy_ListItem(G)) { goto l1282; }  yyDo(G, yySet, -1, 0);
  l1285:;	
  {  int yypos1286= G->pos, yythunkpos1286= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1286; }  goto l1285;
  l1286:;	  G->pos= yypos1286; G->thunkpos= yythunkpos1286;
  }  yyDo(G, yy_1_ListLoose, G->begin, G->end);
  l1283:;	
  {  int yypos1284= G->pos, yythunkpos1284= G->thunkpos;  if (!yy_ListItem(G)) { goto l1284; }  yyDo(G, yySet, -1, 0);
  l1287:;	
  {  int yypos1288= G->pos, yythunkpos1288= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1288; }  goto l1287;
  l1288:;	  G->pos= yypos1288; G->thunkpos= yythunkpos1288;
  }  yyDo(G, yy_1_ListLoose, G->begin, G->end);  goto l1283;
  l1284:;	  G->pos= yypos1284; G->thunkpos= yythunkpos1284;
  }  yyDo(G, yy_2_ListLoose, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "ListLoose", G->buf+G->pos));  yyDo(G, yyPop, 2, 0);
  return 1;
  l1282:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ListLoose", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ListTight(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "ListTight"));  if (!yy_StartList(G)) { goto l1289; }  yyDo(G, yySet, -1, 0);  if (!yy_ListItemTight(G)) { goto l1289; }  yyDo(G, yy_1_ListTight, G->begin, G->end);
  l1290:;	
  {  int yypos1291= G->pos, yythunkpos1291= G->thunkpos;  if (!yy_ListItemTight(G)) { goto l1291; }  yyDo(G, yy_1_ListTight, G->begin, G->end);  goto l1290;
  l1291:;	  G->pos= yypos1291; G->thunkpos= yythunkpos1291;
  }
  l1292:;	
  {  int yypos1293= G->pos, yythunkpos1293= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1293; }  goto l1292;
  l1293:;	  G->pos= yypos1293; G->thunkpos= yythunkpos1293;
  }
  {  int yypos1294= G->pos, yythunkpos1294= G->thunkpos;
  {  int yypos1295= G->pos, yythunkpos1295= G->thunkpos;  if (!yy_Bullet(G)) { goto l1296; }  goto l1295;
  l1296:;	  G->pos= yypos1295; G->thunkpos= yythunkpos1295;  if (!yy_Enumerator(G)) { goto l1294; }
  }
  l1295:;	  goto l1289;
  l1294:;	  G->pos= yypos1294; G->thunkpos= yythunkpos1294;
  }  yyDo(G, yy_2_ListTight, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "ListTight", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1289:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ListTight", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Spacechar(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Spacechar"));
  {  int yypos1298= G->pos, yythunkpos1298= G->thunkpos;  if (!yymatchChar(G, ' ')) goto l1299;  goto l1298;
  l1299:;	  G->pos= yypos1298; G->thunkpos= yythunkpos1298;  if (!yymatchChar(G, '\t')) goto l1297;
  }
  l1298:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Spacechar", G->buf+G->pos));
  return 1;
  l1297:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Spacechar", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Bullet(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Bullet"));
  {  int yypos1301= G->pos, yythunkpos1301= G->thunkpos;  if (!yy_HorizontalRule(G)) { goto l1301; }  goto l1300;
  l1301:;	  G->pos= yypos1301; G->thunkpos= yythunkpos1301;
  }  if (!yy_NonindentSpace(G)) { goto l1300; }  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1300;
  {  int yypos1302= G->pos, yythunkpos1302= G->thunkpos;  if (!yymatchChar(G, '+')) goto l1303;  goto l1302;
  l1303:;	  G->pos= yypos1302; G->thunkpos= yythunkpos1302;  if (!yymatchChar(G, '*')) goto l1304;  goto l1302;
  l1304:;	  G->pos= yypos1302; G->thunkpos= yythunkpos1302;  if (!yymatchChar(G, '-')) goto l1300;
  }
  l1302:;	  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1300;  if (!yy_Spacechar(G)) { goto l1300; }
  l1305:;	
  {  int yypos1306= G->pos, yythunkpos1306= G->thunkpos;  if (!yy_Spacechar(G)) { goto l1306; }  goto l1305;
  l1306:;	  G->pos= yypos1306; G->thunkpos= yythunkpos1306;
  }  yyDo(G, yy_1_Bullet, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Bullet", G->buf+G->pos));
  return 1;
  l1300:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Bullet", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_VerbatimChunk(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "VerbatimChunk"));
  l1308:;	
  {  int yypos1309= G->pos, yythunkpos1309= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1309; }  goto l1308;
  l1309:;	  G->pos= yypos1309; G->thunkpos= yythunkpos1309;
  }  if (!yy_NonblankIndentedLine(G)) { goto l1307; }
  l1310:;	
  {  int yypos1311= G->pos, yythunkpos1311= G->thunkpos;  if (!yy_NonblankIndentedLine(G)) { goto l1311; }  goto l1310;
  l1311:;	  G->pos= yypos1311; G->thunkpos= yythunkpos1311;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "VerbatimChunk", G->buf+G->pos));
  return 1;
  l1307:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "VerbatimChunk", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_IndentedLine(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "IndentedLine"));  if (!yy_Indent(G)) { goto l1312; }  if (!yy_Line(G)) { goto l1312; }
  yyprintf((stderr, "  ok   %s @ %s\n", "IndentedLine", G->buf+G->pos));
  return 1;
  l1312:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "IndentedLine", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_NonblankIndentedLine(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "NonblankIndentedLine"));
  {  int yypos1314= G->pos, yythunkpos1314= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1314; }  goto l1313;
  l1314:;	  G->pos= yypos1314; G->thunkpos= yythunkpos1314;
  }  if (!yy_IndentedLine(G)) { goto l1313; }
  yyprintf((stderr, "  ok   %s @ %s\n", "NonblankIndentedLine", G->buf+G->pos));
  return 1;
  l1313:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "NonblankIndentedLine", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Line(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Line"));  if (!yy_RawLine(G)) { goto l1315; }  yyDo(G, yy_1_Line, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Line", G->buf+G->pos));
  return 1;
  l1315:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Line", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_StartList(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "StartList"));
  {  int yypos1317= G->pos, yythunkpos1317= G->thunkpos;  if (!yymatchDot(G)) goto l1316;  G->pos= yypos1317; G->thunkpos= yythunkpos1317;
  }  yyDo(G, yy_1_StartList, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "StartList", G->buf+G->pos));
  return 1;
  l1316:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "StartList", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_BlockQuoteRaw(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "BlockQuoteRaw"));  if (!yy_StartList(G)) { goto l1318; }  yyDo(G, yySet, -1, 0);  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1318;  if (!yymatchChar(G, '>')) goto l1318;
  {  int yypos1321= G->pos, yythunkpos1321= G->thunkpos;  if (!yymatchChar(G, ' ')) goto l1321;  goto l1322;
  l1321:;	  G->pos= yypos1321; G->thunkpos= yythunkpos1321;
  }
  l1322:;	  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1318;  yyDo(G, yy_1_BlockQuoteRaw, G->begin, G->end);  if (!yy_Line(G)) { goto l1318; }  yyDo(G, yy_2_BlockQuoteRaw, G->begin, G->end);
  l1323:;	
  {  int yypos1324= G->pos, yythunkpos1324= G->thunkpos;
  {  int yypos1325= G->pos, yythunkpos1325= G->thunkpos;  if (!yymatchChar(G, '>')) goto l1325;  goto l1324;
  l1325:;	  G->pos= yypos1325; G->thunkpos= yythunkpos1325;
  }
  {  int yypos1326= G->pos, yythunkpos1326= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1326; }  goto l1324;
  l1326:;	  G->pos= yypos1326; G->thunkpos= yythunkpos1326;
  }  if (!yy_Line(G)) { goto l1324; }  yyDo(G, yy_3_BlockQuoteRaw, G->begin, G->end);  goto l1323;
  l1324:;	  G->pos= yypos1324; G->thunkpos= yythunkpos1324;
  }
  l1327:;	
  {  int yypos1328= G->pos, yythunkpos1328= G->thunkpos;  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1328;  if (!yy_BlankLine(G)) { goto l1328; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1328;  yyDo(G, yy_4_BlockQuoteRaw, G->begin, G->end);  goto l1327;
  l1328:;	  G->pos= yypos1328; G->thunkpos= yythunkpos1328;
  }
  l1319:;	
  {  int yypos1320= G->pos, yythunkpos1320= G->thunkpos;  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1320;  if (!yymatchChar(G, '>')) goto l1320;
  {  int yypos1329= G->pos, yythunkpos1329= G->thunkpos;  if (!yymatchChar(G, ' ')) goto l1329;  goto l1330;
  l1329:;	  G->pos= yypos1329; G->thunkpos= yythunkpos1329;
  }
  l1330:;	  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1320;  yyDo(G, yy_1_BlockQuoteRaw, G->begin, G->end);  if (!yy_Line(G)) { goto l1320; }  yyDo(G, yy_2_BlockQuoteRaw, G->begin, G->end);
  l1331:;	
  {  int yypos1332= G->pos, yythunkpos1332= G->thunkpos;
  {  int yypos1333= G->pos, yythunkpos1333= G->thunkpos;  if (!yymatchChar(G, '>')) goto l1333;  goto l1332;
  l1333:;	  G->pos= yypos1333; G->thunkpos= yythunkpos1333;
  }
  {  int yypos1334= G->pos, yythunkpos1334= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1334; }  goto l1332;
  l1334:;	  G->pos= yypos1334; G->thunkpos= yythunkpos1334;
  }  if (!yy_Line(G)) { goto l1332; }  yyDo(G, yy_3_BlockQuoteRaw, G->begin, G->end);  goto l1331;
  l1332:;	  G->pos= yypos1332; G->thunkpos= yythunkpos1332;
  }
  l1335:;	
  {  int yypos1336= G->pos, yythunkpos1336= G->thunkpos;  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1336;  if (!yy_BlankLine(G)) { goto l1336; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1336;  yyDo(G, yy_4_BlockQuoteRaw, G->begin, G->end);  goto l1335;
  l1336:;	  G->pos= yypos1336; G->thunkpos= yythunkpos1336;
  }  goto l1319;
  l1320:;	  G->pos= yypos1320; G->thunkpos= yythunkpos1320;
  }  yyDo(G, yy_5_BlockQuoteRaw, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "BlockQuoteRaw", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1318:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "BlockQuoteRaw", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Endline(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Endline"));
  {  int yypos1338= G->pos, yythunkpos1338= G->thunkpos;  if (!yy_LineBreak(G)) { goto l1339; }  goto l1338;
  l1339:;	  G->pos= yypos1338; G->thunkpos= yythunkpos1338;  if (!yy_TerminalEndline(G)) { goto l1340; }  goto l1338;
  l1340:;	  G->pos= yypos1338; G->thunkpos= yythunkpos1338;  if (!yy_NormalEndline(G)) { goto l1337; }
  }
  l1338:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Endline", G->buf+G->pos));
  return 1;
  l1337:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Endline", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_RawLine(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "RawLine"));
  {  int yypos1342= G->pos, yythunkpos1342= G->thunkpos;  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1343;
  l1344:;	
  {  int yypos1345= G->pos, yythunkpos1345= G->thunkpos;
  {  int yypos1346= G->pos, yythunkpos1346= G->thunkpos;  if (!yymatchChar(G, '\r')) goto l1346;  goto l1345;
  l1346:;	  G->pos= yypos1346; G->thunkpos= yythunkpos1346;
  }
  {  int yypos1347= G->pos, yythunkpos1347= G->thunkpos;  if (!yymatchChar(G, '\n')) goto l1347;  goto l1345;
  l1347:;	  G->pos= yypos1347; G->thunkpos= yythunkpos1347;
  }  if (!yymatchDot(G)) goto l1345;  goto l1344;
  l1345:;	  G->pos= yypos1345; G->thunkpos= yythunkpos1345;
  }  if (!yy_Newline(G)) { goto l1343; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1343;  goto l1342;
  l1343:;	  G->pos= yypos1342; G->thunkpos= yythunkpos1342;  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1341;  if (!yymatchDot(G)) goto l1341;
  l1348:;	
  {  int yypos1349= G->pos, yythunkpos1349= G->thunkpos;  if (!yymatchDot(G)) goto l1349;  goto l1348;
  l1349:;	  G->pos= yypos1349; G->thunkpos= yythunkpos1349;
  }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1341;  if (!yy_Eof(G)) { goto l1341; }
  }
  l1342:;	  yyDo(G, yy_1_RawLine, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "RawLine", G->buf+G->pos));
  return 1;
  l1341:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "RawLine", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_SetextBottom2(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "SetextBottom2"));  if (!yymatchChar(G, '-')) goto l1350;
  l1351:;	
  {  int yypos1352= G->pos, yythunkpos1352= G->thunkpos;  if (!yymatchChar(G, '-')) goto l1352;  goto l1351;
  l1352:;	  G->pos= yypos1352; G->thunkpos= yythunkpos1352;
  }  if (!yy_Newline(G)) { goto l1350; }
  yyprintf((stderr, "  ok   %s @ %s\n", "SetextBottom2", G->buf+G->pos));
  return 1;
  l1350:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "SetextBottom2", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_SetextBottom1(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "SetextBottom1"));  if (!yymatchChar(G, '=')) goto l1353;
  l1354:;	
  {  int yypos1355= G->pos, yythunkpos1355= G->thunkpos;  if (!yymatchChar(G, '=')) goto l1355;  goto l1354;
  l1355:;	  G->pos= yypos1355; G->thunkpos= yythunkpos1355;
  }  if (!yy_Newline(G)) { goto l1353; }
  yyprintf((stderr, "  ok   %s @ %s\n", "SetextBottom1", G->buf+G->pos));
  return 1;
  l1353:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "SetextBottom1", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_SetextHeading2(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "SetextHeading2"));
  {  int yypos1357= G->pos, yythunkpos1357= G->thunkpos;  if (!yy_RawLine(G)) { goto l1356; }  if (!yy_SetextBottom2(G)) { goto l1356; }  G->pos= yypos1357; G->thunkpos= yythunkpos1357;
  }  if (!yy_LocMarker(G)) { goto l1356; }  yyDo(G, yySet, -1, 0);  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1356;
  {  int yypos1360= G->pos, yythunkpos1360= G->thunkpos;  if (!yy_Endline(G)) { goto l1360; }  goto l1356;
  l1360:;	  G->pos= yypos1360; G->thunkpos= yythunkpos1360;
  }  if (!yy_Inline(G)) { goto l1356; }
  l1358:;	
  {  int yypos1359= G->pos, yythunkpos1359= G->thunkpos;
  {  int yypos1361= G->pos, yythunkpos1361= G->thunkpos;  if (!yy_Endline(G)) { goto l1361; }  goto l1359;
  l1361:;	  G->pos= yypos1361; G->thunkpos= yythunkpos1361;
  }  if (!yy_Inline(G)) { goto l1359; }  goto l1358;
  l1359:;	  G->pos= yypos1359; G->thunkpos= yythunkpos1359;
  }  if (!yy_Sp(G)) { goto l1356; }  if (!yy_Newline(G)) { goto l1356; }  if (!yy_SetextBottom2(G)) { goto l1356; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1356;  yyDo(G, yy_1_SetextHeading2, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "SetextHeading2", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1356:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "SetextHeading2", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_SetextHeading1(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "SetextHeading1"));
  {  int yypos1363= G->pos, yythunkpos1363= G->thunkpos;  if (!yy_RawLine(G)) { goto l1362; }  if (!yy_SetextBottom1(G)) { goto l1362; }  G->pos= yypos1363; G->thunkpos= yythunkpos1363;
  }  if (!yy_LocMarker(G)) { goto l1362; }  yyDo(G, yySet, -1, 0);  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1362;
  {  int yypos1366= G->pos, yythunkpos1366= G->thunkpos;  if (!yy_Endline(G)) { goto l1366; }  goto l1362;
  l1366:;	  G->pos= yypos1366; G->thunkpos= yythunkpos1366;
  }  if (!yy_Inline(G)) { goto l1362; }
  l1364:;	
  {  int yypos1365= G->pos, yythunkpos1365= G->thunkpos;
  {  int yypos1367= G->pos, yythunkpos1367= G->thunkpos;  if (!yy_Endline(G)) { goto l1367; }  goto l1365;
  l1367:;	  G->pos= yypos1367; G->thunkpos= yythunkpos1367;
  }  if (!yy_Inline(G)) { goto l1365; }  goto l1364;
  l1365:;	  G->pos= yypos1365; G->thunkpos= yythunkpos1365;
  }  if (!yy_Sp(G)) { goto l1362; }  if (!yy_Newline(G)) { goto l1362; }  if (!yy_SetextBottom1(G)) { goto l1362; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1362;  yyDo(G, yy_1_SetextHeading1, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "SetextHeading1", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1362:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "SetextHeading1", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_SetextHeading(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "SetextHeading"));
  {  int yypos1369= G->pos, yythunkpos1369= G->thunkpos;  if (!yy_SetextHeading1(G)) { goto l1370; }  goto l1369;
  l1370:;	  G->pos= yypos1369; G->thunkpos= yythunkpos1369;  if (!yy_SetextHeading2(G)) { goto l1368; }
  }
  l1369:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "SetextHeading", G->buf+G->pos));
  return 1;
  l1368:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "SetextHeading", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Space(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Space"));  if (!yy_Spacechar(G)) { goto l1371; }
  l1372:;	
  {  int yypos1373= G->pos, yythunkpos1373= G->thunkpos;  if (!yy_Spacechar(G)) { goto l1373; }  goto l1372;
  l1373:;	  G->pos= yypos1373; G->thunkpos= yythunkpos1373;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "Space", G->buf+G->pos));
  return 1;
  l1371:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Space", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_AtxHeading(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "AtxHeading"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1374;  if (!yy_AtxStart(G)) { goto l1374; }  yyDo(G, yySet, -1, 0);  if (!yy_Space(G)) { goto l1374; }  if (!yy_AtxInline(G)) { goto l1374; }
  l1375:;	
  {  int yypos1376= G->pos, yythunkpos1376= G->thunkpos;  if (!yy_AtxInline(G)) { goto l1376; }  goto l1375;
  l1376:;	  G->pos= yypos1376; G->thunkpos= yythunkpos1376;
  }
  {  int yypos1377= G->pos, yythunkpos1377= G->thunkpos;  if (!yy_Sp(G)) { goto l1377; }
  l1379:;	
  {  int yypos1380= G->pos, yythunkpos1380= G->thunkpos;  if (!yymatchChar(G, '#')) goto l1380;  goto l1379;
  l1380:;	  G->pos= yypos1380; G->thunkpos= yythunkpos1380;
  }  if (!yy_Sp(G)) { goto l1377; }  goto l1378;
  l1377:;	  G->pos= yypos1377; G->thunkpos= yythunkpos1377;
  }
  l1378:;	  if (!yy_Newline(G)) { goto l1374; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1374;  yyDo(G, yy_1_AtxHeading, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "AtxHeading", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1374:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "AtxHeading", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_AtxStart(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "AtxStart"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1381;
  {  int yypos1382= G->pos, yythunkpos1382= G->thunkpos;  if (!yymatchString(G, "######")) goto l1383;  goto l1382;
  l1383:;	  G->pos= yypos1382; G->thunkpos= yythunkpos1382;  if (!yymatchString(G, "#####")) goto l1384;  goto l1382;
  l1384:;	  G->pos= yypos1382; G->thunkpos= yythunkpos1382;  if (!yymatchString(G, "####")) goto l1385;  goto l1382;
  l1385:;	  G->pos= yypos1382; G->thunkpos= yythunkpos1382;  if (!yymatchString(G, "###")) goto l1386;  goto l1382;
  l1386:;	  G->pos= yypos1382; G->thunkpos= yythunkpos1382;  if (!yymatchString(G, "##")) goto l1387;  goto l1382;
  l1387:;	  G->pos= yypos1382; G->thunkpos= yythunkpos1382;  if (!yymatchChar(G, '#')) goto l1381;
  }
  l1382:;	  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1381;  yyDo(G, yy_1_AtxStart, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "AtxStart", G->buf+G->pos));
  return 1;
  l1381:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "AtxStart", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Inline(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Inline"));
  {  int yypos1389= G->pos, yythunkpos1389= G->thunkpos;  if (!yy_Str(G)) { goto l1390; }  goto l1389;
  l1390:;	  G->pos= yypos1389; G->thunkpos= yythunkpos1389;  if (!yy_Endline(G)) { goto l1391; }  goto l1389;
  l1391:;	  G->pos= yypos1389; G->thunkpos= yythunkpos1389;  if (!yy_UlOrStarLine(G)) { goto l1392; }  goto l1389;
  l1392:;	  G->pos= yypos1389; G->thunkpos= yythunkpos1389;  if (!yy_Space(G)) { goto l1393; }  goto l1389;
  l1393:;	  G->pos= yypos1389; G->thunkpos= yythunkpos1389;  if (!yy_Strong(G)) { goto l1394; }  goto l1389;
  l1394:;	  G->pos= yypos1389; G->thunkpos= yythunkpos1389;  if (!yy_Emph(G)) { goto l1395; }  goto l1389;
  l1395:;	  G->pos= yypos1389; G->thunkpos= yythunkpos1389;  if (!yy_Strike(G)) { goto l1396; }  goto l1389;
  l1396:;	  G->pos= yypos1389; G->thunkpos= yythunkpos1389;  if (!yy_Image(G)) { goto l1397; }  goto l1389;
  l1397:;	  G->pos= yypos1389; G->thunkpos= yythunkpos1389;  if (!yy_Link(G)) { goto l1398; }  goto l1389;
  l1398:;	  G->pos= yypos1389; G->thunkpos= yythunkpos1389;  if (!yy_NoteReference(G)) { goto l1399; }  goto l1389;
  l1399:;	  G->pos= yypos1389; G->thunkpos= yythunkpos1389;  if (!yy_InlineNote(G)) { goto l1400; }  goto l1389;
  l1400:;	  G->pos= yypos1389; G->thunkpos= yythunkpos1389;  if (!yy_Code(G)) { goto l1401; }  goto l1389;
  l1401:;	  G->pos= yypos1389; G->thunkpos= yythunkpos1389;  if (!yy_RawHtml(G)) { goto l1402; }  goto l1389;
  l1402:;	  G->pos= yypos1389; G->thunkpos= yythunkpos1389;  if (!yy_Entity(G)) { goto l1403; }  goto l1389;
  l1403:;	  G->pos= yypos1389; G->thunkpos= yythunkpos1389;  if (!yy_EscapedChar(G)) { goto l1404; }  goto l1389;
  l1404:;	  G->pos= yypos1389; G->thunkpos= yythunkpos1389;  if (!yy_Symbol(G)) { goto l1388; }
  }
  l1389:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Inline", G->buf+G->pos));
  return 1;
  l1388:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Inline", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Sp(GREG *G)
{
  yyprintf((stderr, "%s\n", "Sp"));
  l1406:;	
  {  int yypos1407= G->pos, yythunkpos1407= G->thunkpos;  if (!yy_Spacechar(G)) { goto l1407; }  goto l1406;
  l1407:;	  G->pos= yypos1407; G->thunkpos= yythunkpos1407;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "Sp", G->buf+G->pos));
  return 1;
}
YY_RULE(int) yy_Newline(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Newline"));
  {  int yypos1409= G->pos, yythunkpos1409= G->thunkpos;  if (!yymatchChar(G, '\n')) goto l1410;  goto l1409;
  l1410:;	  G->pos= yypos1409; G->thunkpos= yythunkpos1409;  if (!yymatchChar(G, '\r')) goto l1408;
  {  int yypos1411= G->pos, yythunkpos1411= G->thunkpos;  if (!yymatchChar(G, '\n')) goto l1411;  goto l1412;
  l1411:;	  G->pos= yypos1411; G->thunkpos= yythunkpos1411;
  }
  l1412:;	
  }
  l1409:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Newline", G->buf+G->pos));
  return 1;
  l1408:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Newline", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_AtxInline(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "AtxInline"));
  {  int yypos1414= G->pos, yythunkpos1414= G->thunkpos;  if (!yy_Newline(G)) { goto l1414; }  goto l1413;
  l1414:;	  G->pos= yypos1414; G->thunkpos= yythunkpos1414;
  }
  {  int yypos1415= G->pos, yythunkpos1415= G->thunkpos;  if (!yy_Sp(G)) { goto l1415; }
  l1416:;	
  {  int yypos1417= G->pos, yythunkpos1417= G->thunkpos;  if (!yymatchChar(G, '#')) goto l1417;  goto l1416;
  l1417:;	  G->pos= yypos1417; G->thunkpos= yythunkpos1417;
  }  if (!yy_Sp(G)) { goto l1415; }  if (!yy_Newline(G)) { goto l1415; }  goto l1413;
  l1415:;	  G->pos= yypos1415; G->thunkpos= yythunkpos1415;
  }  if (!yy_Inline(G)) { goto l1413; }
  yyprintf((stderr, "  ok   %s @ %s\n", "AtxInline", G->buf+G->pos));
  return 1;
  l1413:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "AtxInline", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Inlines(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Inlines"));
  {  int yypos1421= G->pos, yythunkpos1421= G->thunkpos;
  {  int yypos1423= G->pos, yythunkpos1423= G->thunkpos;  if (!yy_Endline(G)) { goto l1423; }  goto l1422;
  l1423:;	  G->pos= yypos1423; G->thunkpos= yythunkpos1423;
  }  if (!yy_Inline(G)) { goto l1422; }  goto l1421;
  l1422:;	  G->pos= yypos1421; G->thunkpos= yythunkpos1421;  if (!yy_Endline(G)) { goto l1418; }
  {  int yypos1424= G->pos, yythunkpos1424= G->thunkpos;  if (!yy_Inline(G)) { goto l1418; }  G->pos= yypos1424; G->thunkpos= yythunkpos1424;
  }
  }
  l1421:;	
  l1419:;	
  {  int yypos1420= G->pos, yythunkpos1420= G->thunkpos;
  {  int yypos1425= G->pos, yythunkpos1425= G->thunkpos;
  {  int yypos1427= G->pos, yythunkpos1427= G->thunkpos;  if (!yy_Endline(G)) { goto l1427; }  goto l1426;
  l1427:;	  G->pos= yypos1427; G->thunkpos= yythunkpos1427;
  }  if (!yy_Inline(G)) { goto l1426; }  goto l1425;
  l1426:;	  G->pos= yypos1425; G->thunkpos= yythunkpos1425;  if (!yy_Endline(G)) { goto l1420; }
  {  int yypos1428= G->pos, yythunkpos1428= G->thunkpos;  if (!yy_Inline(G)) { goto l1420; }  G->pos= yypos1428; G->thunkpos= yythunkpos1428;
  }
  }
  l1425:;	  goto l1419;
  l1420:;	  G->pos= yypos1420; G->thunkpos= yythunkpos1420;
  }
  {  int yypos1429= G->pos, yythunkpos1429= G->thunkpos;  if (!yy_Endline(G)) { goto l1429; }  goto l1430;
  l1429:;	  G->pos= yypos1429; G->thunkpos= yythunkpos1429;
  }
  l1430:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Inlines", G->buf+G->pos));
  return 1;
  l1418:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Inlines", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_NonindentSpace(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "NonindentSpace"));
  {  int yypos1432= G->pos, yythunkpos1432= G->thunkpos;  if (!yymatchString(G, "   ")) goto l1433;  goto l1432;
  l1433:;	  G->pos= yypos1432; G->thunkpos= yythunkpos1432;  if (!yymatchString(G, "  ")) goto l1434;  goto l1432;
  l1434:;	  G->pos= yypos1432; G->thunkpos= yythunkpos1432;  if (!yymatchChar(G, ' ')) goto l1435;  goto l1432;
  l1435:;	  G->pos= yypos1432; G->thunkpos= yythunkpos1432;  if (!yymatchString(G, "")) goto l1431;
  }
  l1432:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "NonindentSpace", G->buf+G->pos));
  return 1;
  l1431:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "NonindentSpace", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Plain(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Plain"));  if (!yy_Inlines(G)) { goto l1436; }
  yyprintf((stderr, "  ok   %s @ %s\n", "Plain", G->buf+G->pos));
  return 1;
  l1436:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Plain", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Para(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Para"));  if (!yy_NonindentSpace(G)) { goto l1437; }  if (!yy_Inlines(G)) { goto l1437; }  if (!yy_BlankLine(G)) { goto l1437; }
  l1438:;	
  {  int yypos1439= G->pos, yythunkpos1439= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1439; }  goto l1438;
  l1439:;	  G->pos= yypos1439; G->thunkpos= yythunkpos1439;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "Para", G->buf+G->pos));
  return 1;
  l1437:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Para", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_StyleBlock(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "StyleBlock"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1440;  if (!yy_LocMarker(G)) { goto l1440; }  yyDo(G, yySet, -1, 0);  if (!yy_InStyleTags(G)) { goto l1440; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1440;
  l1441:;	
  {  int yypos1442= G->pos, yythunkpos1442= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1442; }  goto l1441;
  l1442:;	  G->pos= yypos1442; G->thunkpos= yythunkpos1442;
  }  yyDo(G, yy_1_StyleBlock, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "StyleBlock", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1440:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "StyleBlock", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlock(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "HtmlBlock"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1443;  if (!yy_LocMarker(G)) { goto l1443; }  yyDo(G, yySet, -1, 0);
  {  int yypos1444= G->pos, yythunkpos1444= G->thunkpos;  if (!yy_HtmlBlockInTags(G)) { goto l1445; }  goto l1444;
  l1445:;	  G->pos= yypos1444; G->thunkpos= yythunkpos1444;  if (!yy_HtmlComment(G)) { goto l1446; }  goto l1444;
  l1446:;	  G->pos= yypos1444; G->thunkpos= yythunkpos1444;  if (!yy_HtmlBlockSelfClosing(G)) { goto l1443; }
  }
  l1444:;	  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1443;  if (!yy_BlankLine(G)) { goto l1443; }
  l1447:;	
  {  int yypos1448= G->pos, yythunkpos1448= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1448; }  goto l1447;
  l1448:;	  G->pos= yypos1448; G->thunkpos= yythunkpos1448;
  }  yyDo(G, yy_1_HtmlBlock, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlock", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1443:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlock", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_BulletList(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "BulletList"));
  {  int yypos1450= G->pos, yythunkpos1450= G->thunkpos;  if (!yy_Bullet(G)) { goto l1449; }  G->pos= yypos1450; G->thunkpos= yythunkpos1450;
  }
  {  int yypos1451= G->pos, yythunkpos1451= G->thunkpos;  if (!yy_ListTight(G)) { goto l1452; }  goto l1451;
  l1452:;	  G->pos= yypos1451; G->thunkpos= yythunkpos1451;  if (!yy_ListLoose(G)) { goto l1449; }
  }
  l1451:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "BulletList", G->buf+G->pos));
  return 1;
  l1449:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "BulletList", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_OrderedList(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "OrderedList"));
  {  int yypos1454= G->pos, yythunkpos1454= G->thunkpos;  if (!yy_Enumerator(G)) { goto l1453; }  G->pos= yypos1454; G->thunkpos= yythunkpos1454;
  }
  {  int yypos1455= G->pos, yythunkpos1455= G->thunkpos;  if (!yy_ListTight(G)) { goto l1456; }  goto l1455;
  l1456:;	  G->pos= yypos1455; G->thunkpos= yythunkpos1455;  if (!yy_ListLoose(G)) { goto l1453; }
  }
  l1455:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "OrderedList", G->buf+G->pos));
  return 1;
  l1453:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "OrderedList", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Heading(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Heading"));
  {  int yypos1458= G->pos, yythunkpos1458= G->thunkpos;  if (!yy_SetextHeading(G)) { goto l1459; }  goto l1458;
  l1459:;	  G->pos= yypos1458; G->thunkpos= yythunkpos1458;  if (!yy_AtxHeading(G)) { goto l1457; }
  }
  l1458:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Heading", G->buf+G->pos));
  return 1;
  l1457:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Heading", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HorizontalRule(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HorizontalRule"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1460;  if (!yy_NonindentSpace(G)) { goto l1460; }
  {  int yypos1461= G->pos, yythunkpos1461= G->thunkpos;  if (!yymatchChar(G, '*')) goto l1462;  if (!yy_Sp(G)) { goto l1462; }  if (!yymatchChar(G, '*')) goto l1462;  if (!yy_Sp(G)) { goto l1462; }  if (!yymatchChar(G, '*')) goto l1462;
  l1463:;	
  {  int yypos1464= G->pos, yythunkpos1464= G->thunkpos;  if (!yy_Sp(G)) { goto l1464; }  if (!yymatchChar(G, '*')) goto l1464;  goto l1463;
  l1464:;	  G->pos= yypos1464; G->thunkpos= yythunkpos1464;
  }  goto l1461;
  l1462:;	  G->pos= yypos1461; G->thunkpos= yythunkpos1461;  if (!yymatchChar(G, '-')) goto l1465;  if (!yy_Sp(G)) { goto l1465; }  if (!yymatchChar(G, '-')) goto l1465;  if (!yy_Sp(G)) { goto l1465; }  if (!yymatchChar(G, '-')) goto l1465;
  l1466:;	
  {  int yypos1467= G->pos, yythunkpos1467= G->thunkpos;  if (!yy_Sp(G)) { goto l1467; }  if (!yymatchChar(G, '-')) goto l1467;  goto l1466;
  l1467:;	  G->pos= yypos1467; G->thunkpos= yythunkpos1467;
  }  goto l1461;
  l1465:;	  G->pos= yypos1461; G->thunkpos= yythunkpos1461;  if (!yymatchChar(G, '_')) goto l1460;  if (!yy_Sp(G)) { goto l1460; }  if (!yymatchChar(G, '_')) goto l1460;  if (!yy_Sp(G)) { goto l1460; }  if (!yymatchChar(G, '_')) goto l1460;
  l1468:;	
  {  int yypos1469= G->pos, yythunkpos1469= G->thunkpos;  if (!yy_Sp(G)) { goto l1469; }  if (!yymatchChar(G, '_')) goto l1469;  goto l1468;
  l1469:;	  G->pos= yypos1469; G->thunkpos= yythunkpos1469;
  }
  }
  l1461:;	  if (!yy_Sp(G)) { goto l1460; }  if (!yy_Newline(G)) { goto l1460; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1460;  if (!yy_BlankLine(G)) { goto l1460; }
  l1470:;	
  {  int yypos1471= G->pos, yythunkpos1471= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1471; }  goto l1470;
  l1471:;	  G->pos= yypos1471; G->thunkpos= yythunkpos1471;
  }  yyDo(G, yy_1_HorizontalRule, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "HorizontalRule", G->buf+G->pos));
  return 1;
  l1460:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HorizontalRule", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Reference(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 3, 0);
  yyprintf((stderr, "%s\n", "Reference"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1472;  if (!yy_LocMarker(G)) { goto l1472; }  yyDo(G, yySet, -3, 0);  if (!yy_NonindentSpace(G)) { goto l1472; }
  {  int yypos1473= G->pos, yythunkpos1473= G->thunkpos;  if (!yymatchString(G, "[]")) goto l1473;  goto l1472;
  l1473:;	  G->pos= yypos1473; G->thunkpos= yythunkpos1473;
  }  if (!yy_Label(G)) { goto l1472; }  yyDo(G, yySet, -2, 0);  if (!yymatchChar(G, ':')) goto l1472;  if (!yy_Spnl(G)) { goto l1472; }  if (!yy_RefSrc(G)) { goto l1472; }  yyDo(G, yySet, -1, 0);  if (!yy_RefTitle(G)) { goto l1472; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1472;  if (!yy_BlankLine(G)) { goto l1472; }
  l1474:;	
  {  int yypos1475= G->pos, yythunkpos1475= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1475; }  goto l1474;
  l1475:;	  G->pos= yypos1475; G->thunkpos= yythunkpos1475;
  }  yyDo(G, yy_1_Reference, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Reference", G->buf+G->pos));  yyDo(G, yyPop, 3, 0);
  return 1;
  l1472:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Reference", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Note(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Note"));  yyText(G, G->begin, G->end);  if (!( EXT(pmh_EXT_NOTES) )) goto l1476;  if (!yy_NonindentSpace(G)) { goto l1476; }  if (!yy_RawNoteReference(G)) { goto l1476; }  if (!yymatchChar(G, ':')) goto l1476;  if (!yy_Sp(G)) { goto l1476; }  if (!yy_RawNoteBlock(G)) { goto l1476; }
  l1477:;	
  {  int yypos1478= G->pos, yythunkpos1478= G->thunkpos;
  {  int yypos1479= G->pos, yythunkpos1479= G->thunkpos;  if (!yy_Indent(G)) { goto l1478; }  G->pos= yypos1479; G->thunkpos= yythunkpos1479;
  }  if (!yy_RawNoteBlock(G)) { goto l1478; }  goto l1477;
  l1478:;	  G->pos= yypos1478; G->thunkpos= yythunkpos1478;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "Note", G->buf+G->pos));
  return 1;
  l1476:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Note", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Verbatim(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "Verbatim"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1480;  if (!yy_LocMarker(G)) { goto l1480; }  yyDo(G, yySet, -1, 0);  if (!yy_VerbatimChunk(G)) { goto l1480; }
  l1481:;	
  {  int yypos1482= G->pos, yythunkpos1482= G->thunkpos;  if (!yy_VerbatimChunk(G)) { goto l1482; }  goto l1481;
  l1482:;	  G->pos= yypos1482; G->thunkpos= yythunkpos1482;
  }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1480;  yyDo(G, yy_1_Verbatim, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Verbatim", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1480:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Verbatim", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_BlockQuote(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "BlockQuote"));  if (!yy_BlockQuoteRaw(G)) { goto l1483; }  yyDo(G, yySet, -1, 0);  yyDo(G, yy_1_BlockQuote, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "BlockQuote", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1483:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "BlockQuote", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_BlankLine(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "BlankLine"));  if (!yy_Sp(G)) { goto l1484; }  if (!yy_Newline(G)) { goto l1484; }
  yyprintf((stderr, "  ok   %s @ %s\n", "BlankLine", G->buf+G->pos));
  return 1;
  l1484:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "BlankLine", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_LocMarker(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "LocMarker"));
  {  int yypos1486= G->pos, yythunkpos1486= G->thunkpos;  if (!yymatchDot(G)) goto l1485;  G->pos= yypos1486; G->thunkpos= yythunkpos1486;
  }  yyDo(G, yy_1_LocMarker, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "LocMarker", G->buf+G->pos));
  return 1;
  l1485:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "LocMarker", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Block(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Block"));
  l1488:;	
  {  int yypos1489= G->pos, yythunkpos1489= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1489; }  goto l1488;
  l1489:;	  G->pos= yypos1489; G->thunkpos= yythunkpos1489;
  }
  {  int yypos1490= G->pos, yythunkpos1490= G->thunkpos;  if (!yy_BlockQuote(G)) { goto l1491; }  goto l1490;
  l1491:;	  G->pos= yypos1490; G->thunkpos= yythunkpos1490;  if (!yy_Verbatim(G)) { goto l1492; }  goto l1490;
  l1492:;	  G->pos= yypos1490; G->thunkpos= yythunkpos1490;  if (!yy_Note(G)) { goto l1493; }  goto l1490;
  l1493:;	  G->pos= yypos1490; G->thunkpos= yythunkpos1490;  if (!yy_Reference(G)) { goto l1494; }  goto l1490;
  l1494:;	  G->pos= yypos1490; G->thunkpos= yythunkpos1490;  if (!yy_HorizontalRule(G)) { goto l1495; }  goto l1490;
  l1495:;	  G->pos= yypos1490; G->thunkpos= yythunkpos1490;  if (!yy_Heading(G)) { goto l1496; }  goto l1490;
  l1496:;	  G->pos= yypos1490; G->thunkpos= yythunkpos1490;  if (!yy_OrderedList(G)) { goto l1497; }  goto l1490;
  l1497:;	  G->pos= yypos1490; G->thunkpos= yythunkpos1490;  if (!yy_BulletList(G)) { goto l1498; }  goto l1490;
  l1498:;	  G->pos= yypos1490; G->thunkpos= yythunkpos1490;  if (!yy_HtmlBlock(G)) { goto l1499; }  goto l1490;
  l1499:;	  G->pos= yypos1490; G->thunkpos= yythunkpos1490;  if (!yy_StyleBlock(G)) { goto l1500; }  goto l1490;
  l1500:;	  G->pos= yypos1490; G->thunkpos= yythunkpos1490;  if (!yy_Para(G)) { goto l1501; }  goto l1490;
  l1501:;	  G->pos= yypos1490; G->thunkpos= yythunkpos1490;  if (!yy_Plain(G)) { goto l1487; }
  }
  l1490:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Block", G->buf+G->pos));
  return 1;
  l1487:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Block", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Doc(GREG *G)
{
  yyprintf((stderr, "%s\n", "Doc"));
  l1503:;	
  {  int yypos1504= G->pos, yythunkpos1504= G->thunkpos;  if (!yy_Block(G)) { goto l1504; }  goto l1503;
  l1504:;	  G->pos= yypos1504; G->thunkpos= yythunkpos1504;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "Doc", G->buf+G->pos));
  return 1;
}

#ifndef YY_PART

typedef int (*yyrule)(GREG *G);

YY_PARSE(int) YY_NAME(parse_from)(GREG *G, yyrule yystart)
{
  int yyok;
  if (!G->buflen)
    {
      G->buflen= YY_BUFFER_START_SIZE;
      G->buf= (char *)YY_ALLOC(G->buflen, G->data);
      G->textlen= YY_BUFFER_START_SIZE;
      G->text= (char *)YY_ALLOC(G->textlen, G->data);
      G->thunkslen= YY_STACK_SIZE;
      G->thunks= (yythunk *)YY_ALLOC(sizeof(yythunk) * G->thunkslen, G->data);
      G->valslen= YY_STACK_SIZE;
      G->vals= (YYSTYPE*)YY_ALLOC(sizeof(YYSTYPE) * G->valslen, G->data);
      G->begin= G->end= G->pos= G->limit= G->thunkpos= 0;
    }
  G->pos = 0;
  G->begin= G->end= G->pos;
  G->thunkpos= 0;
  G->val= G->vals;
  yyok= yystart(G);
  if (yyok) yyDone(G);
  yyCommit(G);
  return yyok;
  (void)yyrefill(NULL);
  (void)yymatchDot(NULL);
  (void)yymatchChar(NULL, 0);
  (void)yymatchString(NULL, NULL);
  (void)yymatchClass(NULL, NULL);
  (void)yyDo(NULL, NULL, 0, 0);
  (void)yyText(NULL, 0, 0);
  (void)yyDone(NULL);
  (void)yyCommit(NULL);
  (void)yyAccept(NULL, 0);
  (void)yyPush(NULL, NULL, 0, NULL, NULL);
  (void)yyPop(NULL, NULL, 0, NULL, NULL);
  (void)yySet(NULL, NULL, 0, NULL, NULL);
}

YY_PARSE(int) YY_NAME(parse)(GREG *G)
{
  return YY_NAME(parse_from)(G, yy_Doc);
}

YY_PARSE(GREG *) YY_NAME(parse_new)(YY_XTYPE data)
{
  GREG *G = (GREG *)YY_CALLOC(1, sizeof(GREG), G->data);
  G->data = data;
  return G;
}

YY_PARSE(void) YY_NAME(parse_free)(GREG *G)
{
  YY_FREE(G->buf);
  YY_FREE(G->text);
  YY_FREE(G->thunks);
  YY_FREE(G->vals);
  YY_FREE(G);
}

#endif




/* PEG Markdown Highlight
 * Copyright 2011-2016 Ali Rantakari -- http://hasseg.org
 * Licensed under the GPL2+ and MIT licenses (see LICENSE for more info).
 * 
 * pmh_parser_foot.c
 * 
 * Code to be appended to the end of the parser code generated from the
 * PEG grammar.
 */


static void _parse(parser_data *p_data, yyrule start_rule)
{
    GREG *g = YY_NAME(parse_new)(p_data);
    if (start_rule == NULL)
        YY_NAME(parse)(g);
    else
        YY_NAME(parse_from)(g, start_rule);
    YY_NAME(parse_free)(g);
    
    pmh_PRINTF("\n\n");
}

static void parse_markdown(parser_data *p_data)
{
    pmh_PRINTF("\nPARSING DOCUMENT: ");
    
    _parse(p_data, NULL);
}

static void parse_references(parser_data *p_data)
{
    pmh_PRINTF("\nPARSING REFERENCES: ");
    
    p_data->parsing_only_references = true;
    _parse(p_data, yy_References);
    p_data->parsing_only_references = false;
    
    p_data->references = p_data->head_elems[pmh_REFERENCE];
    p_data->head_elems[pmh_REFERENCE] = NULL;
}

